% WRV_Plot_3D_BrushCreek.m
%
% AUTHOR:           Michael W. Swyer
% DATE CREATED:     2015/05/26
% DATE MODIFIED:    
% VERSION:          v.1
%
% PURPOSE:  To construct 3D fault geometry of Brush Creek Fault at Wind River
% Valley
%
% PURPOSE OF MODIFICATION:
% 
% INPUT: Surface points from mapped fault trace:
%            1) Brush_Creek_Fault_surfacepoints.csv
%        intersection with Wind River Fault:
%            2) Brush_Creek_Fault_intersection.csv
%
% OUTPUT: Position of fault nodes in UTM Zone 10N meters (XYZ-),
% triangulation of fault nodes (tn-), and unit normal vectors of fault element
% triangles (nvec-).
%
% NOTE:
%
% KEY functions written specifically for this modeling:
%
% Other related functions:
%       deg2utm.m
%       fitNormal.m
%       Delaunay2_5D.m
%       PlotTriNormals.m

clear all;close all

show_graph = 0;% Show graph of fit normal (0=no 1=yes)
f = 1;% smoothing factor (0 to 1)
convention = 'z-';% PlotTriNormals vector direction
%% brush creek fault %%

% local origin
xo = 0;
yo = 0;

% import data
% surface points
data = importdata('Brush_Creek_Fault_surfacepoints.csv',',');
% lat = data.data(:,2);
% long = data.data(:,1);
% [x,y,utmzone] = deg2utm(lat,long);
x = data.data(:,1) - xo;
y = data.data(:,2) - yo;
z = zeros(numel(x),1);

% intersection
dataint = importdata('Brush_Creek_Fault_intersection.csv',',');
xi = dataint.data(:,1);
yi = dataint.data(:,2);
xi = xi - xo;
yi = yi - yo;
zi = dataint.data(:,3);
% fit normal vector
if show_graph==1
    figure
end
clear c;clear n
c(:,1) = [x;xi];c(:,2) = [y;yi];c(:,3) = [z;zi];
n = fitNormal(c, show_graph);

% rotate to j=0
theta = atan(-n(2)/n(1));
Rccw = [cos(theta) -sin(theta);sin(theta) cos(theta)];
dx = 0;
dy = 0;
for i=1:numel(x)
    b = Rccw*[x(i);y(i)];
    x(i) = b(1)+dx;y(i) = b(2)+dy;
end
for i=1:numel(xi)
    b = Rccw*[xi(i);yi(i)];
    xi(i) = b(1)+dx;yi(i) = b(2)+dy;
end
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = [x;xi];c(:,2) = [y;yi];c(:,3) = [z;zi];
    n = fitNormal(c, show_graph);
end

% add fault nodes at depth
for i=1:numel(x)
    xd{i} = xi - (x(13)-x(i));
    yd{i} = yi - (y(13)-y(i));
    zd{i} = zi - (z(13)-z(i));
end
for i=1:numel(x)
    x = [x;xd{i}];
    y = [y;yd{i}];
    z = [z;zd{i}];
end
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = x;c(:,2) = y;c(:,3) = z;
    n = fitNormal(c, show_graph);
end

% fill out SW deep corner
for i=1:numel(xi)
    x = [x;(xi(i:numel(xi))-(x(13)-x(1)))];
    y = [y;(yi(i:numel(yi))-(y(13)-y(1))-250*i)];
    z = [z;zi(i:numel(zi))];
end
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = x;c(:,2) = y;c(:,3) = z;
    n = fitNormal(c, show_graph);
end

% Trim off ends beyond surface trace
I = find(y>=y(1));
x = x(I);y = y(I);z = z(I);
I = find(y<=y(20));
x = x(I);y = y(I);z = z(I);
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = x;c(:,2) = y;c(:,3) = z;
    n = fitNormal(c, show_graph);
end

% Save vertical bounding lines
zi = [0;zi];
for i=1:numel(zi)
    I = find(z==zi(i));
    J = find(y(I)==min(y(I)));
    xs(i) = x(I(J));ys(i) = y(I(J));zs(i) = z(I(J));
    J = find(y(I)==max(y(I)));
    xn(i) = x(I(J));yn(i) = y(I(J));zn(i) = z(I(J));
end
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = [xs';xn'];c(:,2) = [ys';yn'];c(:,3) = [zs';zn'];
    n = fitNormal(c, show_graph);
end

% add curvilinear tips
for i=1:20
    x = [x;xs(round(2+.1*i^2):numel(xs)-round(1+.1*i^2))'];
    y = [y;ys(round(2+.1*i^2):numel(ys)-round(1+.1*i^2))'-250*i];
    z = [z;zs(round(2+.1*i^2):numel(zs)-round(1+.1*i^2))'];
    x = [x;xn(round(2+.1*i^2):numel(xn)-round(1+.1*i^2))'];
    y = [y;yn(round(2+.1*i^2):numel(yn)-round(1+.1*i^2))'+250*i];
    z = [z;zs(round(2+.1*i^2):numel(zs)-round(1+.1*i^2))'];
end
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = x;c(:,2) = y;c(:,3) = z;
    n = fitNormal(c, show_graph);
end

% put xyz points for fault nodes into 3 column matrix
XYZbcfNW(:,1) = x;XYZbcfNW(:,2) = y;XYZbcfNW(:,3) = z;
for i=1:numel(XYZbcfNW(:,3))
    if XYZbcfNW(i,3)==0
        XYZbcfNW(i,3)=-1;
    end
end

% triangulate fault nodes
CON=Delaunay2_5D(XYZbcfNW);

% Rotate back
Rcw = [cos(theta) sin(theta);-sin(theta) cos(theta)];
for i=1:numel(XYZbcfNW(:,1))
    b = Rcw*[XYZbcfNW(i,1)-dx;XYZbcfNW(i,2)-dy];
    XYZbcfNW(i,1) = b(1);XYZbcfNW(i,2) = b(2);
end

% plot fault nodes
figure
plot3(XYZbcfNW(:,1),XYZbcfNW(:,2),XYZbcfNW(:,3),'ko');
xlabel('E-W(m)','fontsize',12)
ylabel('N-S(m)','fontsize',12)
axis equal;grid on
title('Brush Creek Fault','fontsize',12)
hold on

% plot fault triangulation
for i=1:numel(CON(:,1))
    plot3(XYZbcfNW([CON(i,:) CON(i,1)],1),XYZbcfNW([CON(i,:) CON(i,1)],2),XYZbcfNW([CON(i,:) CON(i,1)],3),'b-')
end

% correct polarity of triangulation
[tnbcfNW,nvecbcfNW] = PlotTriNormals(CON,XYZbcfNW,convention);

% Translate back to UTM
XYZbcfNW(:,1) = XYZbcfNW(:,1) + xo;
XYZbcfNW(:,2) = XYZbcfNW(:,2) + yo;