% WRV_Plot_3D_BunkerHill_uncertainty.m
%
% AUTHOR:           Michael W. Swyer
% DATE CREATED:     2015/08/28
% DATE MODIFIED:    
% VERSION:          v.1
%
% PURPOSE:  To construct upper/lower residual3D fault geometry of Bunker
% Hill Fault at Wind River Valley
%
% PURPOSE OF MODIFICATION:
% 
% INPUT: Surface points from mapped fault trace:
%       Bunker_Hill_Fault_surfacepoints.csv
%
% OUTPUT: Position of fault nodes in UTM Zone 10N meters (XYZ-),
% triangulation of fault nodes (tn-), and unit normal vectors of fault element
% triangles (nvec-).
%
% NOTE:
%
% KEY functions written specifically for this modeling:
%
% Other related functions:
%       deg2utm.m
%       fitNormal.m
%       Delaunay2_5D.m
%       PlotTriNormals.m

clear all;close all

show_graph = 1;% Show graph of fit normal (0=no 1=yes)
f = 1;% smoothing factor (0 to 1)
convention = 'z-';% PlotTriNormals vector direction
%% bunker hill fault %%

% local origin
xo = 5.82e5;
yo = 5.074e6;

% import data
data = importdata('Bunker_Hill_Fault_surfacepoints.csv',',');
lat = data.data(:,2);
long = data.data(:,1);
[x,y,utmzone] = deg2utm(lat,long);
x = x - xo;
y = y - yo;
z = zeros(numel(x),1);

% fit normal vector
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = x;c(:,2) = y;c(:,3) = z;
    n = fitNormal(c, show_graph);
end

% rotate to j=0
theta = atan((max(x)-min(x))/(max(y)-min(y)));
Rccw = [cos(theta) -sin(theta);sin(theta) cos(theta)];
dx = 500;
dy = 0;
for i=1:numel(x)
    b = Rccw*[x(i);y(i)];
    x(i) = b(1)+dx;y(i) = b(2)+dy;
end

if show_graph==1
    figure
    clear c;clear n
    c(:,1) = x;c(:,2) = y;c(:,3) = z;
    n = fitNormal(c, show_graph);
end

% row 2
x = [x;x(1);x(1);x;x(numel(x));x(numel(x))];
y = [y;y(1)-600;y(1)-300;y;y(numel(y))+300;y(numel(y))+600];
z = [z;ones(numel(z)+4,1)*-300];
% row 3
x = [x;x(1);x(11:24);x(numel(x))];
y = [y;y(1)-900;y(11:24);y(numel(y))+300];
z = [z;ones(16,1)*-600];
% row 4
x = [x;x(1);x(25:40);x(numel(x))];
y = [y;y(1)-1200;y(25:40);y(numel(y))+300];
z = [z;ones(18,1)*-900];
% row 5
x = [x;x(41:58)];
y = [y;y(41:58)];
z = [z;ones(18,1)*-1200];
% row 6
x = [x;x(1);x(41:58);x(numel(x))];
y = [y;y(1)-1500;y(41:58);y(numel(y))+300];
z = [z;ones(20,1)*-1500];
% row 7
x = [x;x(77:96)];
y = [y;y(77:96)];
z = [z;ones(20,1)*-1800];
% row 8
x = [x;x(98:115)];
y = [y;y(98:115)];
z = [z;ones(18,1)*-2100];
% row 9
x = [x;x(117:134)];
y = [y;y(117:134)];
z = [z;ones(18,1)*-2400];
% row 10
x = [x;x(136:151)];
y = [y;y(136:151)];
z = [z;ones(16,1)*-2700];
% row 11
x = [x;x(154:167)];
y = [y;y(154:167)];
z = [z;ones(14,1)*-3000];
% row 12
x = [x;x(171:180)];
y = [y;y(171:180)];
z = [z;ones(10,1)*-3300];

% fit normal vector
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = x;c(:,2) = y;c(:,3) = z;
    n = fitNormal(c, show_graph);
end

% rotate about y-axis for fault dip
xs = max(x);
x = x - xs;
Rccw = [cos(10*(pi/180)) -sin(10*(pi/180));sin(10*(pi/180)) cos(10*(pi/180))];
Rccw_ul = [cos(20*(pi/180)) -sin(20*(pi/180));sin(20*(pi/180)) cos(20*(pi/180))];
Rccw_ll = [cos(5*(pi/180)) -sin(5*(pi/180));sin(5*(pi/180)) cos(5*(pi/180))];
for i=1:numel(x)
    b = Rccw*[x(i);z(i)];
    b_ul = Rccw_ul*[x(i);z(i)];
    b_ll = Rccw_ll*[x(i);z(i)];
    x(i) = b(1);z(i) = b(2);
    x_ul(i) = b_ul(1);z_ul(i) = b_ul(2);y_ul(i) = y(i);
    x_ll(i) = b_ll(1);z_ll(i) = b_ll(2);y_ll(i) = y(i);
end
x = x + xs;
x_ul = x_ul + xs;
x_ll = x_ll + xs;

% put xyz points for fault nodes in 3 column matrix
XYZbhf(:,1) = x;XYZbhf(:,2) = y;XYZbhf(:,3) = z;
XYZbhf_ul(:,1) = x_ul;XYZbhf_ul(:,2) = y_ul;XYZbhf_ul(:,3) = z_ul;
XYZbhf_ll(:,1) = x_ll;XYZbhf_ll(:,2) = y_ll;XYZbhf_ll(:,3) = z_ll;
for i=1:numel(XYZbhf(:,3))
    if XYZbhf(i,3)==0
        XYZbhf(i,3)=-1;
    end
end

% triangulate fault nodes
CON=Delaunay2_5D(XYZbhf_ul);
for i=1:numel(XYZbhf_ul(:,3))
    if XYZbhf_ul(i,3)==0
        XYZbhf_ul(i,3)=-1;
    end
end
CON_ul=Delaunay2_5D(XYZbhf_ul);
for i=1:numel(XYZbhf_ll(:,3))
    if XYZbhf_ll(i,3)==0
        XYZbhf_ll(i,3)=-1;
    end
end
CON_ll=Delaunay2_5D(XYZbhf_ll);

% Rotate back
Rcw = [cos(theta) sin(theta);-sin(theta) cos(theta)];
for i=1:numel(XYZbhf(:,1))
    b = Rcw*[XYZbhf(i,1)-dx;XYZbhf(i,2)-dy];
    XYZbhf(i,1) = b(1);XYZbhf(i,2) = b(2);
    b = Rcw*[XYZbhf_ul(i,1)-dx;XYZbhf_ul(i,2)-dy];
    XYZbhf_ul(i,1) = b(1);XYZbhf_ul(i,2) = b(2);
    b = Rcw*[XYZbhf_ll(i,1)-dx;XYZbhf_ll(i,2)-dy];
    XYZbhf_ll(i,1) = b(1);XYZbhf_ll(i,2) = b(2);
end

% plot fault nodes
figure
plot3(XYZbhf(:,1),XYZbhf(:,2),XYZbhf(:,3),'ko');
hold on
plot3(XYZbhf_ul(:,1),XYZbhf_ul(:,2),XYZbhf_ul(:,3),'ko');
plot3(XYZbhf_ll(:,1),XYZbhf_ll(:,2),XYZbhf_ll(:,3),'ko');
xlabel('E-W(m)','fontsize',12)
ylabel('N-S(m)','fontsize',12)
axis equal;grid on
title('Bunker Hill Fault','fontsize',12)

% plot fault mesh
for i=1:numel(CON(:,1))
    plot3(XYZbhf([CON(i,:) CON(i,1)],1),XYZbhf([CON(i,:) CON(i,1)],2),XYZbhf([CON(i,:) CON(i,1)],3),'k-')
end
for i=1:numel(CON_ul(:,1))
    plot3(XYZbhf_ul([CON_ul(i,:) CON_ul(i,1)],1),XYZbhf_ul([CON_ul(i,:) CON_ul(i,1)],2),XYZbhf_ul([CON_ul(i,:) CON_ul(i,1)],3),'r-')
end
for i=1:numel(CON_ll(:,1))
    plot3(XYZbhf_ll([CON_ll(i,:) CON_ll(i,1)],1),XYZbhf_ll([CON_ll(i,:) CON_ll(i,1)],2),XYZbhf_ll([CON_ll(i,:) CON_ll(i,1)],3),'r-')
end

% correct polarity of triangulation
[tnbhf,nvecbhf] = PlotTriNormals(CON,XYZbhf,convention);
[tnbhf_ul,nvecbhf_ul] = PlotTriNormals(CON_ul,XYZbhf_ul,convention);
[tnbhf_ll,nvecbhf_ll] = PlotTriNormals(CON_ll,XYZbhf_ll,convention);

% Translate back to UTM
XYZbhf(:,1) = XYZbhf(:,1) + xo;
XYZbhf(:,2) = XYZbhf(:,2) + yo;
XYZbhf_ul(:,1) = XYZbhf_ul(:,1) + xo;
XYZbhf_ul(:,2) = XYZbhf_ul(:,2) + yo;
XYZbhf_ll(:,1) = XYZbhf_ll(:,1) + xo;
XYZbhf_ll(:,2) = XYZbhf_ll(:,2) + yo;