% WRV_Plot_3D_ShiperdsSE_uncertainty.m
%
% AUTHOR:           Michael W. Swyer
% DATE CREATED:     2015/08/27
% DATE MODIFIED:    
% VERSION:          v.1
%
% PURPOSE:  To construct upper/lower residual 3D fault geometry of Brush Creek
% Fault at Wind River Valley
%
% PURPOSE OF MODIFICATION:
% 
% INPUT: Surface points from mapped fault trace:
%            1) Shiperds_Fault SE_surfacepoints.csv
%            2) Shiperds_Fault SE_surfacepoints_ul.csv
%            3) Shiperds_Fault SE_surfacepoints_ll.csv
%        intersection with Wind River Fault:
%            4) Shiperds_Fault SE_intersection.csv
%            5) Shiperds_Fault SE_intersection_ul.csv
%            6) Shiperds_Fault SE_intersection_ll.csv
%
% OUTPUT: Position of fault nodes in UTM Zone 10N meters (XYZ-),
% triangulation of fault nodes (tn-), and unit normal vectors of fault element
% triangles (nvec-).
%
% NOTE:
%
% KEY functions written specifically for this modeling:
%
% Other related functions:
%       deg2utm.m
%       fitNormal.m
%       Delaunay2_5D.m
%       PlotTriNormals.m

clear all;close all

show_graph = 1;% Show graph of fit normal (0=no 1=yes)
f = 1;% smoothing factor (0 to 1)
convention = 'z-';% PlotTriNormals vector direction
%% shiperds fault SE %%

% local origin
xo = 0;
yo = 0;

% import data
% surface points
data = importdata('Shiperds_Fault_SE_surfacepoints.csv',',');
x = data.data(:,1) - xo;
y = data.data(:,2) - yo;
z = zeros(numel(x),1);

% intersection
dataint = importdata('Shiperds_Fault_SE_intersection.csv',',');
xi = dataint.data(:,1);
yi = dataint.data(:,2);
xi = xi - xo;
yi = yi - yo;
zi = dataint.data(:,3);
% fit normal vector
if show_graph==1
    figure
end
clear c;clear n
c(:,1) = [x;xi];c(:,2) = [y;yi];c(:,3) = [z;zi];
n = fitNormal(c, show_graph);

% rotate to j=0
theta = atan(-n(2)/n(1));
Rccw = [cos(theta) -sin(theta);sin(theta) cos(theta)];
dx = 0;
dy = 0;
for i=1:numel(x)
    b = Rccw*[x(i);y(i)];
    x(i) = b(1)+dx;y(i) = b(2)+dy;
end
for i=1:numel(xi)
    b = Rccw*[xi(i);yi(i)];
    xi(i) = b(1)+dx;yi(i) = b(2)+dy;
end
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = [x;xi];c(:,2) = [y;yi];c(:,3) = [z;zi];
    n = fitNormal(c, show_graph);
end

% Add fault nodes at depth
for i=1:numel(x)
    xd{i} = xi - (x(6)-x(i));
    yd{i} = yi - (y(6)-y(i));
    zd{i} = zi - (z(6)-z(i));
end
for i=1:numel(x)
    x = [x;xd{i}];
    y = [y;yd{i}];
    z = [z;zd{i}];
end
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = x;c(:,2) = y;c(:,3) = z;
    n = fitNormal(c, show_graph);
end

% Fill out SW deep corner
for i=1:numel(xi)
    x = [x;(xi(i:numel(xi))-(x(6)-x(1)))];
    y = [y;(yi(i:numel(yi))-(y(6)-y(1))-250*i)];
    z = [z;zi(i:numel(zi))];
end
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = x;c(:,2) = y;c(:,3) = z;
    n = fitNormal(c, show_graph);
end

% Trim off ends beyond surface trace
I = find(y>=y(1));
x = x(I);y = y(I);z = z(I);
I = find(y<=y(11));
x = x(I);y = y(I);z = z(I);
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = x;c(:,2) = y;c(:,3) = z;
    n = fitNormal(c, show_graph);
end

% Save vertical bounding lines
zi = [0;zi];
for i=1:numel(zi)
    I = find(z==zi(i));
    J = find(y(I)==min(y(I)));
    xs(i) = x(I(J));ys(i) = y(I(J));zs(i) = z(I(J));
    J = find(y(I)==max(y(I)));
    xn(i) = x(I(J));yn(i) = y(I(J));zn(i) = z(I(J));
end
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = [xs';xn'];c(:,2) = [ys';yn'];c(:,3) = [zs';zn'];
    n = fitNormal(c, show_graph);
end

% Add curvilinear tips
for i=1:12
    x = [x;xs(round(2+.1*i^2):numel(xs)-round(1+.1*i^2))'];
    y = [y;ys(round(2+.1*i^2):numel(ys)-round(1+.1*i^2))'-200*i];
    z = [z;zs(round(2+.1*i^2):numel(zs)-round(1+.1*i^2))'];
    x = [x;xn(round(2+.1*i^2):numel(xn)-round(1+.1*i^2))'];
    y = [y;yn(round(2+.1*i^2):numel(yn)-round(1+.1*i^2))'+200*i];
    z = [z;zs(round(2+.1*i^2):numel(zs)-round(1+.1*i^2))'];
end
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = x;c(:,2) = y;c(:,3) = z;
    n = fitNormal(c, show_graph);
end

% put xyz points for fault nodes in 3 column matrix
XYZsfSE(:,1) = x;XYZsfSE(:,2) = y;XYZsfSE(:,3) = z;
for i=1:numel(XYZsfSE(:,3))
    if XYZsfSE(i,3)==0
        XYZsfSE(i,3)=-1;
    end
end

% trangulate fault nodes
CON=Delaunay2_5D(XYZsfSE);

% Rotate back
Rcw = [cos(theta) sin(theta);-sin(theta) cos(theta)];
for i=1:numel(XYZsfSE(:,1))
    b = Rcw*[XYZsfSE(i,1)-dx;XYZsfSE(i,2)-dy];
    XYZsfSE(i,1) = b(1);XYZsfSE(i,2) = b(2);
end

% upper residuals
% import data
% surface points
data_ul = importdata('Shiperds_Fault_SE_surfacepoints_ul.csv',',');
x_ul = data_ul.data(:,1) - xo;
y_ul = data_ul.data(:,2) - yo;
z_ul = zeros(numel(x_ul),1);

% intersections
dataint_ul = importdata('Shiperds_Fault_SE_intersection_ul.csv',',');
xi_ul = dataint_ul.data(:,1);
yi_ul = dataint_ul.data(:,2);
xi_ul = xi_ul - xo;
yi_ul = yi_ul - yo;
zi_ul = dataint_ul.data(:,3);
% fit normal vector
if show_graph==1
    figure
end
clear c;clear n
c(:,1) = [x_ul;xi_ul];c(:,2) = [y_ul;yi_ul];c(:,3) = [z_ul;zi_ul];
n = fitNormal(c, show_graph);

% rotate to j=0
theta_ul = atan(-n(2)/n(1));
Rccw = [cos(theta_ul) -sin(theta_ul);sin(theta_ul) cos(theta_ul)];
dx = 0;
dy = 0;
for i=1:numel(x_ul)
    b = Rccw*[x_ul(i);y_ul(i)];
    x_ul(i) = b(1)+dx;y_ul(i) = b(2)+dy;
end
for i=1:numel(xi_ul)
    b = Rccw*[xi_ul(i);yi_ul(i)];
    xi_ul(i) = b(1)+dx;yi_ul(i) = b(2)+dy;
end
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = [x_ul;xi_ul];c(:,2) = [y_ul;yi_ul];c(:,3) = [z_ul;zi_ul];
    n = fitNormal(c, show_graph);
end

% Add fault nodes at depth
for i=1:numel(x_ul)
    xd_ul{i} = xi_ul - (x_ul(6)-x_ul(i));
    yd_ul{i} = yi_ul - (y_ul(6)-y_ul(i));
    zd_ul{i} = zi_ul - (z_ul(6)-z_ul(i));
end
for i=1:numel(x_ul)
    x_ul = [x_ul;xd_ul{i}];
    y_ul = [y_ul;yd_ul{i}];
    z_ul = [z_ul;zd_ul{i}];
end
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = x_ul;c(:,2) = y_ul;c(:,3) = z_ul;
    n = fitNormal(c, show_graph);
end

% Fill out SW deep corner
for i=1:numel(xi_ul)
    x_ul = [x_ul;(xi_ul(i:numel(xi_ul))-(x_ul(6)-x_ul(1)))];
    y_ul = [y_ul;(yi_ul(i:numel(yi_ul))-(y_ul(6)-y_ul(1))-250*i)];
    z_ul = [z_ul;zi_ul(i:numel(zi_ul))];
end
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = x_ul;c(:,2) = y_ul;c(:,3) = z_ul;
    n = fitNormal(c, show_graph);
end

% Trim off ends beyond surface trace
I = find(y_ul>=y_ul(1));
x_ul = x_ul(I);y_ul = y_ul(I);z_ul = z_ul(I);
I = find(y_ul<=y_ul(11));
x_ul = x_ul(I);y_ul = y_ul(I);z_ul = z_ul(I);
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = x_ul;c(:,2) = y_ul;c(:,3) = z_ul;
    n = fitNormal(c, show_graph);
end

% Save vertical bounding lines
zi_ul = [0;zi_ul];
for i=1:numel(zi_ul)
    I = find(z_ul==zi_ul(i));
    J = find(y_ul(I)==min(y_ul(I)));
    xs_ul(i) = x_ul(I(J));ys_ul(i) = y_ul(I(J));zs_ul(i) = z_ul(I(J));
    J = find(y_ul(I)==max(y_ul(I)));
    xn_ul(i) = x_ul(I(J));yn_ul(i) = y_ul(I(J));zn_ul(i) = z_ul(I(J));
end
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = [xs_ul';xn_ul'];c(:,2) = [ys_ul';yn_ul'];c(:,3) = [zs_ul';zn_ul'];
    n = fitNormal(c, show_graph);
end

% Add curvilinear tips
for i=1:12
    x_ul = [x_ul;xs_ul(round(2+.1*i^2):numel(xs_ul)-round(1+.1*i^2))'];
    y_ul = [y_ul;ys_ul(round(2+.1*i^2):numel(ys_ul)-round(1+.1*i^2))'-200*i];
    z_ul = [z_ul;zs_ul(round(2+.1*i^2):numel(zs_ul)-round(1+.1*i^2))'];
    x_ul = [x_ul;xn_ul(round(2+.1*i^2):numel(xn_ul)-round(1+.1*i^2))'];
    y_ul = [y_ul;yn_ul(round(2+.1*i^2):numel(yn_ul)-round(1+.1*i^2))'+200*i];
    z_ul = [z_ul;zs_ul(round(2+.1*i^2):numel(zs_ul)-round(1+.1*i^2))'];
end
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = x_ul;c(:,2) = y_ul;c(:,3) = z_ul;
    n = fitNormal(c, show_graph);
end

% put xyz points for fault nodes in 3 column matrix
XYZsfSE_ul(:,1) = x_ul;XYZsfSE_ul(:,2) = y_ul;XYZsfSE_ul(:,3) = z_ul;
for i=1:numel(XYZsfSE_ul(:,3))
    if XYZsfSE_ul(i,3)==0
        XYZsfSE_ul(i,3)=-1;
    end
end

% triangulate fault nodes
CON_ul=Delaunay2_5D(XYZsfSE_ul);

% Rotate back
Rcw = [cos(theta_ul) sin(theta_ul);-sin(theta_ul) cos(theta_ul)];
for i=1:numel(XYZsfSE_ul(:,1))
    b = Rcw*[XYZsfSE_ul(i,1)-dx;XYZsfSE_ul(i,2)-dy];
    XYZsfSE_ul(i,1) = b(1);XYZsfSE_ul(i,2) = b(2);
end

% lower residuals
% import data
% surface points
data_ll = importdata('Shiperds_Fault_SE_surfacepoints_ll.csv',',');
x_ll = data_ll.data(:,1) - xo;
y_ll = data_ll.data(:,2) - yo;
z_ll = zeros(numel(x_ll),1);

% intersection
dataint_ll = importdata('Shiperds_Fault_SE_intersection_ll.csv',',');
xi_ll = dataint_ll.data(:,1);
yi_ll = dataint_ll.data(:,2);
xi_ll = xi_ll - xo;
yi_ll = yi_ll - yo;
zi_ll = dataint_ll.data(:,3);
% fit normal vector
if show_graph==1
    figure
end
clear c;clear n
c(:,1) = [x_ll;xi_ll];c(:,2) = [y_ll;yi_ll];c(:,3) = [z_ll;zi_ll];
n = fitNormal(c, show_graph);

% rotate to j=0
theta_ll = atan(-n(2)/n(1));
Rccw = [cos(theta_ll) -sin(theta_ll);sin(theta_ll) cos(theta_ll)];
dx = 0;
dy = 0;
for i=1:numel(x_ll)
    b = Rccw*[x_ll(i);y_ll(i)];
    x_ll(i) = b(1)+dx;y_ll(i) = b(2)+dy;
end
for i=1:numel(xi_ll)
    b = Rccw*[xi_ll(i);yi_ll(i)];
    xi_ll(i) = b(1)+dx;yi_ll(i) = b(2)+dy;
end
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = [x_ll;xi_ll];c(:,2) = [y_ll;yi_ll];c(:,3) = [z_ll;zi_ll];
    n = fitNormal(c, show_graph);
end

% Add fault nodes at depth
for i=1:numel(x_ll)
    xd_ll{i} = xi_ll - (x_ll(6)-x_ll(i));
    yd_ll{i} = yi_ll - (y_ll(6)-y_ll(i));
    zd_ll{i} = zi_ll - (z_ll(6)-z_ll(i));
end
for i=1:numel(x_ll)
    x_ll = [x_ll;xd_ll{i}];
    y_ll = [y_ll;yd_ll{i}];
    z_ll = [z_ll;zd_ll{i}];
end
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = x_ll;c(:,2) = y_ll;c(:,3) = z_ll;
    n = fitNormal(c, show_graph);
end

% Fill out SW deep corner
for i=1:numel(xi_ll)
    x_ll = [x_ll;(xi_ll(i:numel(xi_ll))-(x_ll(6)-x_ll(1)))];
    y_ll = [y_ll;(yi_ll(i:numel(yi_ll))-(y_ll(6)-y_ll(1))-250*i)];
    z_ll = [z_ll;zi_ll(i:numel(zi_ll))];
end
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = x_ll;c(:,2) = y_ll;c(:,3) = z_ll;
    n = fitNormal(c, show_graph);
end

% Trim off ends beyond surface trace
I = find(y_ll>=y_ll(1));
x_ll = x_ll(I);y_ll = y_ll(I);z_ll = z_ll(I);
I = find(y_ll<=y_ll(11));
x_ll = x_ll(I);y_ll = y_ll(I);z_ll = z_ll(I);
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = x_ll;c(:,2) = y_ll;c(:,3) = z_ll;
    n = fitNormal(c, show_graph);
end

% Save vertical bounding lines
zi_ll = [0;zi_ll];
for i=1:numel(zi_ll)
    I = find(z_ll==zi_ll(i));
    J = find(y_ll(I)==min(y_ll(I)));
    xs_ll(i) = x_ll(I(J));ys_ll(i) = y_ll(I(J));zs_ll(i) = z_ll(I(J));
    J = find(y_ll(I)==max(y_ll(I)));
    xn_ll(i) = x_ll(I(J));yn_ll(i) = y_ll(I(J));zn_ll(i) = z_ll(I(J));
end
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = [xs_ll';xn_ll'];c(:,2) = [ys_ll';yn_ll'];c(:,3) = [zs_ll';zn_ll'];
    n = fitNormal(c, show_graph);
end

% Add curvilinear tips
for i=1:12
    x_ll = [x_ll;xs_ll(round(2+.1*i^2):numel(xs_ll)-round(1+.1*i^2))'];
    y_ll = [y_ll;ys_ll(round(2+.1*i^2):numel(ys_ll)-round(1+.1*i^2))'-200*i];
    z_ll = [z_ll;zs_ll(round(2+.1*i^2):numel(zs_ll)-round(1+.1*i^2))'];
    x_ll = [x_ll;xn_ll(round(2+.1*i^2):numel(xn_ll)-round(1+.1*i^2))'];
    y_ll = [y_ll;yn_ll(round(2+.1*i^2):numel(yn_ll)-round(1+.1*i^2))'+200*i];
    z_ll = [z_ll;zs_ll(round(2+.1*i^2):numel(zs_ll)-round(1+.1*i^2))'];
end
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = x_ll;c(:,2) = y_ll;c(:,3) = z_ll;
    n = fitNormal(c, show_graph);
end

% put xyz points for fault nodes in 3 column matrix
XYZsfSE_ll(:,1) = x_ll;XYZsfSE_ll(:,2) = y_ll;XYZsfSE_ll(:,3) = z_ll;
for i=1:numel(XYZsfSE_ll(:,3))
    if XYZsfSE_ll(i,3)==0
        XYZsfSE_ll(i,3)=-1;
    end
end

% triangulate fault nodes
CON_ll=Delaunay2_5D(XYZsfSE_ll);

% Rotate back
Rcw = [cos(theta_ll) sin(theta_ll);-sin(theta_ll) cos(theta_ll)];
for i=1:numel(XYZsfSE_ll(:,1))
    b = Rcw*[XYZsfSE_ll(i,1)-dx;XYZsfSE_ll(i,2)-dy];
    XYZsfSE_ll(i,1) = b(1);XYZsfSE_ll(i,2) = b(2);
end

% plot fault nodes
figure
plot3(XYZsfSE(:,1),XYZsfSE(:,2),XYZsfSE(:,3),'ko');
hold on
plot3(XYZsfSE_ul(:,1),XYZsfSE_ul(:,2),XYZsfSE_ul(:,3),'ko');
plot3(XYZsfSE_ll(:,1),XYZsfSE_ll(:,2),XYZsfSE_ll(:,3),'ko');
xlabel('E-W(m)','fontsize',12)
ylabel('N-S(m)','fontsize',12)
axis equal;grid on
title('Shiperds Fault SE','fontsize',12)

% plot fault mesh
for i=1:numel(CON(:,1))
    plot3(XYZsfSE([CON(i,:) CON(i,1)],1),XYZsfSE([CON(i,:) CON(i,1)],2),XYZsfSE([CON(i,:) CON(i,1)],3),'k-')
end
for i=1:numel(CON_ul(:,1))
    plot3(XYZsfSE_ul([CON_ul(i,:) CON_ul(i,1)],1),XYZsfSE_ul([CON_ul(i,:) CON_ul(i,1)],2),XYZsfSE_ul([CON_ul(i,:) CON_ul(i,1)],3),'r-')
    hold on
end
for i=1:numel(CON_ll(:,1))
    plot3(XYZsfSE_ll([CON_ll(i,:) CON_ll(i,1)],1),XYZsfSE_ll([CON_ll(i,:) CON_ll(i,1)],2),XYZsfSE_ll([CON_ll(i,:) CON_ll(i,1)],3),'r-')
    hold on
end

% correct polarity of triangulation
[tnsfSE,nvecsfSE] = PlotTriNormals(CON,XYZsfSE,convention);
[tnsfSE_ul,nvecsfSE_ul] = PlotTriNormals(CON_ul,XYZsfSE_ul,convention);
[tnsfSE_ll,nvecsfSE_ll] = PlotTriNormals(CON_ll,XYZsfSE_ll,convention);

% Translate back to UTM
XYZsfSE(:,1) = XYZsfSE(:,1) + xo;
XYZsfSE(:,2) = XYZsfSE(:,2) + yo;
XYZsfSE_ul(:,1) = XYZsfSE_ul(:,1) + xo;
XYZsfSE_ul(:,2) = XYZsfSE_ul(:,2) + yo;
XYZsfSE_ll(:,1) = XYZsfSE_ll(:,1) + xo;
XYZsfSE_ll(:,2) = XYZsfSE_ll(:,2) + yo;