% WRV_Plot_3D_WR_West_sensitivity.m
%
% AUTHOR:           Michael W. Swyer
% DATE CREATED:     2015/08/28
% DATE MODIFIED:    
% VERSION:          v.1
%
% PURPOSE:  To construct upper/lower residual 3D fault geometry of Gate Creek
% Fault at Wind River Valley
%
% PURPOSE OF MODIFICATION:
% 
% INPUT: Surface points from mapped fault trace:
%       WR_West_surfacepoints.csv
%
% OUTPUT: Position of fault nodes in UTM Zone 10N meters (XYZ-),
% triangulation of fault nodes (tn-), and unit normal vectors of fault element
% triangles (nvec-).
%
% NOTE:
%
% KEY functions written specifically for this modeling:
%
% Other related functions:
%       deg2utm.m
%       fitNormal.m
%       Delaunay2_5D.m
%       PlotTriNormals.m

clear all;close all

show_graph = 1;% Show graph of fit normal (0=no 1=yes)
f = 1;% smoothing factor (0 to 1)
convention = 'z-';% PlotTriNormals vector direction
%% wind river west fault %%

% local origin
xo = 5.86e5;
yo = 5.069e6;

% import data
data = importdata('WR_West_surfacepoints.csv',',');
lat = data.data(:,2);
long = data.data(:,1);
[x,y,utmzone] = deg2utm(lat,long);
x = x - xo;
y = y - yo;
z = zeros(numel(x),1);

% fit normal vector
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = x;c(:,2) = y;c(:,3) = z;
    n = fitNormal(c, show_graph);
end

% rotate to j=0
theta = atan((max(x)-min(x))/(max(y)-min(y)));
Rcw = [cos(theta) sin(theta);-sin(theta) cos(theta)];
dx = 0;
dy = 1000;
for i=1:numel(x)
    b = Rcw*[x(i);y(i)];
    x(i) = b(1)+dx;y(i) = b(2)+dy;
end

% fit normal vector
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = x;c(:,2) = y;c(:,3) = z;
    n = fitNormal(c, show_graph);
end

% row 2
x = [x;x(1);x(1);x;x(numel(x));x(numel(x))];
y = [y;y(1)-600;y(1)-300;y;y(numel(y))+300;y(numel(y))+600];
z = [z;ones(numel(z)+4,1)*-300];
% row 3
x = [x;x(1);x(8:18);x(numel(x))];
y = [y;y(1)-900;y(8:18);y(numel(y))+300];
z = [z;ones(13,1)*-600];
% row 4
x = [x;x(19:31)];
y = [y;y(19:31)];
z = [z;ones(13,1)*-900];
% row 5
x = [x;x(33:43)];
y = [y;y(33:43)];
z = [z;ones(11,1)*-1200];
% row 6
x = [x;x(47:53)];
y = [y;y(47:53)];
z = [z;ones(7,1)*-1500];

% fit normal vector
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = x;c(:,2) = y;c(:,3) = z;
    n = fitNormal(c, show_graph);
end

% rotate about y-axis for dip
xs = min(x);
x = x - xs;
Rcw = [cos(25*(pi/180)) sin(25*(pi/180));-sin(25*(pi/180)) cos(25*(pi/180))];
Rcw_ul = [cos(35*(pi/180)) sin(35*(pi/180));-sin(35*(pi/180)) cos(35*(pi/180))];
Rcw_ll = [cos(15*(pi/180)) sin(15*(pi/180));-sin(15*(pi/180)) cos(15*(pi/180))];
for i=1:numel(x)
    b = Rcw*[x(i);z(i)];
    b_ul = Rcw_ul*[x(i);z(i)];
    b_ll = Rcw_ll*[x(i);z(i)];
    x(i) = b(1);z(i) = b(2);
    x_ul(i) = b_ul(1);z_ul(i) = b_ul(2);
    x_ll(i) = b_ll(1);z_ll(i) = b_ll(2);
end
x = x + xs;
x_ul = x_ul + xs;
x_ll = x_ll + xs;

% put xyz points for fault nodes into 3 column matrix
XYZwrwf(:,1) = x;XYZwrwf(:,2) = y;XYZwrwf(:,3) = z;
XYZwrwf_ul(:,1) = x_ul;XYZwrwf_ul(:,2) = y;XYZwrwf_ul(:,3) = z_ul;
XYZwrwf_ll(:,1) = x_ll;XYZwrwf_ll(:,2) = y;XYZwrwf_ll(:,3) = z_ll;
for i=1:numel(XYZwrwf(:,3))
    if XYZwrwf(i,3)==0
        XYZwrwf(i,3)=-1;
    end
    if XYZwrwf_ul(i,3)==0
        XYZwrwf_ul(i,3)=-1;
    end
    if XYZwrwf_ll(i,3)==0
        XYZwrwf_ll(i,3)=-1;
    end
end

% triangulate fault nodes
CON=Delaunay2_5D(XYZwrwf);
CON_ul=Delaunay2_5D(XYZwrwf_ul);
CON_ll=Delaunay2_5D(XYZwrwf_ll);

% Rotate back
Rccw = [cos(theta) -sin(theta);sin(theta) cos(theta)];
for i=1:numel(XYZwrwf(:,1))
    b = Rccw*[XYZwrwf(i,1)-dx;XYZwrwf(i,2)-dy];
    XYZwrwf(i,1) = b(1);XYZwrwf(i,2) = b(2);
    b = Rccw*[XYZwrwf_ul(i,1)-dx;XYZwrwf_ul(i,2)-dy];
    XYZwrwf_ul(i,1) = b(1);XYZwrwf_ul(i,2) = b(2);
    b = Rccw*[XYZwrwf_ll(i,1)-dx;XYZwrwf_ll(i,2)-dy];
    XYZwrwf_ll(i,1) = b(1);XYZwrwf_ll(i,2) = b(2);
end

% plot fault nodes
figure
plot3(XYZwrwf(:,1),XYZwrwf(:,2),XYZwrwf(:,3),'ko');
hold on
plot3(XYZwrwf_ul(:,1),XYZwrwf_ul(:,2),XYZwrwf_ul(:,3),'ko');
plot3(XYZwrwf_ll(:,1),XYZwrwf_ll(:,2),XYZwrwf_ll(:,3),'ko');
xlabel('E-W(m)','fontsize',12)
ylabel('N-S(m)','fontsize',12)
axis equal;grid on
title('WR West Fault','fontsize',12)

% plot fault mesh
for i=1:numel(CON(:,1))
    plot3(XYZwrwf([CON(i,:) CON(i,1)],1),XYZwrwf([CON(i,:) CON(i,1)],2),XYZwrwf([CON(i,:) CON(i,1)],3),'k-')
end
for i=1:numel(CON_ul(:,1))
    plot3(XYZwrwf_ul([CON_ul(i,:) CON_ul(i,1)],1),XYZwrwf_ul([CON_ul(i,:) CON_ul(i,1)],2),XYZwrwf_ul([CON_ul(i,:) CON_ul(i,1)],3),'r-')
end
for i=1:numel(CON_ll(:,1))
    plot3(XYZwrwf_ll([CON_ll(i,:) CON_ll(i,1)],1),XYZwrwf_ll([CON_ll(i,:) CON_ll(i,1)],2),XYZwrwf_ll([CON_ll(i,:) CON_ll(i,1)],3),'r-')
end

% correct polarity of triangulation
[tnwrwf,nvecwrwf] = PlotTriNormals(CON,XYZwrwf,convention);
[tnwrwf_ul,nvecwrwf_ul] = PlotTriNormals(CON_ul,XYZwrwf_ul,convention);
[tnwrwf_ll,nvecwrwf_ll] = PlotTriNormals(CON_ll,XYZwrwf_ll,convention);

% Translate back to UTM
XYZwrwf(:,1) = XYZwrwf(:,1) + xo;
XYZwrwf(:,2) = XYZwrwf(:,2) + yo;
XYZwrwf_ul(:,1) = XYZwrwf_ul(:,1) + xo;
XYZwrwf_ul(:,2) = XYZwrwf_ul(:,2) + yo;
XYZwrwf_ll(:,1) = XYZwrwf_ll(:,1) + xo;
XYZwrwf_ll(:,2) = XYZwrwf_ll(:,2) + yo;