% WRV_Plot_EQ_3D_BigButte_sensitivity.m
%
% AUTHOR:           Michael W. Swyer
% DATE CREATED:     2015/08/28
% DATE MODIFIED:    
% VERSION:          v.1
%
% PURPOSE:  To construct upper/lower residual 3D fault geometry of
% Big Butte Fault at Wind River Valley
%
% PURPOSE OF MODIFICATION:
% 
% INPUT: Seismic catalogs selected from Pacific Northwest Seismic Network:
%           1) FOCAL_MECHS_Big_Butte_Fault.csv
%           2) relocated_earthquakes_Big_Butte_Fault.csv
%           3) pnsn_earthquakes_not_relocated_Big_Butte_Fault.csv
%
% OUTPUT: Position of fault nodes in UTM Zone 10N meters (XYZ-),
% triangulation of fault nodes (tn-), and unit normal vectors of fault element
% triangles (nvec-).
%
% NOTE:
%
% KEY functions written specifically for this modeling:
%
% Other related functions:
%       deg2utm.m
%       fitNormal.m
%       lowess.m
%       smooth.m
%       R3RSR.m
%       R3R.m
%       SR.m
%       H.m
%       Delaunay2_5D.m
%       PlotTriNormals.m

clear all;close all

show_graph = 0;% Show graph of fit normal (0=no 1=yes)
f = 1;% smoothing factor (0 to 1)
wantplot = 1;% zero = no plot
imagefile = '\lowess.png';% directory where lowess plot is stored(not used if wantplot = 0)
convention = 'z-';% PlotTriNormals vector direction
%% big butte fault %%

% local origin
xo_BBF = 568500;
yo_BBF = 5082000;

% import data
% Focal Mechanisms
data_BBF_FM = importdata('FOCAL_MECHS_Big_Butte_Fault.csv');
for i=2:numel(data_BBF_FM)
    d = strsplit(data_BBF_FM{i},',');
    lat_BBF_FM(i-1,1) = str2num(d{4});
    long_BBF_FM(i-1,1) = str2num(d{5});
    z_BBF_FM(i-1,1) = (-str2num(d{7})*1000)-(rand*(10^-7));
    m_BBF_FM(i-1,1) = str2num(d{6});
    strikeA_BBF_FM(i-1,1) = str2num(d{8});
    dipA_BBF_FM(i-1,1) = str2num(d{9});
    rakeA_BBF_FM(i-1,1) = str2num(d{10});
    strikeB_BBF_FM(i-1,1) = str2num(d{11});
    if strikeB_BBF_FM(i-1,1)<200
        strikeB_BBF_FM(i-1,1) = strikeB_BBF_FM(i-1,1)+180;
    end
    dipB_BBF_FM(i-1,1) = str2num(d{12});
    rakeB_BBF_FM(i-1,1) = str2num(d{13});
end
strike_BBF = mean(strikeB_BBF_FM);
dip_BBF = mean(dipB_BBF_FM);
S_BBF_FM = 3.^m_BBF_FM;
[x_BBF_FM,y_BBF_FM,utmzone] = deg2utm(lat_BBF_FM,long_BBF_FM);
x_BBF_FM = x_BBF_FM - xo_BBF;
y_BBF_FM = y_BBF_FM - yo_BBF;

% Relocations
data_BBF_RL = importdata('relocated_earthquakes_Big_Butte_Fault.csv');
for i=2:numel(data_BBF_RL.textdata(:,1))
    lat_BBF_RL(i-1,1) = str2num(data_BBF_RL.textdata{i,6});
    long_BBF_RL(i-1,1) = str2num(data_BBF_RL.textdata{i,7});
    z_BBF_RL(i-1,1) = (-str2num(data_BBF_RL.textdata{i,4})*1000)-(rand*(10^-7));
    m_BBF_RL(i-1,1) = str2num(data_BBF_RL.textdata{i,5});
end
S_BBF_RL = 3.^m_BBF_RL;
[x_BBF_RL,y_BBF_RL,utmzone] = deg2utm(lat_BBF_RL,long_BBF_RL);
x_BBF_RL = x_BBF_RL - xo_BBF;
y_BBF_RL = y_BBF_RL - yo_BBF;

% Non-Relcoations
data_BBF_NRL = importdata('pnsn_earthquakes_not_relocated_Big_Butte_Fault.csv');
for i=2:numel(data_BBF_NRL.textdata(:,1))
    lat_BBF_NRL(i-1,1) = str2num(data_BBF_NRL.textdata{i,6});
    long_BBF_NRL(i-1,1) = str2num(data_BBF_NRL.textdata{i,7});
    z_BBF_NRL(i-1,1) = (-str2num(data_BBF_NRL.textdata{i,4})*1000)-(rand*(10^-7));
    m_BBF_NRL(i-1,1) = str2num(data_BBF_NRL.textdata{i,5});
end
S_BBF_NRL = 3.^m_BBF_NRL;
[x_BBF_NRL,y_BBF_NRL,utmzone] = deg2utm(lat_BBF_NRL,long_BBF_NRL);
x_BBF_NRL = x_BBF_NRL - xo_BBF;
y_BBF_NRL = y_BBF_NRL - yo_BBF;

% fit normal vector
x_BBF = [x_BBF_FM;x_BBF_RL;x_BBF_NRL];
y_BBF = [y_BBF_FM;y_BBF_RL;y_BBF_NRL];
z_BBF = [z_BBF_FM;z_BBF_RL;z_BBF_NRL];
if show_graph==1
    figure
end
clear c;clear n
c(:,1) = x_BBF;c(:,2) = y_BBF;c(:,3) = z_BBF;
n = fitNormal(c, show_graph);

% rotate to j=0
theta_BBF = atan(n(2)/n(1));
Rcw = [cos(theta_BBF) sin(theta_BBF);-sin(theta_BBF) cos(theta_BBF)];
for i=1:numel(x_BBF)
    b = Rcw*[x_BBF(i);y_BBF(i)];
    x_BBF(i) = b(1)-7000;y_BBF(i) = b(2)+7000;
end
if show_graph==1
    clear c;clear n
    c(:,1) = x_BBF;c(:,2) = y_BBF;c(:,3) = z_BBF;
    figure
    n = fitNormal(c, show_graph);
end
for i=1:numel(x_BBF_FM)
    b = Rcw*[x_BBF_FM(i);y_BBF_FM(i)];
    x_BBF_FM(i) = b(1)-7000;y_BBF_FM(i) = b(2)+7000;
end
for i=1:numel(x_BBF_RL)
    b = Rcw*[x_BBF_RL(i);y_BBF_RL(i)];
    x_BBF_RL(i) = b(1)-7000;y_BBF_RL(i) = b(2)+7000;
end
for i=1:numel(x_BBF_NRL)
    b = Rcw*[x_BBF_NRL(i);y_BBF_NRL(i)];
    x_BBF_NRL(i) = b(1)-7000;y_BBF_NRL(i) = b(2)+7000;
end

% rotate about y-axis
z_BBF_FM = z_BBF_FM + 7500;x_BBF_FM = x_BBF_FM - 3000;
z_BBF_RL = z_BBF_RL + 7500;x_BBF_RL = x_BBF_RL - 3000;
z_BBF_NRL = z_BBF_NRL + 7500;x_BBF_NRL = x_BBF_NRL - 3000;
Rccw = [cos(3*(pi/180)) -sin(3*(pi/180));sin(3*(pi/180)) cos(3*(pi/180))];
for i=1:numel(x_BBF_FM)
    b = Rccw*[x_BBF_FM(i);z_BBF_FM(i)];
    x_BBF_FM(i) = b(1);z_BBF_FM(i) = b(2);
end
for i=1:numel(x_BBF_RL)
    b = Rccw*[x_BBF_RL(i);z_BBF_RL(i)];
    x_BBF_RL(i) = b(1);z_BBF_RL(i) = b(2);
end
for i=1:numel(x_BBF_NRL)
    b = Rccw*[x_BBF_NRL(i);z_BBF_NRL(i)];
    x_BBF_NRL(i) = b(1);z_BBF_NRL(i) = b(2);
end
z_BBF_FM = z_BBF_FM - 7500;x_BBF_FM = x_BBF_FM + 3000;
z_BBF_RL = z_BBF_RL - 7500;x_BBF_RL = x_BBF_RL + 3000;
z_BBF_NRL = z_BBF_NRL - 7500;x_BBF_NRL = x_BBF_NRL + 3000;

% plot EQs
figure
h1 = scatter3(x_BBF_FM,y_BBF_FM,z_BBF_FM,S_BBF_FM,'g');
hold on
h2 = scatter3(x_BBF_RL,y_BBF_RL,z_BBF_RL,S_BBF_RL,'r');
h3 = scatter3(x_BBF_NRL,y_BBF_NRL,z_BBF_NRL,S_BBF_NRL,'k');
legend([h1 h2 h3],'Focal Mechanisms','Relocations','Non-Relocations');
axis equal;grid on;
xlim([0 5000])
ylim([0 20000])
zlim([-13000 -2000])
xlabel('E-W(m)','fontsize',12)
ylabel('N-S(m)','fontsize',12)
zlabel('depth(m)','fontsize',12)
title('Big Butte Fault','fontsize',14)

% depth slices for node locations
depths_BBF = [-13000:300:-2800];
depths_BBF = depths_BBF';
depths2 = [-13000:600:-4600];
depths2 = depths2';
depths2 = [depths2;depths_BBF(30:35)];
depths3 = [-13000:1200:-2200];depths3 = depths3';
% northing coordinates for cross-sections/node locations
norths_BBF = [760:300:17560];% 300m spacing
norths_BBF = norths_BBF';
norths2 = [4960:1200:17560];
norths2 = norths2';
norths2 = [norths_BBF(1:15);norths2];
qf=60;% window front
qb=60;% window back

% cross sections
for i=1:numel(norths2)
        J = find(y_BBF_RL>(norths2(i)-300*qb)&y_BBF_RL<=(norths2(i)+300*qf));
        X_BBF{i}.RL = x_BBF_RL(J);
        X_BBF{i}.north = norths2(i);
        Y_BBF{i}.RL = y_BBF_RL(J);
        Y_BBF{i}.north = norths2(i);
        Z_BBF{i}.RL = z_BBF_RL(J);
        Z_BBF{i}.north = norths2(i);
end

% regression
Xbbf=[];Xbbf_ul=[];Xbbf_ll=[];
Ybbf=[];Ybbf_ul=[];Ybbf_ll=[];
Zbbf=[];Zbbf_ul=[];Zbbf_ll=[];

for i=1:numel(X_BBF)
    clear datain
    clear datains
    clear dataind
    clear xy
    clear xys
    clear xyd
    clear xdata
        % relocations
        datain(:,1) = [Z_BBF{i}.RL];
        datain(:,2) = [X_BBF{i}.RL];
        if X_BBF{1,i}.north<=4960
            xdata = depths2;
        if mod((X_BBF{1,i}.north-160)/300,2)==0
            I = find(xdata>=-4600);
            xdata = xdata(I);
        end
        else
            xdata = depths3;
        end
        
        % regression on cross section using Lowess function
        [dataout lowerLimit upperLimit xy] = lowess(datain,f,wantplot,imagefile,xdata);
        
        % vertical extent of fault
        if X_BBF{1,i}.north==760
                I = find(xdata>=-7600&xdata<=-6100);
        elseif X_BBF{1,i}.north==1060
                I = find(xdata>=-8200&xdata<=-5800);
        elseif X_BBF{1,i}.north==1360
                I = find(xdata>=-8500&xdata<=-5500);
        elseif X_BBF{1,i}.north==1660
                I = find(xdata>=-9100&xdata<=-4900);
        elseif X_BBF{1,i}.north==1960
                I = find(xdata>=-9400&xdata<=-4600);
        elseif X_BBF{1,i}.north==2260
                I = find(xdata>=-9700&xdata<=-4300);
        elseif X_BBF{1,i}.north==2560
                I = find(xdata>=-10000&xdata<=-4000);
        elseif X_BBF{1,i}.north==2860
                I = find(xdata>=-10300&xdata<=-4000);
        elseif X_BBF{1,i}.north==3160
                I = find(xdata>=-10300&xdata<=-4000);
        elseif X_BBF{1,i}.north==3460
                I = find(xdata>=-10600&xdata<=-3700);
        elseif X_BBF{1,i}.north==3760
                I = find(xdata>=-10600&xdata<=-3700);
        elseif X_BBF{1,i}.north==4060
                I = find(xdata>=-10900&xdata<=-3700);
        elseif X_BBF{1,i}.north==4360
                I = find(xdata>=-10900&xdata<=-3700);
        elseif X_BBF{1,i}.north==4660
                I = find(xdata>=-11200&xdata<=-3700);
        elseif X_BBF{1,i}.north==4960
                I = find(xdata>=-11200&xdata<=-3700);
        elseif X_BBF{1,i}.north==5260
                I = find(xdata>=-11200&xdata<=-3400);
        elseif X_BBF{1,i}.north==5560
                I = find(xdata>=-11500&xdata<=-3400);
        elseif X_BBF{1,i}.north==5860
                I = find(xdata>=-11500&xdata<=-3400);
        elseif X_BBF{1,i}.north==6160
                I = find(xdata>=-11500&xdata<=-3400);
        elseif X_BBF{1,i}.north==6460
                I = find(xdata>=-11500&xdata<=-3100);
        elseif X_BBF{1,i}.north==6760
                I = find(xdata>=-11500&xdata<=-3100);
        elseif X_BBF{1,i}.north==7060
                I = find(xdata>=-11500&xdata<=-3100);
        elseif X_BBF{1,i}.north==7360
                I = find(xdata>=-11500&xdata<=-3100);
        elseif X_BBF{1,i}.north==7660
                I = find(xdata>=-11500&xdata<=-3100);
        elseif X_BBF{1,i}.north==7960
                I = find(xdata>=-11500&xdata<=-3100);
        elseif X_BBF{1,i}.north==8260
                I = find(xdata>=-11500&xdata<=-3100);
        elseif X_BBF{1,i}.north==8560
                I = find(xdata>=-11500&xdata<=-3100);
        elseif X_BBF{1,i}.north==8860
                I = find(xdata>=-11500&xdata<=-3100);
        elseif X_BBF{1,i}.north==17560
                I = find(xdata>=-9100&xdata<=-6100);
        elseif X_BBF{1,i}.north==17260
                I = find(xdata>=-9100&xdata<=-5500);
        elseif X_BBF{1,i}.north==16960
                I = find(xdata>=-9700&xdata<=-5200);
        elseif X_BBF{1,i}.north==16660
                I = find(xdata>=-10000&xdata<=-4900);
        elseif X_BBF{1,i}.north==16360
                I = find(xdata>=-10300&xdata<=-4300);
        elseif X_BBF{1,i}.north==16060
                I = find(xdata>=-10600&xdata<=-4000);
        elseif X_BBF{1,i}.north==15760
                I = find(xdata>=-10900&xdata<=-3700);
        elseif X_BBF{1,i}.north==15460
                I = find(xdata>=-10900&xdata<=-3700);
        elseif X_BBF{1,i}.north==15160
                I = find(xdata>=-11200&xdata<=-3400);
        elseif X_BBF{1,i}.north==14860
                I = find(xdata>=-11200&xdata<=-3400);
        else
                I = find(xdata>=min(datain(:,1))&xdata<=max(datain(:,1)));
        end

        % store xyz points for fault nodes              
        Xbbf(numel(Xbbf)+1:numel(Xbbf)+numel(I),1) = xy(I,2);
        Ybbf(numel(Ybbf)+1:numel(Ybbf)+numel(I),1) = Y_BBF{i}.north;
        Zbbf(numel(Zbbf)+1:numel(Zbbf)+numel(I),1) = xy(I,1);
        
        Xbbf_ul(numel(Xbbf_ul)+1:numel(Xbbf_ul)+numel(I),1) = xy(I,3);
        Ybbf_ul(numel(Ybbf_ul)+1:numel(Ybbf_ul)+numel(I),1) = Y_BBF{i}.north;
        Zbbf_ul(numel(Zbbf_ul)+1:numel(Zbbf_ul)+numel(I),1) = xy(I,1);
        
        Xbbf_ll(numel(Xbbf_ll)+1:numel(Xbbf_ll)+numel(I),1) = xy(I,4);
        Ybbf_ll(numel(Ybbf_ll)+1:numel(Ybbf_ll)+numel(I),1) = Y_BBF{i}.north;
        Zbbf_ll(numel(Zbbf_ll)+1:numel(Zbbf_ll)+numel(I),1) = xy(I,1);
end

% put fault nodes in 3 column matrix
XYZbbf(:,1) = Xbbf;XYZbbf(:,2) = Ybbf;XYZbbf(:,3) = Zbbf;
XYZbbf_ul(:,1) = Xbbf_ul;XYZbbf_ul(:,2) = Ybbf_ul;XYZbbf_ul(:,3) = Zbbf_ul;
XYZbbf_ll(:,1) = Xbbf_ll;XYZbbf_ll(:,2) = Ybbf_ll;XYZbbf_ll(:,3) = Zbbf_ll;

% triangulate fault nodes
CONbbf=Delaunay2_5D(XYZbbf);
CONbbf_ul=Delaunay2_5D(XYZbbf_ul);
CONbbf_ll=Delaunay2_5D(XYZbbf_ll);

% plot fault mesh
figure
for i=1:numel(CONbbf(:,1))
    plot3(XYZbbf([CONbbf(i,:) CONbbf(i,1)],1),XYZbbf([CONbbf(i,:) CONbbf(i,1)],2),XYZbbf([CONbbf(i,:) CONbbf(i,1)],3),'k-')
    hold on
end
for i=1:numel(CONbbf_ul(:,1))
    plot3(XYZbbf_ul([CONbbf_ul(i,:) CONbbf_ul(i,1)],1),XYZbbf_ul([CONbbf_ul(i,:) CONbbf_ul(i,1)],2),XYZbbf_ul([CONbbf_ul(i,:) CONbbf_ul(i,1)],3),'r-')
end
for i=1:numel(CONbbf_ll(:,1))
    plot3(XYZbbf_ll([CONbbf_ll(i,:) CONbbf_ll(i,1)],1),XYZbbf_ll([CONbbf_ll(i,:) CONbbf_ll(i,1)],2),XYZbbf_ll([CONbbf_ll(i,:) CONbbf_ll(i,1)],3),'r-')
end
axis equal;grid on;
xlim([0 5000])
ylim([0 20000])
zlim([-13000 -2000])
xlabel('E-W(m)','fontsize',12)
ylabel('N-S(m)','fontsize',12)
zlabel('depth(m)','fontsize',12)
title('Big Butte Fault','fontsize',14)

% Rotate back
Rccw = [cos(theta_BBF) -sin(theta_BBF);sin(theta_BBF) cos(theta_BBF)];
for i=1:numel(Xbbf)
    b = Rccw*[XYZbbf(i,1)+7000;XYZbbf(i,2)-7000];
    XYZbbf(i,1) = b(1);XYZbbf(i,2) = b(2);
    b = Rccw*[XYZbbf_ul(i,1)+7000;XYZbbf_ul(i,2)-7000];
    XYZbbf_ul(i,1) = b(1);XYZbbf_ul(i,2) = b(2);
    b = Rccw*[XYZbbf_ll(i,1)+7000;XYZbbf_ll(i,2)-7000];
    XYZbbf_ll(i,1) = b(1);XYZbbf_ll(i,2) = b(2);
end

% correct polarity of triangulation
[tnbbf,nvecbbf] = PlotTriNormals(CONbbf,XYZbbf,convention);
[tnbbf_ul,nvecbbf_ul] = PlotTriNormals(CONbbf_ul,XYZbbf_ul,convention);
[tnbbf_ll,nvecbbf_ll] = PlotTriNormals(CONbbf_ll,XYZbbf_ll,convention);

% correct polarity of upper residual fault
I = find(nvecbbf_ul(:,1)>0);
for i=1:numel(I)
    a = tnbbf_ul(I(i),1);
    c = tnbbf_ul(I(i),3);
    tnbbf_ul(I(i),1) = c;
    tnbbf_ul(I(i),3) = a;
    nvecbbf_ul(I(i),:) = -nvecbbf_ul(I(i),:);
end

% correct polarity of lower residual fault
I = find(nvecbbf_ll(:,1)>0);
for i=1:numel(I)
    a = tnbbf_ll(I(i),1);
    c = tnbbf_ll(I(i),3);
    tnbbf_ll(I(i),1) = c;
    tnbbf_ll(I(i),3) = a;
    nvecbbf_ll(I(i),:) = -nvecbbf_ll(I(i),:);
end

% Check Polarity
[d1,d2] = PlotTriNormals(tnbbf_ul,XYZbbf_ul,convention);
[d1,d2] = PlotTriNormals(tnbbf_ll,XYZbbf_ll,convention);

% Translate back to global coordinates
XYZbbf(:,1) = XYZbbf(:,1) + xo_BBF;
XYZbbf(:,2) = XYZbbf(:,2) + yo_BBF;
XYZbbf_ul(:,1) = XYZbbf_ul(:,1) + xo_BBF;
XYZbbf_ul(:,2) = XYZbbf_ul(:,2) + yo_BBF;
XYZbbf_ll(:,1) = XYZbbf_ll(:,1) + xo_BBF;
XYZbbf_ll(:,2) = XYZbbf_ll(:,2) + yo_BBF;