% WRV_Plot_EQ_3D_GateCreek.m
%
% AUTHOR:           Michael W. Swyer
% DATE CREATED:     2015/05/26
% DATE MODIFIED:    
% VERSION:          v.1
%
% PURPOSE:  To construct 3D fault geometry of Gate Creek Fault at Wind River
% Valley
%
% PURPOSE OF MODIFICATION:
% 
% INPUT: Seismic catalogs selected from Pacific Northwest Seismic Network:
%           1) FOCAL_MECHS_Gate_Creek_Fault.csv
%           2) pnsn_earthquakes_not_relocated_Gate_Creek_Fault.csv
%        Surface points from mapped fault trace
%           3) Gate_Creek_Fault_surfacepoints.csv
%
% OUTPUT: Position of fault nodes in UTM Zone 10N meters (XYZ-),
% triangulation of fault nodes (tn-), and unit normal vectors of fault element
% triangles (nvec-).
%
% NOTE:
%
% KEY functions written specifically for this modeling:
%
% Other related functions:
%       deg2utm.m
%       fitNormal.m
%       lowess.m
%       smooth.m
%       R3RSR.m
%       R3R.m
%       SR.m
%       H.m
%       Delaunay2_5D.m
%       PlotTriNormals.m

clear all;close all

show_graph = 0;% Show graph of fit normal (0=no 1=yes)
f = 1;% smoothing factor (0 to 1)
wantplot = 0;% zero = no plot
imagefile = '\lowess.png';% directory where lowess plot is stored(not used if wantplot = 0)
convention = 'z-';% PlotTriNormals vector direction
%% gate creek fault %%

% local origin
xo = 5.96e5;
yo = 5.048e6;

% import data
% Focal Mechanisms
data_FM = importdata('FOCAL_MECH_Gate_Creek_Fault.csv');
for i=2:numel(data_FM.textdata(:,1))
    lat_FM(i-1,1) = str2num(data_FM.textdata{i,4});
    long_FM(i-1,1) = str2num(data_FM.textdata{i,5});
    z_FM(i-1,1) = (-str2num(data_FM.textdata{i,7})*1000);
    m_FM(i-1,1) = str2num(data_FM.textdata{i,6});
end
S_FM = 3.^m_FM;
[x_FM,y_FM,utmzone] = deg2utm(lat_FM,long_FM);
x_FM = x_FM - xo;
y_FM = y_FM - yo;

% Non-Relcoations
data_NRL = importdata('pnsn_earthquakes_not_relocated_Gate_Creek_Fault.csv');
for i=1:numel(data_NRL.data(:,1))
    lat_NRL(i,1) = data_NRL.data(i,3);
    long_NRL(i,1) = data_NRL.data(i,4);
    z_NRL(i,1) = (- data_NRL.data(i,1))*1000;
    m_NRL(i,1) = data_NRL.data(i,2);
end
S_NRL = 3.^m_NRL;
[x_NRL,y_NRL,utmzone] = deg2utm(lat_NRL,long_NRL);
x_NRL = x_NRL - xo;
y_NRL = y_NRL - yo;

% surface points
data_SP = importdata('Gate_Creek_Fault_surfacepoints.csv');
[x_SP,y_SP,utmzone] = deg2utm(data_SP.data(:,2),data_SP.data(:,1));
z_SP = data_SP.data(:,3)*.3048;
x_SP = x_SP - xo;
y_SP = y_SP - yo;

% fit normal vector
x = [x_FM;x_NRL;x_SP];
y = [y_FM;y_NRL;y_SP];
z = [z_FM;z_NRL;z_SP];
if show_graph==1
    figure
end
clear c;clear n
c(:,1) = x;c(:,2) = y;c(:,3) = z;
n = fitNormal(c, show_graph);

% rotate to j=0
theta = atan(n(2)/n(1));
Rcw = [cos(theta) sin(theta);-sin(theta) cos(theta)];
dx = -2000;
dy = 2000;
for i=1:numel(x)
    b = Rcw*[x(i);y(i)];
    x(i) = b(1)+dx;y(i) = b(2)+dy;
end
if show_graph==1
    clear c;clear n
    c(:,1) = x;c(:,2) = y;c(:,3) = z;
    figure
    n = fitNormal(c, show_graph);
end
for i=1:numel(x_FM)
    b = Rcw*[x_FM(i);y_FM(i)];
    x_FM(i) = b(1)+dx;y_FM(i) = b(2)+dy;
end
for i=1:numel(x_NRL)
    b = Rcw*[x_NRL(i);y_NRL(i)];
    x_NRL(i) = b(1)+dx;y_NRL(i) = b(2)+dy;
end
for i=1:numel(x_SP)
    b = Rcw*[x_SP(i);y_SP(i)];
    x_SP(i) = b(1)+dx;y_SP(i) = b(2)+dy;
end

% plot EQs
figure
h1 = scatter3(x_FM,y_FM,z_FM,S_FM,'g');
hold on
h3 = scatter3(x_NRL,y_NRL,z_NRL,S_NRL,'k');
h4 = plot3(x_SP,y_SP,z_SP,'kx');
x_sp = mean(x_SP);y_sp = mean(y_SP);z_sp = mean(z_SP);
legend([h1 h3 h4],'Focal Mechanisms','Non-Relocations','Surface Points');
axis equal;grid on;
xlim([0 7000])
ylim([0 13000])
zlim([-10000 1000])
xlabel('E-W(m)','fontsize',12)
ylabel('N-S(m)','fontsize',12)
zlabel('depth(m)','fontsize',12)
title('Gate Creek Fault','fontsize',14)

% depth slices for node locations
depths = [-9900:300:0];depths = depths';
depths2 = [-9900:1200:-5100];depths2 = depths2';
depths2 = [depths2;-4500];
depths2 = [depths2;depths(20:34,1)];
depths3 = [-9900:1200:0];depths3 = depths3';
% northing coordinates for cross-sections/node locations
norths = [0:300:12300];norths = norths';% 300m spacing
norths2 = [0:1200:7200];norths2 = [norths2';norths(27:42)];

qf=30;% window front
qb=40;% window back
% cross sections
for i=1:numel(norths2)
        I = find(y_NRL>(norths2(i)-300*qb)&y_NRL<=(norths2(i)+300*qf));
        K = find(y_FM>(norths2(i)-300*qb)&y_FM<=(norths2(i)+300*qf));
        L = find(y_SP>(norths2(i)-2100)&y_SP<=(norths2(i)+2100));
        figure
        scatter(x_NRL(I),z_NRL(I),S_NRL(I),'k');
        hold on
        scatter(x_FM(K),z_FM(K),S_FM(K),'g');
        plot(x_SP(L),z_SP(L),'kx');
        axis equal;grid on;
        xlim([0 7000])
        ylim([-10000 1000])
        xlabel('E-W(m)','fontsize',12)
        ylabel('depth(m)','fontsize',12)
        title(strcat(num2str(norths(i)),'m north'),'fontsize',12)
        X{i}.NRL = x_NRL(I);
        X{i}.FM = x_FM(K);
        X{i}.SP = x_SP(L);
        X{i}.SP(:,1) = mean(X{i}.SP(:,1));
        X{i}.north = norths2(i);
        Y{i}.NRL = y_NRL(I);
        Y{i}.FM = y_FM(K);
        Y{i}.SP = y_SP(L);
        Y{i}.north = norths2(i);
        Z{i}.NRL = z_NRL(I);
        Z{i}.FM = z_FM(K);
        Z{i}.SP = z_SP(L);
        Z{i}.north = norths2(i);
end

% regression
Xf=[];
Yf=[];
Zf=[];

for i=1:numel(X)
    clear datain
    clear datains
    clear dataind
    clear xy
    clear xys
    clear xyd
    clear xdata
    % non-relocations, focal mechanisms, and surface points
        datain(:,1) = [Z{i}.NRL;Z{i}.FM;Z{i}.SP];
        datain(:,2) = [X{i}.NRL;X{i}.FM;X{i}.SP];
        if X{1,i}.north<=7200
            xdata = depths3;
        else
            % coarser mesh to the south
            xdata = depths2;
            if mod(X{1,i}.north/600,2)~=0
                I = find(xdata>=-4500);
                xdata = xdata(I);
            end
        end
        
        % regression on cross section using Lowess function
        [dataout lowerLimit upperLimit xy] = lowess(datain,f,wantplot,imagefile,xdata);

        % depth extent of fault
    if X{1,i}.north<=3000
        I = find(xdata>=(0.0007*X{1,i}.north^2 - 4.3287*X{1,i}.north - 3083.9)&xdata<=max(datain(:,1)));
    elseif X{1,i}.north>=9300
        I = find(xdata>=(0.0007*(X{1,i}.north-9300)^2 - 0.1469*(X{1,i}.north-9300) - 9356.6)&xdata<=max(datain(:,1)));
    else
        I = find(xdata>=min(datain(:,1))&xdata<=max(datain(:,1)));
    end

        % plot regression on cross sections
        figure(i+1)
        plot(xy(I,2),xy(I,1),'k-');
        
        % store xyz points
        Xf(numel(Xf)+1:numel(Xf)+numel(I),1) = xy(I,2);
        Yf(numel(Yf)+1:numel(Yf)+numel(I),1) = Y{i}.north;
        Zf(numel(Zf)+1:numel(Zf)+numel(I),1) = xy(I,1);
end

% smooth fault in y-direction
C = unique(Zf);
for i=1:numel(C)
    I = find(Zf==C(i));
    [Xf(I),r]=smooth(Xf(I),1);
end

% put xyz points in 3 column matrix
XYZgcf(:,1) = Xf;XYZgcf(:,2) = Yf;XYZgcf(:,3) = Zf;
for i=1:numel(XYZgcf(:,3))
    if XYZgcf(i,3)==0
        XYZgcf(i,3)=-1;
    end
end

% triangulate fault nodes
CONgcf=Delaunay2_5D(XYZgcf);

% plot fault mesh
figure(1)
for i=1:numel(CONgcf(:,1))
    plot3(XYZgcf([CONgcf(i,:) CONgcf(i,1)],1),XYZgcf([CONgcf(i,:) CONgcf(i,1)],2),XYZgcf([CONgcf(i,:) CONgcf(i,1)],3),'b-')
end

% Rotate back
Rccw = [cos(theta) -sin(theta);sin(theta) cos(theta)];
for i=1:numel(Xf)
    b = Rccw*[XYZgcf(i,1)-dx;XYZgcf(i,2)-dy];
    XYZgcf(i,1) = b(1);XYZgcf(i,2) = b(2);
end

% correct polarity of fault triangulation
[tngcf,nvecgcf] = PlotTriNormals(CONgcf,XYZgcf,convention);\

% Translate back to global coordinates
XYZgcf(:,1) = XYZgcf(:,1) + xo;
XYZgcf(:,2) = XYZgcf(:,2) + yo;