% WRV_Plot_EQ_3D_GateCreek_sensitivity.m
%
% AUTHOR:           Michael W. Swyer
% DATE CREATED:     2015/08/24
% DATE MODIFIED:    
% VERSION:          v.1
%
% PURPOSE:  To construct upper/lower residual 3D fault geometry of Gate Creek
% Fault at Wind River Valley
%
% PURPOSE OF MODIFICATION:
% 
% INPUT: Seismic catalogs selected from Pacific Northwest Seismic Network:
%           1) FOCAL_MECHS_Gate_Creek_Fault.csv
%           2) pnsn_earthquakes_not_relocated_Gate_Creek_Fault.csv
%        Surface points from mapped fault trace
%           3) Gate_Creek_Fault_surfacepoints.csv
%
% OUTPUT: Position of fault nodes in UTM Zone 10N meters (XYZ-),
% triangulation of fault nodes (tn-), and unit normal vectors of fault element
% triangles (nvec-).
%
% NOTE:
%
% KEY functions written specifically for this modeling:
%
% Other related functions:
%       deg2utm.m
%       fitNormal.m
%       lowess.m
%       smooth.m
%       R3RSR.m
%       R3R.m
%       SR.m
%       H.m
%       Delaunay2_5D.m
%       PlotTriNormals.m

clear all;close all

show_graph = 0;% Show graph of fit normal (0=no 1=yes)
f = 1;% smoothing factor (0 to 1)
wantplot = 1;% zero = no plot
imagefile = '\lowess.png';% directory where lowess plot is stored(not used if wantplot = 0)
convention = 'z-';% PlotTriNormals vector direction
%% gate creek fault %%

% local origin
xo = 5.96e5;
yo = 5.048e6;

% import data
% Focal Mechanisms
data_FM = importdata('FOCAL_MECH_Gate_Creek_Fault.csv');
for i=2:numel(data_FM.textdata(:,1))
    lat_FM(i-1,1) = str2num(data_FM.textdata{i,4});
    long_FM(i-1,1) = str2num(data_FM.textdata{i,5});
    z_FM(i-1,1) = (-str2num(data_FM.textdata{i,7})*1000);
    m_FM(i-1,1) = str2num(data_FM.textdata{i,6});
end
S_FM = 3.^m_FM;
[x_FM,y_FM,utmzone] = deg2utm(lat_FM,long_FM);
x_FM = x_FM - xo;
y_FM = y_FM - yo;

% Non-Relcoations
data_NRL = importdata('pnsn_earthquakes_not_relocated_Gate_Creek_Fault.csv');
for i=1:numel(data_NRL.data(:,1))
    lat_NRL(i,1) = data_NRL.data(i,3);
    long_NRL(i,1) = data_NRL.data(i,4);
    z_NRL(i,1) = (- data_NRL.data(i,1))*1000;
    m_NRL(i,1) = data_NRL.data(i,2);
end
S_NRL = 3.^m_NRL;
[x_NRL,y_NRL,utmzone] = deg2utm(lat_NRL,long_NRL);
x_NRL = x_NRL - xo;
y_NRL = y_NRL - yo;

% surface points
data_SP = importdata('Gate_Creek_Fault_surfacepoints.csv');
[x_SP,y_SP,utmzone] = deg2utm(data_SP.data(:,2),data_SP.data(:,1));
z_SP = data_SP.data(:,3)*.3048;
x_SP = x_SP - xo;
y_SP = y_SP - yo;

% fit normal vector
x = [x_FM;x_NRL;x_SP];
y = [y_FM;y_NRL;y_SP];
z = [z_FM;z_NRL;z_SP];
if show_graph==1
    figure
end
clear c;clear n
c(:,1) = x;c(:,2) = y;c(:,3) = z;
n = fitNormal(c, show_graph);

% rotate to j=0
theta = atan(n(2)/n(1));
Rcw = [cos(theta) sin(theta);-sin(theta) cos(theta)];
dx = -2000;
dy = 2000;
for i=1:numel(x)
    b = Rcw*[x(i);y(i)];
    x(i) = b(1)+dx;y(i) = b(2)+dy;
end
if show_graph==1
    clear c;clear n
    c(:,1) = x;c(:,2) = y;c(:,3) = z;
    figure
    n = fitNormal(c, show_graph);
end
for i=1:numel(x_FM)
    b = Rcw*[x_FM(i);y_FM(i)];
    x_FM(i) = b(1)+dx;y_FM(i) = b(2)+dy;
end
for i=1:numel(x_NRL)
    b = Rcw*[x_NRL(i);y_NRL(i)];
    x_NRL(i) = b(1)+dx;y_NRL(i) = b(2)+dy;
end
for i=1:numel(x_SP)
    b = Rcw*[x_SP(i);y_SP(i)];
    x_SP(i) = b(1)+dx;y_SP(i) = b(2)+dy;
end

% plot EQs
figure
h1 = scatter3(x_FM,y_FM,z_FM,S_FM,'g');
hold on
% h2 = scatter3(x_RL,y_RL,z_RL,S_RL,'r');
h3 = scatter3(x_NRL,y_NRL,z_NRL,S_NRL,'k');
h4 = plot3(x_SP,y_SP,z_SP,'kx');
x_sp = mean(x_SP);y_sp = mean(y_SP);z_sp = mean(z_SP);
legend([h1 h3 h4],'Focal Mechanisms','Non-Relocations','Surface Points');
axis equal;grid on;
xlim([0 7000])
ylim([0 13000])
zlim([-10000 1000])
xlabel('E-W(m)','fontsize',12)
ylabel('N-S(m)','fontsize',12)
zlabel('depth(m)','fontsize',12)
title('Gate Creek Fault','fontsize',14)

% depth slices for node locations
depths = [-9900:300:0];depths = depths';
depths2 = [-9900:1200:-5100];depths2 = depths2';
depths2 = [depths2;-4500];
depths2 = [depths2;depths(20:34,1)];
depths3 = [-9900:1200:0];depths3 = depths3';
% northing coordinates for cross-sections/node locations
norths = [0:300:12300];norths = norths';% 300m spacing
norths2 = [0:1200:7200];norths2 = [norths2';norths(27:42)];

qf=50;% window front
qb=60;% window back
% cross sections
for i=1:numel(norths2)
        I = find(y_NRL>(norths2(i)-300*qb)&y_NRL<=(norths2(i)+300*qf));
        K = find(y_FM>(norths2(i)-300*qb)&y_FM<=(norths2(i)+300*qf));
        L = find(y_SP>(norths2(i)-12000)&y_SP<=(norths2(i)+12000));
        figure
        scatter(x_NRL(I),z_NRL(I),S_NRL(I),'k');
        hold on
        scatter(x_FM(K),z_FM(K),S_FM(K),'g');
        plot(x_SP(L),z_SP(L),'kx');
        axis equal;grid on;
        xlim([0 7000])
        ylim([-10000 1000])
        xlabel('E-W(m)','fontsize',12)
        ylabel('depth(m)','fontsize',12)
        title(strcat(num2str(norths(i)),'m north'),'fontsize',12)
        X{i}.NRL = x_NRL(I);
        X{i}.FM = x_FM(K);
        X{i}.SP = x_SP(L);
        X{i}.SP(:,1) = mean(X{i}.SP(:,1));
        X{i}.north = norths2(i);
        Y{i}.NRL = y_NRL(I);
        Y{i}.FM = y_FM(K);
        Y{i}.SP = y_SP(L);
        Y{i}.north = norths2(i);
        Z{i}.NRL = z_NRL(I);
        Z{i}.FM = z_FM(K);
        Z{i}.SP = z_SP(L);
        Z{i}.north = norths2(i);
end

% regression
Xf=[];Xf_ul=[];Xf_ll=[];
Yf=[];Yf_ul=[];Yf_ll=[];
Zf=[];Zf_ul=[];Zf_ll=[];

for i=1:numel(X)
    clear datain
    clear datains
    clear dataind
    clear xy
    clear xys
    clear xyd
    clear xdata
    % non-relocations, focal mechanisms, and surface points
    if i==1
        datain(:,1) = [Z{i+1}.NRL;Z{i+1}.FM;Z{i+1}.SP];
        datain(:,2) = [X{i+1}.NRL;X{i+1}.FM;X{i+1}.SP];
    else
        datain(:,1) = [Z{i}.NRL;Z{i}.FM;Z{i}.SP];
        datain(:,2) = [X{i}.NRL;X{i}.FM;X{i}.SP];
    end
        if X{1,i}.north<=7200
            xdata = depths3;
        else
            xdata = depths2;
            if mod(X{1,i}.north/600,2)~=0
                I = find(xdata>=-4500);
                xdata = xdata(I);
            end
        end
        
        % regression on cross section using Lowess function
        [dataout lowerLimit upperLimit xy] = lowess(datain,f,wantplot,imagefile,xdata);

    % depth extent of fault
    if X{1,i}.north<=3000
        I = find(xdata>=(0.0007*X{1,i}.north^2 - 4.3287*X{1,i}.north - 3083.9)&xdata<=max(datain(:,1)));
    elseif X{1,i}.north>=9300
        I = find(xdata>=(0.0007*(X{1,i}.north-9300)^2 - 0.1469*(X{1,i}.north-9300) - 9356.6)&xdata<=max(datain(:,1)));
    else
        I = find(xdata>=min(datain(:,1))&xdata<=max(datain(:,1)));
    end

        % plot regression on cross sections
        figure(i+1)
        plot(xy(I,2),xy(I,1),'k-');
        plot(xy(I,3),xy(I,1),'r-');
        plot(xy(I,4),xy(I,1),'r-');

        % store xyz points of fault nodes
        Xf(numel(Xf)+1:numel(Xf)+numel(I),1) = xy(I,2);
        Yf(numel(Yf)+1:numel(Yf)+numel(I),1) = Y{i}.north;
        Zf(numel(Zf)+1:numel(Zf)+numel(I),1) = xy(I,1);
        
        Xf_ul(numel(Xf_ul)+1:numel(Xf_ul)+numel(I),1) = xy(I,3);
        Yf_ul(numel(Yf_ul)+1:numel(Yf_ul)+numel(I),1) = Y{i}.north;
        Zf_ul(numel(Zf_ul)+1:numel(Zf_ul)+numel(I),1) = xy(I,1);
        
        Xf_ll(numel(Xf_ll)+1:numel(Xf_ll)+numel(I),1) = xy(I,4);
        Yf_ll(numel(Yf_ll)+1:numel(Yf_ll)+numel(I),1) = Y{i}.north;
        Zf_ll(numel(Zf_ll)+1:numel(Zf_ll)+numel(I),1) = xy(I,1);
end

% smooth fault in y-direction
C = unique(Zf);
for i=1:numel(C)
    I = find(Zf==C(i));
    [Xf(I),r]=smooth(Xf(I),1);
end
C_ul = unique(Zf_ul);
for i=1:numel(C_ul)
    I = find(Zf_ul==C_ul(i));
    [Xf_ul(I),r]=smooth(Xf_ul(I),1);
end
C_ll = unique(Zf_ll);
for i=1:numel(C_ll)
    I = find(Zf_ll==C_ll(i));
    [Xf_ll(I),r]=smooth(Xf_ll(I),1);
end

% put xyz points of fault nodes in 3 column matrix
XYZgcf(:,1) = Xf;XYZgcf(:,2) = Yf;XYZgcf(:,3) = Zf;
XYZgcf_ul(:,1) = Xf_ul;XYZgcf_ul(:,2) = Yf_ul;XYZgcf_ul(:,3) = Zf_ul;
XYZgcf_ll(:,1) = Xf_ll;XYZgcf_ll(:,2) = Yf_ll;XYZgcf_ll(:,3) = Zf_ll;
for i=1:numel(XYZgcf(:,3))
    if XYZgcf(i,3)==0
        XYZgcf(i,3)=-1;
    end
end
for i=1:numel(XYZgcf_ul(:,3))
    if XYZgcf_ul(i,3)==0
        XYZgcf_ul(i,3)=-1;
    end
end
for i=1:numel(XYZgcf_ll(:,3))
    if XYZgcf_ll(i,3)==0
        XYZgcf_ll(i,3)=-1;
    end
end

% triangulate fault nodes
CONgcf=Delaunay2_5D(XYZgcf);
CONgcf_ul=Delaunay2_5D(XYZgcf_ul);
CONgcf_ll=Delaunay2_5D(XYZgcf_ll);

% plot fault mesh
figure
for i=1:numel(CONgcf(:,1))
    plot3(XYZgcf([CONgcf(i,:) CONgcf(i,1)],1),XYZgcf([CONgcf(i,:) CONgcf(i,1)],2),XYZgcf([CONgcf(i,:) CONgcf(i,1)],3),'k-')
    hold on
end
for i=1:numel(CONgcf_ul(:,1))
    plot3(XYZgcf_ul([CONgcf_ul(i,:) CONgcf_ul(i,1)],1),XYZgcf_ul([CONgcf_ul(i,:) CONgcf_ul(i,1)],2),XYZgcf_ul([CONgcf_ul(i,:) CONgcf_ul(i,1)],3),'r-')
end
for i=1:numel(CONgcf_ll(:,1))
    plot3(XYZgcf_ll([CONgcf_ll(i,:) CONgcf_ll(i,1)],1),XYZgcf_ll([CONgcf_ll(i,:) CONgcf_ll(i,1)],2),XYZgcf_ll([CONgcf_ll(i,:) CONgcf_ll(i,1)],3),'r-')
end
axis equal;grid on;
xlim([0 7000])
ylim([0 13000])
zlim([-10000 1000])
xlabel('E-W(m)','fontsize',12)
ylabel('N-S(m)','fontsize',12)
zlabel('depth(m)','fontsize',12)
title('Gate Creek Fault','fontsize',14)


% Rotate back
Rccw = [cos(theta) -sin(theta);sin(theta) cos(theta)];
for i=1:numel(Xf)
    b = Rccw*[XYZgcf(i,1)-dx;XYZgcf(i,2)-dy];
    XYZgcf(i,1) = b(1);XYZgcf(i,2) = b(2);
    b = Rccw*[XYZgcf_ul(i,1)-dx;XYZgcf_ul(i,2)-dy];
    XYZgcf_ul(i,1) = b(1);XYZgcf_ul(i,2) = b(2);
    b = Rccw*[XYZgcf_ll(i,1)-dx;XYZgcf_ll(i,2)-dy];
    XYZgcf_ll(i,1) = b(1);XYZgcf_ll(i,2) = b(2);
end
[tngcf,nvecgcf] = PlotTriNormals(CONgcf,XYZgcf,convention);
[tngcf_ul,nvecgcf_ul] = PlotTriNormals(CONgcf_ul,XYZgcf_ul,convention);
[tngcf_ll,nvecgcf_ll] = PlotTriNormals(CONgcf_ll,XYZgcf_ll,convention);

% Correct polarity of upper residual fault
I = find(nvecgcf_ul(:,1)>0);
for i=1:numel(I)
    a = tngcf_ul(I(i),1);
    c = tngcf_ul(I(i),3);
    tngcf_ul(I(i),1) = c;
    tngcf_ul(I(i),3) = a;
    nvecgcf_ul(I(i),:) = -nvecgcf_ul(I(i),:);
end

% Translate back to global coordinates
XYZgcf(:,1) = XYZgcf(:,1) + xo;
XYZgcf(:,2) = XYZgcf(:,2) + yo;
XYZgcf_ul(:,1) = XYZgcf_ul(:,1) + xo;
XYZgcf_ul(:,2) = XYZgcf_ul(:,2) + yo;
XYZgcf_ll(:,1) = XYZgcf_ll(:,1) + xo;
XYZgcf_ll(:,2) = XYZgcf_ll(:,2) + yo;