% WRV_Plot_EQ_3D_TroutCreek_sensitivity.m
%
% AUTHOR:           Michael W. Swyer
% DATE CREATED:     2015/08/24
% DATE MODIFIED:    
% VERSION:          v.1
%
% PURPOSE:  To construct upper/lower residual 3D fault geometry of Big Butte
% Fault at Wind River Valley
%
% PURPOSE OF MODIFICATION:
% 
% INPUT: Seismic catalogs selected from Pacific Northwest Seismic Network:
%           1) FOCAL_MECHS_Trout_Creek_Fault.csv
%           2) relocated_earthquakes_Trout_Creek_Fault.csv
%           3) pnsn_earthquakes_not_relocated_Trout_Creek_Fault.csv
%        Surface points from mapped fault trace
%           4) Trout_Creek_Fault_surfacepoints.csv
%
% OUTPUT: Position of fault nodes in UTM Zone 10N meters (XYZ-),
% triangulation of fault nodes (tn-), and unit normal vectors of fault element
% triangles (nvec-).
%
% NOTE:
%
% KEY functions written specifically for this modeling:
%
% Other related functions:
%       deg2utm.m
%       fitNormal.m
%       lowess.m
%       smooth.m
%       R3RSR.m
%       R3R.m
%       SR.m
%       H.m
%       Delaunay2_5D.m
%       PlotTriNormals.m

clear all;close all

show_graph = 0;% Show graph of fit normal (0=no 1=yes)
f = 1;% smoothing factor (0 to 1)
wantplot = 1;% zero = no plot
imagefile = '\lowess.png';% directory where lowess plot is stored(not used if wantplot = 0)
convention = 'z-';% PlotTriNormals vector direction
%% trout creek fault %%

% local origin
xo = 567500;
yo = 5079000;

% import data
% Focal Mechanisms
data_FM = importdata('FOCAL_MECH_Trout_Creek_Fault.csv');
for i=2:numel(data_FM)
    d = strsplit(data_FM{i},',');
    lat_FM(i-1,1) = str2num(d{4});
    long_FM(i-1,1) = str2num(d{5});
    z_FM(i-1,1) = (-str2num(d{7})*1000)-rand;
    m_FM(i-1,1) = str2num(d{6});
    strikeA_FM(i-1,1) = str2num(d{8});
    dipA_FM(i-1,1) = str2num(d{9});
    rakeA_FM(i-1,1) = str2num(d{10});
    strikeB_FM(i-1,1) = str2num(d{11});
    if strikeB_FM(i-1,1)<200
        strikeB_FM(i-1,1) = strikeB_FM(i-1,1)+180;
    end
    dipB_FM(i-1,1) = str2num(d{12});
    rakeB_FM(i-1,1) = str2num(d{13});
end
strike = mean(strikeB_FM);
dip = mean(dipB_FM);
S_FM = 3.^m_FM;
[x_FM,y_FM,utmzone] = deg2utm(lat_FM,long_FM);
x_FM = x_FM - xo;
y_FM = y_FM - yo;

% Relocations
data_RL = importdata('relocated_earthquakes_Trout_Creek_Fault.csv');
for i=2:numel(data_RL.textdata(:,1))
    lat_RL(i-1,1) = str2num(data_RL.textdata{i,6});
    long_RL(i-1,1) = str2num(data_RL.textdata{i,7});
    z_RL(i-1,1) = (-str2num(data_RL.textdata{i,4})*1000)-rand;
    m_RL(i-1,1) = str2num(data_RL.textdata{i,5});
end
S_RL = 3.^m_RL;
[x_RL,y_RL,utmzone] = deg2utm(lat_RL,long_RL);
x_RL = x_RL - xo;
y_RL = y_RL - yo;

% Non-Relcoations
data_NRL = importdata('pnsn_earthquakes_not_relocated_Trout_Creek_Fault.csv');
for i=2:numel(data_NRL.textdata(:,1))
    lat_NRL(i-1,1) = str2num(data_NRL.textdata{i,6});
    long_NRL(i-1,1) = str2num(data_NRL.textdata{i,7});
    z_NRL(i-1,1) = (-str2num(data_NRL.textdata{i,4})*1000)-rand;
    m_NRL(i-1,1) = str2num(data_NRL.textdata{i,5});
end
S_NRL = 3.^m_NRL;
[x_NRL,y_NRL,utmzone] = deg2utm(lat_NRL,long_NRL);
x_NRL = x_NRL - xo;
y_NRL = y_NRL - yo;

% surface points
data_SP = importdata('Trout_Creek_Fault_surfacepoints.csv');
[x_SP,y_SP,utmzone] = deg2utm(data_SP.data(:,2),data_SP.data(:,1));
z_SP = data_SP.data(:,3)*.3048;
x_SP = x_SP - xo;
y_SP = y_SP - yo;

% fit normal vector
x = [x_FM;x_RL;x_NRL;x_SP];
y = [y_FM;y_RL;y_NRL;y_SP];
z = [z_FM;z_RL;z_NRL;z_SP];
if show_graph==1
    figure
end
clear c;clear n
c(:,1) = x;c(:,2) = y;c(:,3) = z;
n = fitNormal(c, show_graph);

% rotate to j=0
theta = atan(n(2)/n(1));
Rcw = [cos(theta) sin(theta);-sin(theta) cos(theta)];
dx = -6000;
dy = 6000;
for i=1:numel(x)
    b = Rcw*[x(i);y(i)];
    x(i) = b(1)+dx;y(i) = b(2)+dy;
end
if show_graph==1
    clear c;clear n
    c(:,1) = x;c(:,2) = y;c(:,3) = z;
    figure
    n = fitNormal(c, show_graph);
end
for i=1:numel(x_FM)
    b = Rcw*[x_FM(i);y_FM(i)];
    x_FM(i) = b(1)+dx;y_FM(i) = b(2)+dy;
end
for i=1:numel(x_RL)
    b = Rcw*[x_RL(i);y_RL(i)];
    x_RL(i) = b(1)+dx;y_RL(i) = b(2)+dy;
end
for i=1:numel(x_NRL)
    b = Rcw*[x_NRL(i);y_NRL(i)];
    x_NRL(i) = b(1)+dx;y_NRL(i) = b(2)+dy;
end
for i=1:numel(x_SP)
    b = Rcw*[x_SP(i);y_SP(i)];
    x_SP(i) = b(1)+dx;y_SP(i) = b(2)+dy;
end

% plot EQs
figure
h1 = scatter3(x_FM,y_FM,z_FM,S_FM,'g');
hold on
h2 = scatter3(x_RL,y_RL,z_RL,S_RL,'r');
h3 = scatter3(x_NRL,y_NRL,z_NRL,S_NRL,'k');
h4 = plot3(x_SP,y_SP,z_SP,'kx');
x_sp = mean(x_SP);y_sp = mean(y_SP);z_sp = mean(z_SP);
legend([h1 h2 h3 h4],'Focal Mechanisms','Relocations','Non-Relocations','Surface Points');
axis equal;grid on;
xlim([0 6000])
ylim([0 20000])
zlim([-14000 1000])
xlabel('E-W(m)','fontsize',12)
ylabel('N-S(m)','fontsize',12)
zlabel('depth(m)','fontsize',12)
title('Trout Creek Fault','fontsize',14)

% depth slices for node locations
depths = [-13500:300:0];depths = depths';
depths2 = [-13500:600:-6300];depths2 = depths2';
depths2 = [depths2;depths(26:46)];
depths3 = [-13500:1200:0];
depths3 = depths3';
% northing coordinates for cross-sections/node locations
norths = [1200:300:20000];% 300m spacing
norths = norths';
norths2 = [9900:1200:20000];
norths2 = [9300;norths2'];
norths2 = [norths(1:28);norths2];
qf=65;% window front
qb=25;% window back
% cross sections
for i=1:numel(norths2)
        I = find(y_NRL>(norths(i)-300*qb)&y_NRL<=(norths(i)+300*qf));
        J = find(y_RL>(norths2(i)-300*qb)&y_RL<=(norths2(i)+300*qf));
        K = find(y_FM>(norths(i)-300*qb)&y_FM<=(norths(i)+300*qf));
        L = find(y_SP>(norths2(i)-18000)&y_SP<=(norths2(i)+1200));
        figure
        scatter(x_NRL(I),z_NRL(I),S_NRL(I),'k');
        hold on
        scatter(x_RL(J),z_RL(J),S_RL(J),'r');
        hold on
        scatter(x_FM(K),z_FM(K),S_FM(K),'g');
        plot(x_SP(L),z_SP(L),'kx');
        axis equal;grid on;
        xlim([0 6000])
        ylim([-14000 1000])
        xlabel('E-W(m)','fontsize',12)
        ylabel('depth(m)','fontsize',12)
        title(strcat(num2str(norths(i)),'m north'),'fontsize',12)
        X{i}.RL = x_RL(J);
        X{i}.SP = x_SP(L);
        X{i}.north = norths2(i);
        Y{i}.RL = y_RL(J);
        Y{i}.SP = y_SP(L);
        Y{i}.north = norths2(i);
        Z{i}.RL = z_RL(J);
        Z{i}.SP = z_SP(L);
        Z{i}.north = norths2(i);
end

% regression
Xf=[];Xf_ul=[];Xf_ll=[];
Yf=[];Yf_ul=[];Yf_ll=[];
Zf=[];Zf_ul=[];Zf_ll=[];

for i=1:numel(X)
    clear datain
    clear datains
    clear dataind
    clear xy
    clear xys
    clear xyd
    clear xdata
        % relocations and surface points
        datain(:,1) = [Z{i}.RL;Z{i}.SP];
        datain(:,2) = [X{i}.RL;X{i}.SP];
        if X{1,i}.north<=9300
            xdata = depths2;
        if mod(X{1,i}.north/300,2)==0
            I = find(xdata>=-6300);
            xdata = xdata(I);
        end
        else
            xdata = depths3;
        end
            
        % regression on cross section using Lowess function
        [dataout lowerLimit upperLimit xy] = lowess(datain,f,wantplot,imagefile,xdata);
        
        % Vertical extent of fault
        if X{1,i}.north==600
                I = find(xdata>=-5700&xdata<=-2700);
        elseif X{1,i}.north==900
                I = find(xdata>=-6300&xdata<=-2100);
        elseif X{1,i}.north==1200
                I = find(xdata>=-6900&xdata<=-600);
        elseif X{1,i}.north==1500
                I = find(xdata>=-7800&xdata<=-300);
        elseif X{1,i}.north==1800
                I = find(xdata>=-8400);
        elseif X{1,i}.north==2100
                I = find(xdata>=-9000);
        elseif X{1,i}.north==2400
                I = find(xdata>=-9600);
        elseif X{1,i}.north==2700
                I = find(xdata>=-9600);
        elseif X{1,i}.north==3000
                I = find(xdata>=-9900);
        elseif X{1,i}.north==3300
                I = find(xdata>=-10200);
        elseif X{1,i}.north==3600
                I = find(xdata>=-10200&xdata<=600);
        elseif X{1,i}.north==3900
                I = find(xdata>=-10500&xdata<=600);
        elseif X{1,i}.north==4200
                I = find(xdata>=-10500&xdata<=600);
        elseif X{1,i}.north==4500
                I = find(xdata>=-10800&xdata<=600);
        elseif X{1,i}.north==4800
                I = find(xdata>=-11100&xdata<=600);
        elseif X{1,i}.north==5100
                I = find(xdata>=-11100&xdata<=600);
        elseif X{1,i}.north==5400
                I = find(xdata>=-11400&xdata<=600);
        elseif X{1,i}.north==5700
                I = find(xdata>=-11700&xdata<=600);
        elseif X{1,i}.north==6000
                I = find(xdata>=-11700&xdata<=-300);
        elseif X{1,i}.north==6300
                I = find(xdata>=-12000&xdata<=-300);
        elseif X{1,i}.north==6600
                I = find(xdata>=-12000&xdata<=-300);
        elseif X{1,i}.north==6900
                I = find(xdata>=-12300&xdata<=-300);
        elseif X{1,i}.north==7200
                I = find(xdata>=-12300&xdata<=-300);
        elseif X{1,i}.north==7500
                I = find(xdata>=-12300&xdata<=-300);
        elseif X{1,i}.north==7800
                I = find(xdata>=-12600&xdata<=-300);
        elseif X{1,i}.north==8100
                I = find(xdata>=-12600&xdata<=-300);
        elseif X{1,i}.north==8400
                I = find(xdata>=-12900&xdata<=-300);
        elseif X{1,i}.north==8700
                I = find(xdata>=-12900&xdata<=-300);
        elseif X{1,i}.north==9000
                I = find(xdata>=-13200&xdata<=-300);
        elseif X{1,i}.north==9300
                I = find(xdata>=-13200&xdata<=-300);
        elseif X{1,i}.north==9600
                I = find(xdata>=-13200&xdata<=-300);
        elseif X{1,i}.north==9900
                I = find(xdata>=-13200&xdata<=-600);
        elseif X{1,i}.north==10200
                I = find(xdata<=-600);
        elseif X{1,i}.north==10500
                I = find(xdata<=-600);
        elseif X{1,i}.north==10800
                I = find(xdata<=-600);
        elseif X{1,i}.north==11100
                I = find(xdata<=-900);
        elseif X{1,i}.north==11400
                I = find(xdata<=-900);
        elseif X{1,i}.north==11700
                I = find(xdata<=-1200);
        elseif X{1,i}.north==12000
                I = find(xdata<=-1200);
        elseif X{1,i}.north==12300
                I = find(xdata<=-1200);
        elseif X{1,i}.north==12600
                I = find(xdata<=-1200);
        elseif X{1,i}.north==12900
                I = find(xdata<=-1500);
        elseif X{1,i}.north==13200
                I = find(xdata<=-1500);
        elseif X{1,i}.north==13500
                I = find(xdata<=-1800);
        elseif X{1,i}.north==13800
                I = find(xdata<=-1800);
        elseif X{1,i}.north==14100
                I = find(xdata<=-2100);
        elseif X{1,i}.north==14400
                I = find(xdata<=-2400);
        elseif X{1,i}.north==14700
                I = find(xdata<=-2400);
        elseif X{1,i}.north==15000
                I = find(xdata<=-2700);
        elseif X{1,i}.north==15300
                I = find(xdata<=-3000);
        elseif X{1,i}.north==15600
                I = find(xdata<=-3000);
        elseif X{1,i}.north==15900
                I = find(xdata<=-3300);
        elseif X{1,i}.north==16200
                I = find(xdata<=-3600);
        elseif X{1,i}.north==16500
                I = find(xdata<=-3900);
        elseif X{1,i}.north==16800
                I = find(xdata<=-3900);
        elseif X{1,i}.north==17100
                I = find(xdata>=-13200&xdata<=-4200);
        elseif X{1,i}.north==17400
                I = find(xdata>=-13200&xdata<=-4500);
        elseif X{1,i}.north==17700
                I = find(xdata>=-13200&xdata<=-4800);
        elseif X{1,i}.north==18000
                I = find(xdata>=-13200&xdata<=-5100);
        elseif X{1,i}.north==18300
                I = find(xdata>=-12600&xdata<=-5700);
        elseif X{1,i}.north==18600
                I = find(xdata>=-12300&xdata<=-6300);
        elseif X{1,i}.north==18900
                I = find(xdata>=-12000&xdata<=-6600);
        elseif X{1,i}.north==19200
                I = find(xdata>=-11400&xdata<=-7200);
        elseif X{1,i}.north==19500
                I = find(xdata>=-10800&xdata<=-7800);
        elseif X{1,i}.north==19800
                I = find(xdata>=-9900&xdata<=-8700);  
        else
                I = find(xdata>=min(datain(:,1))&xdata<=max(datain(:,1)));
        end

        % plot regression on cross sections
        figure(i+1)
        plot(xy(I,2),xy(I,1),'k-');
        
        % store xyz points of fault nodes
        Xf(numel(Xf)+1:numel(Xf)+numel(I),1) = xy(I,2);
        Yf(numel(Yf)+1:numel(Yf)+numel(I),1) = Y{i}.north;
        Zf(numel(Zf)+1:numel(Zf)+numel(I),1) = xy(I,1);
        
        Xf_ul(numel(Xf_ul)+1:numel(Xf_ul)+numel(I),1) = xy(I,3);
        Yf_ul(numel(Yf_ul)+1:numel(Yf_ul)+numel(I),1) = Y{i}.north;
        Zf_ul(numel(Zf_ul)+1:numel(Zf_ul)+numel(I),1) = xy(I,1);
        
        Xf_ll(numel(Xf_ll)+1:numel(Xf_ll)+numel(I),1) = xy(I,4);
        Yf_ll(numel(Yf_ll)+1:numel(Yf_ll)+numel(I),1) = Y{i}.north;
        Zf_ll(numel(Zf_ll)+1:numel(Zf_ll)+numel(I),1) = xy(I,1);
end


% split fault into shallow and deep sections because upper half dips to the
% west and deep half dips to the east.
I = find(Zf>=-6300);J = find(Zf<=-6300);
I_ul = find(Zf_ul>=-6300);J_ul = find(Zf_ul<=-6300);
I_ll = find(Zf_ll>=-6300);J_ll = find(Zf_ll<=-6300);

% Shallow half
% put xyz points in 3 column matrix
XYZtcfs(:,1) = Xf(I);XYZtcfs(:,2) = Yf(I);XYZtcfs(:,3) = Zf(I);
for i=1:numel(XYZtcfs(:,3))
    if XYZtcfs(i,3)==0
        XYZtcfs(i,3)=-1;
    end
end
XYZtcfs_ul(:,1) = Xf_ul(I_ul);XYZtcfs_ul(:,2) = Yf_ul(I_ul);XYZtcfs_ul(:,3) = Zf_ul(I_ul);
for i=1:numel(XYZtcfs_ul(:,3))
    if XYZtcfs_ul(i,3)==0
        XYZtcfs_ul(i,3)=-1;
    end
end
XYZtcfs_ll(:,1) = Xf_ll(I_ll);XYZtcfs_ll(:,2) = Yf_ll(I_ll);XYZtcfs_ll(:,3) = Zf_ll(I_ll);
for i=1:numel(XYZtcfs_ll(:,3))
    if XYZtcfs_ll(i,3)==0
        XYZtcfs_ll(i,3)=-1;
    end
end
% triangulate fault nodes
CONtcfs=Delaunay2_5D(XYZtcfs);
CONtcfs_ul=Delaunay2_5D(XYZtcfs_ul);
CONtcfs_ll=Delaunay2_5D(XYZtcfs_ll);
% plot fault mesh
figure
for i=1:numel(CONtcfs(:,1))
    plot3(XYZtcfs([CONtcfs(i,:) CONtcfs(i,1)],1),XYZtcfs([CONtcfs(i,:) CONtcfs(i,1)],2),XYZtcfs([CONtcfs(i,:) CONtcfs(i,1)],3),'k-')
    hold on
end
for i=1:numel(CONtcfs_ul(:,1))
    plot3(XYZtcfs_ul([CONtcfs_ul(i,:) CONtcfs_ul(i,1)],1),XYZtcfs_ul([CONtcfs_ul(i,:) CONtcfs_ul(i,1)],2),XYZtcfs_ul([CONtcfs_ul(i,:) CONtcfs_ul(i,1)],3),'r-')
end
for i=1:numel(CONtcfs_ll(:,1))
    plot3(XYZtcfs_ll([CONtcfs_ll(i,:) CONtcfs_ll(i,1)],1),XYZtcfs_ll([CONtcfs_ll(i,:) CONtcfs_ll(i,1)],2),XYZtcfs_ll([CONtcfs_ll(i,:) CONtcfs_ll(i,1)],3),'r-')
end
axis equal;grid on;
xlim([0 6000])
ylim([0 20000])
zlim([-14000 1000])
xlabel('E-W(m)','fontsize',12)
ylabel('N-S(m)','fontsize',12)
zlabel('depth(m)','fontsize',12)
title('Trout Creek Fault','fontsize',14)
% Rotate back
Rccw = [cos(theta) -sin(theta);sin(theta) cos(theta)];
for i=1:numel(XYZtcfs(:,1))
    b = Rccw*[XYZtcfs(i,1)-dx;XYZtcfs(i,2)-dy];
    XYZtcfs(i,1) = b(1);XYZtcfs(i,2) = b(2);
    b = Rccw*[XYZtcfs_ul(i,1)-dx;XYZtcfs_ul(i,2)-dy];
    XYZtcfs_ul(i,1) = b(1);XYZtcfs_ul(i,2) = b(2);
    b = Rccw*[XYZtcfs_ll(i,1)-dx;XYZtcfs_ll(i,2)-dy];
    XYZtcfs_ll(i,1) = b(1);XYZtcfs_ll(i,2) = b(2);
end
[tntcfs,nvectcfs] = PlotTriNormals(CONtcfs,XYZtcfs,convention);
[tntcfs_ul,nvectcfs_ul] = PlotTriNormals(CONtcfs_ul,XYZtcfs_ul,convention);
[tntcfs_ll,nvectcfs_ll] = PlotTriNormals(CONtcfs_ll,XYZtcfs_ll,convention);
% Translate back to global coordinates
XYZtcfs(:,1) = XYZtcfs(:,1) + xo;
XYZtcfs(:,2) = XYZtcfs(:,2) + yo;
XYZtcfs_ul(:,1) = XYZtcfs_ul(:,1) + xo;
XYZtcfs_ul(:,2) = XYZtcfs_ul(:,2) + yo;
XYZtcfs_ll(:,1) = XYZtcfs_ll(:,1) + xo;
XYZtcfs_ll(:,2) = XYZtcfs_ll(:,2) + yo;

% Deep half
% put xyz points in 3 column matrix
XYZtcfd(:,1) = Xf(J);XYZtcfd(:,2) = Yf(J);XYZtcfd(:,3) = Zf(J);
XYZtcfd_ul(:,1) = Xf_ul(J_ul);XYZtcfd_ul(:,2) = Yf_ul(J_ul);XYZtcfd_ul(:,3) = Zf_ul(J_ul);
XYZtcfd_ll(:,1) = Xf_ll(J_ll);XYZtcfd_ll(:,2) = Yf_ll(J_ll);XYZtcfd_ll(:,3) = Zf_ll(J_ll);
% triangulate fault nodes
CONtcfd=Delaunay2_5D(XYZtcfd);
CONtcfd_ul=Delaunay2_5D(XYZtcfd_ul);
CONtcfd_ll=Delaunay2_5D(XYZtcfd_ll);
% plot fault mesh
figure(2)
for i=1:numel(CONtcfd(:,1))
    plot3(XYZtcfd([CONtcfd(i,:) CONtcfd(i,1)],1),XYZtcfd([CONtcfd(i,:) CONtcfd(i,1)],2),XYZtcfd([CONtcfd(i,:) CONtcfd(i,1)],3),'k-')
end
for i=1:numel(CONtcfd_ul(:,1))
    plot3(XYZtcfd_ul([CONtcfd_ul(i,:) CONtcfd_ul(i,1)],1),XYZtcfd_ul([CONtcfd_ul(i,:) CONtcfd_ul(i,1)],2),XYZtcfd_ul([CONtcfd_ul(i,:) CONtcfd_ul(i,1)],3),'r-')
end
for i=1:numel(CONtcfd_ll(:,1))
    plot3(XYZtcfd_ll([CONtcfd_ll(i,:) CONtcfd_ll(i,1)],1),XYZtcfd_ll([CONtcfd_ll(i,:) CONtcfd_ll(i,1)],2),XYZtcfd_ll([CONtcfd_ll(i,:) CONtcfd_ll(i,1)],3),'r-')
end
% Rotate back
Rccw = [cos(theta) -sin(theta);sin(theta) cos(theta)];
for i=1:numel(XYZtcfd(:,1))
    b = Rccw*[XYZtcfd(i,1)-dx;XYZtcfd(i,2)-dy];
    XYZtcfd(i,1) = b(1);XYZtcfd(i,2) = b(2);
    b = Rccw*[XYZtcfd_ul(i,1)-dx;XYZtcfd_ul(i,2)-dy];
    XYZtcfd_ul(i,1) = b(1);XYZtcfd_ul(i,2) = b(2);
    b = Rccw*[XYZtcfd_ll(i,1)-dx;XYZtcfd_ll(i,2)-dy];
    XYZtcfd_ll(i,1) = b(1);XYZtcfd_ll(i,2) = b(2);
end
convention = 'z+';% PlotTriNormals vector direction (oposite of top half)
% correct polarity of triangulation
[tntcfd,nvectcfd] = PlotTriNormals(CONtcfd,XYZtcfd,convention);
[tntcfd_ul,nvectcfd_ul] = PlotTriNormals(CONtcfd_ul,XYZtcfd_ul,convention);
[tntcfd_ll,nvectcfd_ll] = PlotTriNormals(CONtcfd_ll,XYZtcfd_ll,convention);

% Correct polarity of upper residual fault
I = find(nvectcfd_ul(:,1)<0);
for i=1:numel(I)
    a = tntcfd_ul(I(i),1);
    c = tntcfd_ul(I(i),3);
    tntcfd_ul(I(i),1) = c;
    tntcfd_ul(I(i),3) = a;
    nvectcfd_ul(I(i),:) = -nvectcfd_ul(I(i),:);
end
% Translate back to global coordinates
XYZtcfd(:,1) = XYZtcfd(:,1) + xo;
XYZtcfd(:,2) = XYZtcfd(:,2) + yo;
XYZtcfd_ul(:,1) = XYZtcfd_ul(:,1) + xo;
XYZtcfd_ul(:,2) = XYZtcfd_ul(:,2) + yo;
XYZtcfd_ll(:,1) = XYZtcfd_ll(:,1) + xo;
XYZtcfd_ll(:,2) = XYZtcfd_ll(:,2) + yo;