% WRV_Plot_EQ_3D_WindRiver.m
%
% AUTHOR:           Michael W. Swyer
% DATE CREATED:     2015/05/26
% DATE MODIFIED:    
% VERSION:          v.1
%
% PURPOSE:  To construct 3D fault geometry of Wind River Fault at Wind River
% Valley
%
% PURPOSE OF MODIFICATION:
% 
% INPUT: Seismic catalogs selected from Pacific Northwest Seismic Network:
%           1) FOCAL_MECHS_Wind_River_Fault.csv
%           2) relocated_earthquakes_Wind_River_Fault.csv
%           3) pnsn_earthquakes_not_relocated_Wind_River_Fault.csv
%        Surface points from mapped fault trace
%           4) Wind_River_Fault_surfacepoints.csv
%
% OUTPUT: Position of fault nodes in UTM Zone 10N meters (XYZ-),
% triangulation of fault nodes (tn-), and unit normal vectors of fault element
% triangles (nvec-).
%
% NOTE:
%
% KEY functions written specifically for this modeling:
%
% Other related functions:
%       deg2utm.m
%       fitNormal.m
%       lowess.m
%       smooth.m
%       R3RSR.m
%       R3R.m
%       SR.m
%       H.m
%       Delaunay2_5D.m
%       PlotTriNormals.m

clear all;close all

show_graph = 0;% Show graph of fit normal (0=no 1=yes)
f = 1;% smoothing factor (0 to 1)
wantplot = 0;% zero = no plot
imagefile = '\lowess.png';% directory where lowess plot is stored(not used if wantplot = 0)
convention = 'z-';% PlotTriNormals vector direction
%% wind river fault %%

% local origin
xo = 580000;
yo = 5060000;

% import data
% Focal Mechanisms
data_FM = importdata('FOCAL_MECH_Wind_River_Fault.csv');
for i=2:numel(data_FM.textdata(:,1))
    lat_FM(i-1,1) = str2num(data_FM.textdata{i,4});
    long_FM(i-1,1) = str2num(data_FM.textdata{i,5});
    z_FM(i-1,1) = (-str2num(data_FM.textdata{i,7})*1000);
    m_FM(i-1,1) = str2num(data_FM.textdata{i,6});
end
S_FM = 3.^m_FM;
[x_FM,y_FM,utmzone] = deg2utm(lat_FM,long_FM);
x_FM = x_FM - xo;
y_FM = y_FM - yo;

% Relocations
data_RL = importdata('relocated_earthquakes_Wind_River_Fault.csv');
for i=2:numel(data_RL.textdata(:,1))
    lat_RL(i-1,1) = str2num(data_RL.textdata{i,6});
    long_RL(i-1,1) = str2num(data_RL.textdata{i,7});
    z_RL(i-1,1) = (-str2num(data_RL.textdata{i,4})*1000)-(rand*(10^-7));
    m_RL(i-1,1) = str2num(data_RL.textdata{i,5});
end
S_RL = 3.^m_RL;
[x_RL,y_RL,utmzone] = deg2utm(lat_RL,long_RL);
x_RL = x_RL - xo;
y_RL = y_RL - yo;

% Non-Relcoations
data_NRL = importdata('pnsn_earthquakes_not_relocated_Wind_River_Fault.csv');
for i=2:numel(data_NRL.textdata(:,1))
    lat_NRL(i-1,1) = str2num(data_NRL.textdata{i,6});
    long_NRL(i-1,1) = str2num(data_NRL.textdata{i,7});
    z_NRL(i-1,1) = (-str2num(data_NRL.textdata{i,4})*1000)-(rand*(10^-7));
    m_NRL(i-1,1) = str2num(data_NRL.textdata{i,5});
end
S_NRL = 3.^m_NRL;
[x_NRL,y_NRL,utmzone] = deg2utm(lat_NRL,long_NRL);
x_NRL = x_NRL - xo;
y_NRL = y_NRL - yo;

% surface points
data_SP = importdata('Wind_River_Fault_surfacepoints.csv');
[x_SP,y_SP,utmzone] = deg2utm(data_SP.data(:,2),data_SP.data(:,1));
z_SP = data_SP.data(:,3)*.3048;
x_SP = x_SP - xo;
y_SP = y_SP - yo;

% fit normal vector
x = [x_FM;x_RL;x_NRL;x_SP];
y = [y_FM;y_RL;y_NRL;y_SP];
z = [z_FM;z_RL;z_NRL;z_SP];
if show_graph==1
    figure
end
clear c;clear n
c(:,1) = x;c(:,2) = y;c(:,3) = z;
n = fitNormal(c, show_graph);

% rotate to j=0
theta = atan(n(2)/n(1));
Rcw = [cos(theta) sin(theta);-sin(theta) cos(theta)];
dx = -10000;
dy = 13500;
for i=1:numel(x)
    b = Rcw*[x(i);y(i)];
    x(i) = b(1)+dx;y(i) = b(2)+dy;
end
if show_graph==1
    clear c;clear n
    c(:,1) = x;c(:,2) = y;c(:,3) = z;
    figure
    n = fitNormal(c, show_graph);
end
for i=1:numel(x_FM)
    b = Rcw*[x_FM(i);y_FM(i)];
    x_FM(i) = b(1)+dx;y_FM(i) = b(2)+dy;
end
for i=1:numel(x_RL)
    b = Rcw*[x_RL(i);y_RL(i)];
    x_RL(i) = b(1)+dx;y_RL(i) = b(2)+dy;
end
for i=1:numel(x_NRL)
    b = Rcw*[x_NRL(i);y_NRL(i)];
    x_NRL(i) = b(1)+dx;y_NRL(i) = b(2)+dy;
end
for i=1:numel(x_SP)
    b = Rcw*[x_SP(i);y_SP(i)];
    x_SP(i) = b(1)+dx;y_SP(i) = b(2)+dy;
end

% rotate about y-axis
z_FM = z_FM;x_FM = x_FM - 1000;
z_RL = z_RL;x_RL = x_RL - 1000;
z_NRL = z_NRL;x_NRL = x_NRL - 1000;
z_SP = z_SP;x_SP = x_SP - 1000;
Rccw = [cos(3*(pi/180)) -sin(3*(pi/180));sin(3*(pi/180)) cos(3*(pi/180))];
for i=1:numel(x_FM)
    b = Rccw*[x_FM(i);z_FM(i)];
    x_FM(i) = b(1);z_FM(i) = b(2);
end
for i=1:numel(x_RL)
    b = Rccw*[x_RL(i);z_RL(i)];
    x_RL(i) = b(1);z_RL(i) = b(2);
end
for i=1:numel(x_NRL)
    b = Rccw*[x_NRL(i);z_NRL(i)];
    x_NRL(i) = b(1);z_NRL(i) = b(2);
end
z_FM = z_FM;x_FM = x_FM + 1000;
z_RL = z_RL;x_RL = x_RL + 1000;
z_NRL = z_NRL;x_NRL = x_NRL + 1000;
z_SP = z_SP;x_SP = x_SP + 1000;

% plot EQs
figure
h1 = scatter3(x_FM,y_FM,z_FM,S_FM,'g');
hold on
h2 = scatter3(x_RL,y_RL,z_RL,S_RL,'r');
h3 = scatter3(x_NRL,y_NRL,z_NRL,S_NRL,'k');
h4 = plot3(x_SP,y_SP,z_SP,'kx');
x_sp = mean(x_SP);y_sp = mean(y_SP);z_sp = mean(z_SP);
legend([h1 h2 h3 h4],'Focal Mechanisms','Relocations','Non-Relocations','Surface Points');
axis equal;grid on;
xlim([0 7000])
ylim([0 23500])
zlim([-16000 1000])
xlabel('E-W(m)','fontsize',12)
ylabel('N-S(m)','fontsize',12)
zlabel('depth(m)','fontsize',12)
title('Wind River Fault','fontsize',14)

% depth slices for node locations
depths = [-14700:175:0];depths = depths';
depths2 = [-14700:525:0];depths2 = depths2';
depths2 = [[-14700:1050:-6300]';depths2(18:29)];
depths3 = [depths2(1:21,1);depths(62:85,1)];
% northing coordinates for cross-sections/node locations
norths = [0:300:22500];% 300m spacing
qf=60;% window front
qb=70;% window back

% cross sections
for i=1:numel(norths)
        I = find(y_NRL>(norths(i)-300*qb)&y_NRL<=(norths(i)+300*qf));
        J = find(y_RL>(norths(i)-300*qb)&y_RL<=(norths(i)+300*qf));
        K = find(y_FM>(norths(i)-300*qb)&y_FM<=(norths(i)+300*qf));
        L = find(y_SP>(norths(i)-2100)&y_SP<=(norths(i)+1200));
        figure
        scatter(x_NRL(I),z_NRL(I),S_NRL(I),'k');
        hold on
        scatter(x_RL(J),z_RL(J),S_RL(J),'r');
        scatter(x_FM(K),z_FM(K),S_FM(K),'g');
        plot(x_SP(L),z_SP(L),'kx');
        axis equal;grid on;
        xlim([0 7000])
        ylim([-16000 1000])
        xlabel('E-W(m)','fontsize',12)
        ylabel('depth(m)','fontsize',12)
        title(strcat(num2str(norths(i)),'m north'),'fontsize',12)
        X{i}.NRL = x_NRL(I);
        X{i}.RL = x_RL(J);
        X{i}.FM = x_FM(K);
        X{i}.SP = x_SP(L);
        X{i}.SP(:,1) = mean(X{i}.SP(:,1));
        X{i}.north = norths(i);
        Y{i}.NRL = y_NRL(I);
        Y{i}.RL = y_RL(J);
        Y{i}.FM = y_FM(K);
        Y{i}.SP = y_SP(L);
        Y{i}.north = norths(i);
        Z{i}.NRL = z_NRL(I);
        Z{i}.RL = z_RL(J);
        Z{i}.FM = z_FM(K);
        Z{i}.SP = z_SP(L);
        Z{i}.north = norths(i);
end

% regression
Xf=[];
Yf=[];
Zf=[];

for i=1:numel(X)
    clear datain
    clear datains
    clear dataind
    clear xy
    clear xys
    clear xyd
    clear xdata
    % relocations, non-relocations, focal mechanisms, and surface points
        datain(:,1) = [Z{i}.NRL;Z{i}.RL;Z{i}.FM;Z{i}.SP];
        datain(:,2) = [X{i}.NRL;X{i}.RL;X{i}.FM;X{i}.SP];
        xdata = depths2;
    
    % change depth extent for every other cross section for coarser deep mesh
    if mod(X{1,i}.north/300,2)~=0
        I = find(xdata>=-4200);
        xdata = xdata(I);
    elseif mod(X{1,i}.north/600,2)~=0
        I = find(xdata>=-6300);
        xdata = xdata(I);
    end
    
    % regression on cross section using Lowess function
    [dataout lowerLimit upperLimit xy] = lowess(datain,f,wantplot,imagefile,xdata);

    % depth extent of fault
    if X{1,i}.north<=10500
        I = find(xdata>=(-4345*log(Y{i}.north)+28214));
    elseif X{1,i}.north==22500
        I = find(xdata>=-12000&xdata<=(-.000000007*Y{i}.north^3+.0003*Y{i}.north^2-4.8703*Y{i}.north+26892));
    elseif X{1,i}.north==22200
        I = find(xdata>=-12600&xdata<=(-.000000007*Y{i}.north^3+.0003*Y{i}.north^2-4.8703*Y{i}.north+26892));
    elseif X{1,i}.north==21900
        I = find(xdata>=-12900&xdata<=(-.000000007*Y{i}.north^3+.0003*Y{i}.north^2-4.8703*Y{i}.north+26892));
    elseif X{1,i}.north==21600
        I = find(xdata>=-13200&xdata<=(-.000000007*Y{i}.north^3+.0003*Y{i}.north^2-4.8703*Y{i}.north+26892));
    elseif X{1,i}.north==21300
        I = find(xdata>=-13500&xdata<=(-.000000007*Y{i}.north^3+.0003*Y{i}.north^2-4.8703*Y{i}.north+26892));
    elseif X{1,i}.north==21000
        I = find(xdata>=-13500&xdata<=(-.000000007*Y{i}.north^3+.0003*Y{i}.north^2-4.8703*Y{i}.north+26892));
    elseif X{1,i}.north==20700
        I = find(xdata>=-13800&xdata<=(-.000000007*Y{i}.north^3+.0003*Y{i}.north^2-4.8703*Y{i}.north+26892));
    elseif X{1,i}.north==20400
        I = find(xdata>=-13800&xdata<=(-.000000007*Y{i}.north^3+.0003*Y{i}.north^2-4.8703*Y{i}.north+26892));
    elseif X{1,i}.north==20100
        I = find(xdata>=-14100&xdata<=(-.000000007*Y{i}.north^3+.0003*Y{i}.north^2-4.8703*Y{i}.north+26892));
    elseif X{1,i}.north==19800
        I = find(xdata>=-14100&xdata<=(-.000000007*Y{i}.north^3+.0003*Y{i}.north^2-4.8703*Y{i}.north+26892));
    elseif X{1,i}.north==19500
        I = find(xdata>=-14400&xdata<=(-.000000007*Y{i}.north^3+.0003*Y{i}.north^2-4.8703*Y{i}.north+26892));
    else
        I = find(xdata>=(-4345*log(Y{i}.north)+28214)&xdata<=(-.000000007*Y{i}.north^3+.0003*Y{i}.north^2-4.8703*Y{i}.north+26892));
    end

        % plot regression on cross sections
        figure(i+1)
        plot(xy(I,2),xy(I,1),'k-');
        
        % store xyz points of fault nodes
        Xf(numel(Xf)+1:numel(Xf)+numel(I),1) = xy(I,2);
        % change y location for intersection
        if Y{i}.north==7100
            Yf(numel(Yf)+1:numel(Yf)+numel(I),1) = Y{i}.north+35.389869;
        else
            Yf(numel(Yf)+1:numel(Yf)+numel(I),1) = Y{i}.north;
        end
        Zf(numel(Zf)+1:numel(Zf)+numel(I),1) = xy(I,1);
end

% smooth fault in y-direction
C = unique(Zf);
for i=1:numel(C)
    I = find(Zf==C(i));
    [Xf(I),r]=smooth(Xf(I),1);
end

% stagger y-points for intersecting fault dip
clear C
C = unique(Yf);
for i=1:numel(C)
    I = find(Yf==C(i));
    clear Zd
    Zd = sort(Zf(I),'descend');
    for j=1:numel(Zd)
        J = find(Zf(I)==Zd(j));
            if mod(Zd(j)/525,2)==0
                Yf(I(J)) = Yf(I(J))+75;
            else
                Yf(I(J)) = Yf(I(J))-75;
            end
    end  
end

% put xyz points into 3 column matrix
XYZwrf(:,1) = Xf;XYZwrf(:,2) = Yf+42.280457;XYZwrf(:,3) = Zf;
for i=1:numel(XYZwrf(:,3))
    if XYZwrf(i,3)==0
        XYZwrf(i,3)=-1;
    end
end

% triangulate fault nodes
CONwrf=Delaunay2_5D(XYZwrf);

% plot fault mesh
figure(1)
for i=1:numel(CONwrf(:,1))
    plot3(XYZwrf([CONwrf(i,:) CONwrf(i,1)],1),XYZwrf([CONwrf(i,:) CONwrf(i,1)],2),XYZwrf([CONwrf(i,:) CONwrf(i,1)],3),'b-')
end
% Rotate back
Rccw = [cos(theta) -sin(theta);sin(theta) cos(theta)];
for i=1:numel(Xf)
    b = Rccw*[XYZwrf(i,1)-dx;XYZwrf(i,2)-dy];
    XYZwrf(i,1) = b(1);XYZwrf(i,2) = b(2);
end
[tnwrf,nvecwrf] = PlotTriNormals(CONwrf,XYZwrf,convention);

% Translate back to global coordinates
XYZwrf(:,1) = XYZwrf(:,1) + xo;
XYZwrf(:,2) = XYZwrf(:,2) + yo;