% MASTER_p3d_WRV.m
%
% AUTHOR:           Michael Swyer
% DATE CREATED:     5/18/2015
% DATE MODIFIED:    
% VERSION:          v.1
%
% PURPOSE:
%   Script to run poly3d, version from 1999, in c++ is slaved to matlab
%   for:
%   - Modeling the faults at Wind River Valley
%
% OBSERVATION GRIDS:
%      Areal grid: 2D
%           -Extent of WADGER thermal model for WRV with 2000 ft obs point
%           spacing converted to meters in UTM.
%          
% PURPOSE OF MODIFICATION:
%
% INPUT: Fault nodes and connectivity in global coordinates NAD_1983_UTM_ZONE_10N
%       , Stress tensors for 200m and 3000m depths and focal mechanism observation
%       points in Microsoft Excel format named:
%           -Big_Butte_Fault.xls
%           -Trout_Creek_Fault_shallow.xls
%           -Trout_Creek_Fault_deep.xls
%           -Wind_River_Fault.xls
%           -Gate_Creek_Fault.xls
%           -WR_West_Fault.xls
%           -Wise_Fault.xls
%           -Bunker_Hill_Fault.xls
%           -Bear_Creek_Fault.xls
%           -Brush_Creek_Fault.xls
%           -Shiperds_Fault_NW.xls
%           -Shiperds_Fault_SE.xls
%           -StressTensorWRV200.csv
%           -StressTensorWRV3km.csv
% 
% OUTPUT: Poly 3D Input and Output files named:
%           -WindRiver200.in
%           -WindRiver200.out
%           -WindRiver3km.in
%           -WindRiver3km.out
%
%
%
%
% NOTE: 
% - Based on original files drafted by J. Ole Kaven
% 
% - Note specific paths to the folder containg p3d and to the folder
% containing this mfile are specified for running p3d and saving .in and
% .out files respectively
% 
% 
% KEY functions written specifically for this modeling
%
% Other related functions
% - Delaunay2_5D 
% - p3din_FAULT_func_v1
% - PlotTriNormals
% - p3doutputreader_v04
%
%

clear all, close all

tic

%% 1. Define OBSERVATION GRID RANGES
% Generate observation grids in global coordinates.

% AREAL GRIDS: 2D

% User Coordinate System
x1o = 573353.110394;
x2o = 5055478.41079;
x3o = 0;
rot1 = 0;
rot2 = 0;
% rot3 = 1.805;
rot3 = 1.80496099950057;
CS_WADGER = [x1o, x2o, x3o, rot1, rot2, rot3, 123];% matrix used in p3din_FAULT_func_v1

% Extent of WADGER thermal model
% min/max values 1000ft spacing at 200m depth
minx = 0;  % min value of x
maxx = 30469.431059;  % max value of x
miny = 0;  % min value of y
maxy = 27727.162767; % max value of y
minz = -200;  % min value of z
maxz = -200;  % max value of z    
npx  = 101; % number of points corresponding to inc in each dimension
npy  = 92; % see also function: linspace
npz  = 1;
OBSgridWADGER200 = [minx miny minz maxx maxy maxz npx npy npz];% matrix used in p3din_FAULT_func_v1

% min/max values 1000ft spacing at 3000m depth
minx = 0;  % min value of x
maxx = 30469.431059;  % max value of x
miny = 0;  % min value of y
maxy = 27727.162767; % max value of y
minz = -3000;  % min value of z
maxz = -3000;  % max value of z    
npx  = 101; % number of points corresponding to inc in each dimension
npy  = 92; % see also function: linspace
npz  = 1;
OBSgridWADGER3km = [minx miny minz maxx maxy maxz npx npy npz];% matrix used in p3din_FAULT_func_v1

%% 2. Define Boundary Conditions to run

% depth to water table(meters)
dw = 20;

% import stress tensor(s)
% 200m
Sigma200 = importdata('StressTensorWRV200.csv',',');
d = .2;% depth km
Pp200 = (9.733*(d-(dw/1000)));
Pf200 = Pp200*1000000;% fluid pressure used in poly3D
% 3000m
Sigma3km = importdata('StressTensorWRV3km.csv',',');
d = 3;% depth km
Pp3km = (9.733*(d-(dw/1000)));
Pf3km = Pp3km*1000000;% fluid pressure used in poly3D

% Elastic Properties
nu = 0.25; % poisson's ratio
E = 30000000000; % Young's Modulus in Pa
   
    %% 3. IMPORT FAULTS
    
    % Big Butte Fault
    XYZbbf = xlsread('Big_Butte_Fault.xls','XYZbbf','A2:C1403');
    tnbbf = xlsread('Big_Butte_Fault.xls','tnbbf','A1:C2670');

    % Trout Creek Fault
    XYZtcfs = xlsread('Trout_Creek_Fault_shallow.xls','XYZtcfs','A2:C1028');
    tntcfs = xlsread('Trout_Creek_Fault_shallow.xls','tntcfs','A1:C1915');
    XYZtcfd = xlsread('Trout_Creek_Fault_deep.xls','XYZtcfd','A2:C1282');
    tntcfd = xlsread('Trout_Creek_Fault_deep.xls','tntcfd','A1:C2420');

    % Wind River Fault
    XYZwrf = xlsread('Wind_River_Fault.xls','XYZwrf','A2:C5575');
    tnwrf = xlsread('Wind_River_Fault.xls','tnwrf','A1:C10911');
    
    % Gate Creek Fault
    XYZgcf = xlsread('Gate_Creek_Fault.xls','XYZgcf','A2:C1213');
    tngcf = xlsread('Gate_Creek_Fault.xls','tngcf','A1:C2295');
    
    % WR West Fault
    XYZwrwf = xlsread('WR_West_Fault.xls','XYZwrwf','A2:C63');
    tnwrwf = xlsread('WR_West_Fault.xls','tnwrwf','A1:C96');
    
    % Wise Fault
    XYZwf = xlsread('Wise_Fault.xls','XYZwf','A2:C63');
    tnwf = xlsread('Wise_Fault.xls','tnwf','A1:C96');
    
    % Bunker Hill Fault
    XYZbhf = xlsread('Bunker_Hill_Fault.xls','XYZbhf','A2:C193');
    tnbhf = xlsread('Bunker_Hill_Fault.xls','tnbhf','A1:C340');
    
    % Bear Creek Fault
    XYZbcf = xlsread('Bear_Creek_Fault.xls','XYZbcf','A2:C863');
    tnbcf = xlsread('Bear_Creek_Fault.xls','tnbcf','A1:C1625');
    
    % Brush Creek Fault
    XYZbrcf = xlsread('Brush_Creek_Fault.xls','XYZbrcf','A2:C805');
    tnbrcf = xlsread('Brush_Creek_Fault.xls','tnbrcf','A1:C1519');
    
    % Shiperds Fault
    XYZsfNW = xlsread('Shiperds_Fault_NW.xls','XYZsfNW','A2:C741');
    tnsfNW = xlsread('Shiperds_Fault_NW.xls','tnsfNW','A1:C1395');
    XYZsfSE = xlsread('Shiperds_Fault_SE.xls','XYZsfSE','A2:C632');
    tnsfSE = xlsread('Shiperds_Fault_SE.xls','tnsfSE','A1:C1193');
    
    %% 4. RUN p3din_FAULT_v1.m to generate P3D input file and run P3D

    filename = 'WindRiver200';
    path_in = strcat('InputOutputFiles/');
    filename_in  = [path_in,filename,'.in'];
    
        % p3din_FAULT_v1
        p3din_FAULT_func_v1_WRV_200m(E,nu,Sigma200,Pf200,filename_in,XYZbbf,XYZtcfs,XYZtcfd,XYZwrf,XYZgcf,XYZwrwf,XYZwf,XYZbhf,XYZbcf,XYZbrcf,XYZsfNW,XYZsfSE,tnbbf,tntcfs,tntcfd,tnwrf,tngcf,tnwrwf,tnwf,tnbhf,tnbcf,tnbrcf,tnsfNW,tnsfSE,CS_WADGER,OBSgridWADGER200)
    
        %%% Un-comment these lines to run Poly3D %%%
%         filename_out  = [path_in,filename,'.out'];
%         pcdloc = '/P3D/P3DinC1999/newpoly3d';
%         system([pcdloc,' -i ',filename_in,' -o ',filename_out])

toc

tic

    filename = 'WindRiver3km';
    path_in = strcat('InputOutputFiles/');
    filename_in  = [path_in,filename,'.in'];
    
        % p3din_FAULT_v1
        p3din_FAULT_func_v1_WRV_3km(E,nu,Sigma3km,Pf3km,filename_in,XYZbbf,XYZtcfs,XYZtcfd,XYZwrf,XYZgcf,XYZwrwf,XYZwf,XYZbhf,XYZbcf,XYZbrcf,XYZsfNW,XYZsfSE,tnbbf,tntcfs,tntcfd,tnwrf,tngcf,tnwrwf,tnwf,tnbhf,tnbcf,tnbrcf,tnsfNW,tnsfSE,CS_WADGER,OBSgridWADGER3km)
    
        %%% Un-comment these lines to run Poly3D %%%
%         filename_out  = [path_in,filename,'.out'];
%         pcdloc = '/P3D/P3DinC1999/newpoly3d';
%         system([pcdloc,' -i ',filename_in,' -o ',filename_out])

toc