% MASTER_p3d_WRV_sensitivity.m
%
% AUTHOR:           Michael Swyer
% DATE CREATED:     5/18/2015
% DATE MODIFIED:    
% VERSION:          v.1
%
% PURPOSE:
%   Script to run poly3d, version from 1999, in c++ is slaved to matlab
%   for:
%   - Modeling the faults at Wind River Valley
%
% OBSERVATION GRIDS:
%      Areal grid: 2D
%           -Extent of WADGER thermal model for WRV with 2000 ft obs point
%           spacing converted to meters in UTM.
%          
% PURPOSE OF MODIFICATION:
%
% INPUT: Fault nodes and connectivity in global coordinates NAD_1983_UTM_ZONE_10N
%       , Stress tensors for 200m and 3000m depths and focal mechanism observation
%       points in Microsoft Excel format named:
%           -Big_Butte_Fault.xls
%           -Trout_Creek_Fault_shallow.xls
%           -Trout_Creek_Fault_deep.xls
%           -Wind_River_Fault.xls
%           -Gate_Creek_Fault.xls
%           -WR_West_Fault.xls
%           -Wise_Fault.xls
%           -Bunker_Hill_Fault.xls
%           -Bear_Creek_Fault.xls
%           -Brush_Creek_Fault.xls
%           -Shiperds_Fault_NW.xls
%           -Shiperds_Fault_SE.xls
%           -StressTensorWRV200.csv
%           -StressTensorWRV3km.csv
% 
% OUTPUT: Poly 3D Input and Output files named:
%           -WindRiver200_ul.in
%           -WindRiver200_ul.out
%           -WindRiver200_ll.in
%           -WindRiver200_ll.out
%           -WindRiver3km_ul.in
%           -WindRiver3km_ul.out
%           -WindRiver3km_ll.in
%           -WindRiver3km_ll.out
%
%
%
%
% NOTE: 
% - Based on original files drafted by J. Ole Kaven
% 
% - Note specific paths to the folder containg p3d and to the folder
% containing this mfile are specified for running p3d and saving .in and
% .out files respectively
% 
% 
% KEY functions written specifically for this modeling
%
% Other related functions
% - Delaunay2_5D 
% - p3din_FAULT_func_v1
% - PlotTriNormals
% - p3doutputreader_v04
%

clear all, close all

tic

%% 1. Define OBSERVATION GRID RANGES
% Generate observation grids in global coordinates.

% AREAL GRIDS: 2D

% Extent of WADGER thermal model
% User Coordinate System
x1o = 573353.110394;
x2o = 5055478.41079;
x3o = 0;
rot1 = 0;
rot2 = 0;
rot3 = 1.80496099950057;
CS_WADGER = [x1o, x2o, x3o, rot1, rot2, rot3, 123];% matrix used in p3din_FAULT_func_v1

% min/max values 1000ft spacing at 200m depth
minx = 0;  % min value of x
maxx = 30469.431059;  % max value of x
miny = 0;  % min value of y
maxy = 27727.162767; % max value of y
minz = -200;  % min value of z
maxz = -200;  % max value of z    
npx  = 101; % number of points corresponding to inc in each dimension
npy  = 92; % see also function: linspace
npz  = 1;
OBSgridWADGER200 = [minx miny minz maxx maxy maxz npx npy npz];% matrix used in p3din_FAULT_func_v1

% min/max values 1000ft spacing at 3000m depth
minx = 0;  % min value of x
maxx = 30469.431059;  % max value of x
miny = 0;  % min value of y
maxy = 27727.162767; % max value of y
minz = -3000;  % min value of z
maxz = -3000;  % max value of z    
npx  = 101; % number of points corresponding to inc in each dimension
npy  = 92; % see also function: linspace
npz  = 1;
OBSgridWADGER3km = [minx miny minz maxx maxy maxz npx npy npz];% matrix used in p3din_FAULT_func_v1

%% 2. Define Boundary Conditions to run

% depth to water table(meters)
dw = 20;

% import stress tensor(s)
% 200m
Sigma200 = importdata('StressTensorWRV200.csv',',');
d = .2;% depth km
Pp200 = (9.733*(d-(dw/1000)));
Pf200 = Pp200*1000000;% fluid pressure used in poly3D
% 3000m
Sigma3km = importdata('StressTensorWRV3km.csv',',');
d = 3;% depth km
Pp3km = (9.733*(d-(dw/1000)));
Pf3km = Pp3km*1000000;% fluid pressure used in poly3D

% Elastic Properties
nu = 0.25; % poisson's ratio
E = 30000000000; % Young's Modulus in Pa
     
    %% 3. IMPORT FAULTS
    
    % Big Butte Fault
    XYZbbf_ul = xlsread('Big_Butte_Fault_ul.xls','XYZbbf_ul','A2:C5000');
    tnbbf_ul = xlsread('Big_Butte_Fault_ul.xls','tnbbf_ul','A1:C5000');
    XYZbbf_ll = xlsread('Big_Butte_Fault_ll.xls','XYZbbf_ll','A2:C5000');
    tnbbf_ll = xlsread('Big_Butte_Fault_ll.xls','tnbbf_ll','A1:C5000');

    % Trout Creek Fault
    XYZtcfs_ul = xlsread('Trout_Creek_Fault_shallow_ul.xls','XYZtcfs_ul','A2:C5000');
    tntcfs_ul = xlsread('Trout_Creek_Fault_shallow_ul.xls','tntcfs_ul','A1:C5000');
    XYZtcfd_ul = xlsread('Trout_Creek_Fault_deep_ul.xls','XYZtcfd_ul','A2:C5000');
    tntcfd_ul = xlsread('Trout_Creek_Fault_deep_ul.xls','tntcfd_ul','A1:C5000');
    XYZtcfs_ll = xlsread('Trout_Creek_Fault_shallow_ll.xls','XYZtcfs_ll','A2:C5000');
    tntcfs_ll = xlsread('Trout_Creek_Fault_shallow_ll.xls','tntcfs_ll','A1:C5000');
    XYZtcfd_ll = xlsread('Trout_Creek_Fault_deep_ll.xls','XYZtcfd_ll','A2:C5000');
    tntcfd_ll = xlsread('Trout_Creek_Fault_deep_ll.xls','tntcfd_ll','A1:C5000');

    % Wind River Fault
    XYZwrf_ul = xlsread('Wind_River_Fault_ul.xls','XYZwrf_ul','A2:C20000');
    tnwrf_ul = xlsread('Wind_River_Fault_ul.xls','tnwrf_ul','A1:C20000');
    XYZwrf_ll = xlsread('Wind_River_Fault_ll.xls','XYZwrf_ll','A2:C20000');
    tnwrf_ll = xlsread('Wind_River_Fault_ll.xls','tnwrf_ll','A1:C20000');
    
    % Gate Creek Fault
    XYZgcf_ul = xlsread('Gate_Creek_Fault_ul.xls','XYZgcf_ul','A2:C5000');
    tngcf_ul = xlsread('Gate_Creek_Fault_ul.xls','tngcf_ul','A1:C5000');
    XYZgcf_ll = xlsread('Gate_Creek_Fault_ll.xls','XYZgcf_ll','A2:C5000');
    tngcf_ll = xlsread('Gate_Creek_Fault_ll.xls','tngcf_ll','A1:C5000');
    
    % WR West Fault
    XYZwrwf_ul = xlsread('WR_West_Fault_ul.xls','XYZwrwf_ul','A2:C500');
    tnwrwf_ul = xlsread('WR_West_Fault_ul.xls','tnwrwf_ul','A1:C500');
    XYZwrwf_ll = xlsread('WR_West_Fault_ll.xls','XYZwrwf_ll','A2:C500');
    tnwrwf_ll = xlsread('WR_West_Fault_ll.xls','tnwrwf_ll','A1:C500');
    
    % Wise Fault
    XYZwf_ul = xlsread('Wise_Fault_ul.xls','XYZwf_ul','A2:C500');
    tnwf_ul = xlsread('Wise_Fault_ul.xls','tnwf_ul','A1:C500');
    XYZwf_ll = xlsread('Wise_Fault_ll.xls','XYZwf_ll','A2:C500');
    tnwf_ll = xlsread('Wise_Fault_ll.xls','tnwf_ll','A1:C500');
    
    % Bunker Hill Fault
    XYZbhf_ul = xlsread('Bunker_Hill_Fault_ul.xls','XYZbhf_ul','A2:C500');
    tnbhf_ul = xlsread('Bunker_Hill_Fault_ul.xls','tnbhf_ul','A1:C500');
    XYZbhf_ll = xlsread('Bunker_Hill_Fault_ll.xls','XYZbhf_ll','A2:C500');
    tnbhf_ll = xlsread('Bunker_Hill_Fault_ll.xls','tnbhf_ll','A1:C500');
    
    % Bear Creek Fault
    XYZbcf_ul = xlsread('Bear_Creek_Fault_ul.xls','XYZbcf_ul','A2:C5000');
    tnbcf_ul = xlsread('Bear_Creek_Fault_ul.xls','tnbcf_ul','A1:C5000');
    XYZbcf_ll = xlsread('Bear_Creek_Fault_ll.xls','XYZbcf_ll','A2:C5000');
    tnbcf_ll = xlsread('Bear_Creek_Fault_ll.xls','tnbcf_ll','A1:C5000');
    
    % Brush Creek Fault
    XYZbrcf_ul = xlsread('Brush_Creek_Fault_ul.xls','XYZbrcf_ul','A2:C5000');
    tnbrcf_ul = xlsread('Brush_Creek_Fault_ul.xls','tnbrcf_ul','A1:C5000');
    XYZbrcf_ll = xlsread('Brush_Creek_Fault_ll.xls','XYZbrcf_ll','A2:C5000');
    tnbrcf_ll = xlsread('Brush_Creek_Fault_ll.xls','tnbrcf_ll','A1:C5000');
    
    % Shiperds Fault
    XYZsfNW_ll = xlsread('Shiperds_Fault_NW_ll.xls','XYZsfNW_ll','A2:C5000');
    tnsfNW_ll = xlsread('Shiperds_Fault_NW_ll.xls','tnsfNW_ll','A1:C5000');
    XYZsfSE_ll = xlsread('Shiperds_Fault_SE_ll.xls','XYZsfSE_ll','A2:C5000');
    tnsfSE_ll = xlsread('Shiperds_Fault_SE_ll.xls','tnsfSE_ll','A1:C5000');
    
    %% 4. RUN p3din_FAULT_v1.m to generate P3D input file and run P3D

    filename = 'WindRiver200_ul';
    path_in = strcat('InputOutputFiles/');
    filename_in  = [path_in,filename,'.in'];
    
        % p3din_FAULT_v1
        p3din_FAULT_func_v1_WRV_200m(E,nu,Sigma200,Pf200,filename_in,XYZbbf_ul,XYZtcfs_ul,XYZtcfd_ul,XYZwrf_ul,XYZgcf_ul,XYZwrwf_ul,XYZwf_ul,XYZbhf_ul,XYZbcf_ul,XYZbrcf_ul,XYZsfNW_ul,XYZsfSE_ul,tnbbf_ul,tntcfs_ul,tntcfd_ul,tnwrf_ul,tngcf_ul,tnwrwf_ul,tnwf_ul,tnbhf_ul,tnbcf_ul,tnbrcf_ul,tnsfNW_ul,tnsfSE_ul,CS_WADGER,OBSgridWADGER200)
    
        %%% Un-comment these lines to run Poly3D %%%
%         filename_out  = [path_in,filename,'.out'];
%         pcdloc = '/P3D/P3DinC1999/newpoly3d';
%         system([pcdloc,' -i ',filename_in,' -o ',filename_out])

    filename = 'WindRiver3km_ul';
    path_in = strcat('InputOutputFiles/');
    filename_in  = [path_in,filename,'.in'];
    
        % p3din_FAULT_v1
        p3din_FAULT_func_v1_WRV_3km(E,nu,Sigma3km,Pf3km,filename_in,XYZbbf_ul,XYZtcfs_ul,XYZtcfd_ul,XYZwrf_ul,XYZgcf_ul,XYZwrwf_ul,XYZwf_ul,XYZbhf_ul,XYZbcf_ul,XYZbrcf_ul,XYZsfNW_ul,XYZsfSE_ul,tnbbf_ul,tntcfs_ul,tntcfd_ul,tnwrf_ul,tngcf_ul,tnwrwf_ul,tnwf_ul,tnbhf_ul,tnbcf_ul,tnbrcf_ul,tnsfNW_ul,tnsfSE_ul,CS_WADGER,OBSgridWADGER3km)
    
        %%% Un-comment these lines to run Poly3D %%%
%         filename_out  = [path_in,filename,'.out'];
%         pcdloc = '/P3D/P3DinC1999/newpoly3d';
%         system([pcdloc,' -i ',filename_in,' -o ',filename_out])

    filename = 'WindRiver200_ll';
    path_in = strcat('InputOutputFiles/');
    filename_in  = [path_in,filename,'.in'];
    
        % p3din_FAULT_v1
        p3din_FAULT_func_v1_WRV_200m(E,nu,Sigma200,Pf200,filename_in,XYZbbf_ll,XYZtcfs_ll,XYZtcfd_ll,XYZwrf_ll,XYZgcf_ll,XYZwrwf_ll,XYZwf_ll,XYZbhf_ll,XYZbcf_ll,XYZbrcf_ll,XYZsfNW_ll,XYZsfSE_ll,tnbbf_ll,tntcfs_ll,tntcfd_ll,tnwrf_ll,tngcf_ll,tnwrwf_ll,tnwf_ll,tnbhf_ll,tnbcf_ll,tnbrcf_ll,tnsfNW_ll,tnsfSE_ll,CS_WADGER,OBSgridWADGER200)
    
        %%% Un-comment these lines to run Poly3D %%%
%         filename_out  = [path_in,filename,'.out'];
%         pcdloc = '/P3D/P3DinC1999/newpoly3d';
%         system([pcdloc,' -i ',filename_in,' -o ',filename_out])

    filename = 'WindRiver3km_ll';
    path_in = strcat('InputOutputFiles/');
    filename_in  = [path_in,filename,'.in'];
    
        % p3din_FAULT_v1
        p3din_FAULT_func_v1_WRV_3km(E,nu,Sigma3km,Pf3km,filename_in,XYZbbf_ll,XYZtcfs_ll,XYZtcfd_ll,XYZwrf_ll,XYZgcf_ll,XYZwrwf_ll,XYZwf_ll,XYZbhf_ll,XYZbcf_ll,XYZbrcf_ll,XYZsfNW_ll,XYZsfSE_ll,tnbbf_ll,tntcfs_ll,tntcfd_ll,tnwrf_ll,tngcf_ll,tnwrwf_ll,tnwf_ll,tnbhf_ll,tnbcf_ll,tnbrcf_ll,tnsfNW_ll,tnsfSE_ll,CS_WADGER,OBSgridWADGER3km)
    
        %%% Un-comment these lines to run Poly3D %%%
%         filename_out  = [path_in,filename,'.out'];
%         pcdloc = '/P3D/P3DinC1999/newpoly3d';
%         system([pcdloc,' -i ',filename_in,' -o ',filename_out])

toc