% WRV_PermeabilityModel_200m.m
%
% AUTHOR:           Michael Swyer
% DATE CREATED:     8/3/2015
% DATE MODIFIED:    
% VERSION:          v.1
%
% PURPOSE:
%   Read Poly3D .out file and process data for permeability potential
%         
% PURPOSE OF MODIFICATION:
%
% INPUT: Poly3D output file
%           WindRiver200m.out
% 
% OUTPUT:
%   fault/stress model outputs:
%           -FAULT_GRID: x, y, z, slip tendency, dilation tendency, displacement(m), displacement gradient(m/m)
%           -STRESS_GRID: x, y, z, maximum Coulomb shear stress(Pa), sigma3(Pa)
%   Permeability potential layers:
%           -Fault.sliptendency: x, y, z, slip tendency
%           -Fault.dilationtendency: x, y, z, dilation tendency
%           -Fault.displacement: x, y, z, normalized displacement
%           -Fault.displacementgradient: x, y, z, normalized displacement gradient
%           -Stress.MaximumCoulombShearStress: x, y, z, normalized maximum Coulomb shear stress
%           -Stress.Sigma3: x, y, z, normalized sigma 3
%
% NOTE: 
%
% KEY functions written specifically for this modeling
%
% Other related functions
% - p3doutputreader_v04
% - redblue

clear all;close all

filename = 'InputOutputFiles\WindRiver200.out';

out = p3doutputreader_v04(filename);
% Generates structured array including
%   FAULT OBJECTS
%   out.fault.xyz   = array of vertex locations
% 
%   out.fault.vert  = array of vertices
%                     [VERTNUM X1 X2 X3]
% 
%   out.fault.disp  = cell array contain displacements for each fault obj
%                     [ELT X1C X2C X3C B1 U1(+) U1(-) B2 U2(+) U2(-) B3 U3(+)]
%                     ELT = element number, for use in tri
%                     X1C, X2C, X3C = element centroid coordinates
%                     B1, B2, B3 are the burgers vectos components as
%                       (strike,dip,normal)
%                     Ui(+), Ui(-) = relative displacment at centroid
%
%   out.fault.tract = cell array contain tractions for each fault obj
%                     [ELT X1C X2C X3C T1 T2 T3]
%                     T1,T2,T3 are the traction components
%                       (strike,dip,normal)
%   out.fault.name  = cell array contain displacements for each fault obj
% 
%
%   OBSERVATION GRID
%   out.obs.xyz     = array containing the obs grid pts [X1,X2,X3]
%
%   out.obs.disp    = array containing displacements at obs pts
%                     [X1 X2 X3 U1 U2 U3]
%                     U1,U2,U3 = components of the displacement vector
%                     
%   out.obs.pstress = array containing principal stress and principal
%                     stress direcitons at obs pts
%                     [X1 X2 X3 N1 N2 N3 SIG1 N1 N2 N3 SIG2 N1 N2 N3 SIG3]
%                     SIG1,2,3 = principal stress components (tensoral
%                     convention) at each observation point
%                     N1,N2,N3 = principal stress direction vectors for the
%                       following principal stress in the array)
%
%   out.obs.stress  = array contain 
%                     [X1 X2 X3 SIG11 SIG22 SIG33 SIG12 SIG23 SIG13]
%                     SIG11,22,33,12,23,13 = stress tensor component at
%                     each observation point

Sigma200 = importdata('StressTensorWRV200.csv',',');
[V,PS200] = eig(Sigma200);% PS200 = eigenvalues as principal stresses

%% Slip/Dilation Tendency/Displacement/Displacement Gradient

%%% 200m %%%
% Trout Creek Fault
nvectcfs = xlsread('Trout_Creek_Fault_shallow.xls','nvectcfs','A2:C2000');
I = find(out.fault.disp{1,2}(:,4)<-90&out.fault.disp{1,2}(:,4)>-210);
% Tractions
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,2}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvectcfs(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvectcfs(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STtcfs(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTtcfs(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Disptcfs(i,1) = (out.fault.disp{1,2}(I(i),5)^2 + out.fault.disp{1,2}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STtcfs = STtcfs(I,1);
DTtcfs = DTtcfs(I,1);
Disptcfs = Disptcfs(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Disptcfs(i)/100;
    else
        dg(i,1) = abs(Disptcfs(i)-Disptcfs(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Disptcfs(i)/100;
for i=1:length(I)
    DGtcfs(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
        J(i,1) = find(Dobs==min(Dobs));
        J(i,2) = i;
end
% Find unique observation points and closest element center
Ltcfs(:,1) = unique(J(:,1));
for i=1:length(Ltcfs)
    I = find(J(:,1)==Ltcfs(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Ltcfs(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Ltcfs(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Ltcfs(i,2) = J(I(K),2);
end


% Wind River Fault
nvecwrf = xlsread('Wind_River_Fault.xls','nvecwrf','A2:C6000');
I = find(out.fault.disp{1,4}(:,4)<-90&out.fault.disp{1,4}(:,4)>-375);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,4}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecwrf(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwrf(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwrf(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwrf(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispwrf(i,1) = (out.fault.disp{1,4}(I(i),5)^2 + out.fault.disp{1,4}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STwrf = STwrf(I,1);
DTwrf = DTwrf(I,1);
Dispwrf = Dispwrf(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispwrf(i)/100;
    else
        dg(i,1) = abs(Dispwrf(i)-Dispwrf(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispwrf(i)/100;
for i=1:length(I)
    DGwrf(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lwrf(:,1) = unique(J(:,1));
for i=1:length(Lwrf)
    I = find(J(:,1)==Lwrf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lwrf(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lwrf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwrf(i,2) = J(I(K),2);
end


% Gate Creek Fault
nvecgcf = xlsread('Gate_Creek_Fault.xls','nvecgcf','A2:C6000');
I = find(out.fault.disp{1,5}(:,4)<-90&out.fault.disp{1,5}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,5}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecgcf(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecgcf(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STgcf(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTgcf(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispgcf(i,1) = (out.fault.disp{1,5}(I(i),5)^2 + out.fault.disp{1,5}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STgcf = STgcf(I,1);
DTgcf = DTgcf(I,1);
Dispgcf = Dispgcf(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispgcf(i)/100;
    else
        dg(i,1) = abs(Dispgcf(i)-Dispgcf(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispgcf(i)/100;
for i=1:length(I)
    DGgcf(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
        J(i,1) = find(Dobs==min(Dobs));
        J(i,2) = i;
end
% Find unique observation points and closest element center
Lgcf(:,1) = unique(J(:,1));
for i=1:length(Lgcf)
    I = find(J(:,1)==Lgcf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lgcf(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lgcf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lgcf(i,2) = J(I(K),2);
end


% Wind River West Fault
nvecwrwf = xlsread('WR_West_Fault.xls','nvecwrwf','A2:C6000');
I = find(out.fault.disp{1,6}(:,4)<-90&out.fault.disp{1,6}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,6}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecwrwf(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwrwf(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwrwf(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwrwf(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispwrwf(i,1) = (out.fault.disp{1,6}(I(i),5)^2 + out.fault.disp{1,6}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STwrwf = STwrwf(I,1);
DTwrwf = DTwrwf(I,1);
Dispwrwf = Dispwrwf(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispwrwf(i)/100;
    else
        dg(i,1) = abs(Dispwrwf(i)-Dispwrwf(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispwrwf(i)/100;
for i=1:length(I)
    DGwrwf(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lwrwf(:,1) = unique(J(:,1));
for i=1:length(Lwrwf)
    I = find(J(:,1)==Lwrwf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lwrwf(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lwrwf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwrwf(i,2) = J(I(K),2);
end


% Wise Fault
nvecwf = xlsread('Wise_Fault.xls','nvecwf','A2:C6000');
I = find(out.fault.disp{1,7}(:,4)<-90&out.fault.disp{1,7}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,7}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecwf(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwf(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwf(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwf(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispwf(i,1) = (out.fault.disp{1,7}(I(i),5)^2 + out.fault.disp{1,7}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STwf = STwf(I,1);
DTwf = DTwf(I,1);
Dispwf = Dispwf(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispwf(i)/100;
    else
        dg(i,1) = abs(Dispwf(i)-Dispwf(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispwf(i)/100;
for i=1:length(I)
    DGwf(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lwf(:,1) = unique(J(:,1));
for i=1:length(Lwf)
    I = find(J(:,1)==Lwf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lwf(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lwf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwf(i,2) = J(I(K),2);
end


% Bunker Hill Fault
nvecbhf = xlsread('Bunker_Hill_Fault.xls','nvecbhf','A2:C6000');
I = find(out.fault.disp{1,8}(:,4)<-90&out.fault.disp{1,8}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,8}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecbhf(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecbhf(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STbhf(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTbhf(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispbhf(i,1) = (out.fault.disp{1,8}(I(i),5)^2 + out.fault.disp{1,8}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STbhf = STbhf(I,1);
DTbhf = DTbhf(I,1);
Dispbhf = Dispbhf(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispbhf(i)/100;
    else
        dg(i,1) = abs(Dispbhf(i)-Dispbhf(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispbhf(i)/100;
for i=1:length(I)
    DGbhf(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lbhf(:,1) = unique(J(:,1));
for i=1:length(Lbhf)
    I = find(J(:,1)==Lbhf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lbhf(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lbhf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lbhf(i,2) = J(I(K),2);
end


% Bear Creek Fault
nvecbcf = xlsread('Bear_Creek_Fault.xls','nvecbcf','A2:C6000');
I = find(out.fault.disp{1,9}(:,4)<-90&out.fault.disp{1,9}(:,4)>-375);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,9}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecbcf(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecbcf(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STbcf(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTbcf(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispbcf(i,1) = (out.fault.disp{1,9}(I(i),5)^2 + out.fault.disp{1,9}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STbcf = STbcf(I,1);
DTbcf = DTbcf(I,1);
Dispbcf = Dispbcf(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispbcf(i)/100;
    else
        dg(i,1) = abs(Dispbcf(i)-Dispbcf(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispbcf(i)/100;
for i=1:length(I)
    DGbcf(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lbcf(:,1) = unique(J(:,1));
for i=1:length(Lbcf)
    I = find(J(:,1)==Lbcf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lbcf(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lbcf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lbcf(i,2) = J(I(K),2);
end


% Brush Creek Fault
nvecbrcf = xlsread('Brush_Creek_Fault.xls','nvecbrcf','A2:C6000');
I = find(out.fault.disp{1,10}(:,4)<-90&out.fault.disp{1,10}(:,4)>-375);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,10}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecbrcf(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecbrcf(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STbrcf(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTbrcf(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispbrcf(i,1) = (out.fault.disp{1,10}(I(i),5)^2 + out.fault.disp{1,10}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STbrcf = STbrcf(I,1);
DTbrcf = DTbrcf(I,1);
Dispbrcf = Dispbrcf(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispbrcf(i)/100;
    else
        dg(i,1) = abs(Dispbrcf(i)-Dispbrcf(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispbrcf(i)/100;
for i=1:length(I)
    DGbrcf(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lbrcf(:,1) = unique(J(:,1));
for i=1:length(Lbrcf)
    I = find(J(:,1)==Lbrcf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lbrcf(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lbrcf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lbrcf(i,2) = J(I(K),2);
end


% Shiperds Fault NW
nvecsfNW = xlsread('Shiperds_Fault_NW.xls','nvecsfNW','A2:C6000');
I = find(out.fault.disp{1,11}(:,4)<-90&out.fault.disp{1,11}(:,4)>-375);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,11}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecsfNW(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecsfNW(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STsfNW(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTsfNW(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    DispsfNW(i,1) = (out.fault.disp{1,11}(I(i),5)^2 + out.fault.disp{1,11}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STsfNW = STsfNW(I,1);
DTsfNW = DTsfNW(I,1);
DispsfNW = DispsfNW(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = DispsfNW(i)/100;
    else
        dg(i,1) = abs(DispsfNW(i)-DispsfNW(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = DispsfNW(i)/100;
for i=1:length(I)
    DGsfNW(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
LsfNW(:,1) = unique(J(:,1));
for i=1:length(LsfNW)
    I = find(J(:,1)==LsfNW(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(LsfNW(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(LsfNW(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    LsfNW(i,2) = J(I(K),2);
end


% Shiperds Fault SE
nvecsfSE = xlsread('Shiperds_Fault_SE.xls','nvecsfSE','A2:C6000');
I = find(out.fault.disp{1,12}(:,4)<-90&out.fault.disp{1,12}(:,4)>-375);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,12}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecsfSE(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecsfSE(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STsfSE(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTsfSE(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    DispsfSE(i,1) = (out.fault.disp{1,12}(I(i),5)^2 + out.fault.disp{1,12}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STsfSE = STsfSE(I,1);
DTsfSE = DTsfSE(I,1);
DispsfSE = DispsfSE(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = DispsfSE(i)/100;
    else
        dg(i,1) = abs(DispsfSE(i)-DispsfSE(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = DispsfSE(i)/100;
for i=1:length(I)
    DGsfSE(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
LsfSE(:,1) = unique(J(:,1));
for i=1:length(LsfSE)
    I = find(J(:,1)==LsfSE(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(LsfSE(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(LsfSE(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    LsfSE(i,2) = J(I(K),2);
end


% Rock Creek Fault
datarcf = importdata('Rock_Creek_Fault_surfacepoints.csv',',');
% Normal Vectors --> Slip/Dilation Tendencies
for i=2:length(datarcf.data)
    x1 = datarcf.data(i-1,1);x2 = datarcf.data(i,1);
    y1 = datarcf.data(i-1,2);y2 = datarcf.data(i,2);
    l = ((x2-x1)^2+(y2-y1)^2)^.5;
    nvec(1,1) = (y2-y1)/l;
    nvec(2,1) = -(x2-x1)/l;
    nvec(3,1) = 0;
    T = Sigma200*nvec;% Tractions
    Tn = -T'*nvec;% Normal Tractions
    Tmag = (T(1)^2 + T(2)^2 + T(3)^2)^(1/2);% Traction Magnitudes
    DC = Tn/Tmag;% Direction Cosines
    theta = acos(DC);% Traction angle from normal vector
    Ts = Tmag*sin(theta);% Shear Tractions
    STrcf(i-1,1) = Ts/Tn;% Slip Tendencies
    DTrcf(i-1,1) = ((-PS200(1,1))-(Tn))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    XYrcf(i-1,1) = x1;XYrcf(i-1,2) = y1;% XY points
end
Disprcf = zeros(length(XYrcf),1);
DGrcf = zeros(length(XYrcf),1);
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(XYrcf)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYrcf(i,1)-out.obs.xyz(j,1))^2 + (XYrcf(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lrcf(:,1) = unique(J(:,1));
for i=1:length(Lrcf)
    I = find(J(:,1)==Lrcf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYrcf(J(I(j),2),1)-out.obs.xyz(Lrcf(i),1))^2 + (XYrcf(J(I(j),2),2)-out.obs.xyz(Lrcf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lrcf(i,2) = J(I(K),2);
end

%% combine fault layers
L = [Ltcfs;Lwrf;Lgcf;Lwrwf;Lwf;Lbhf;Lbcf;Lbrcf;LsfNW;LsfSE;Lrcf];
STall = [STtcfs(Ltcfs(:,2));STwrf(Lwrf(:,2));STgcf(Lgcf(:,2));STwrwf(Lwrwf(:,2));STwf(Lwf(:,2));STbhf(Lbhf(:,2));STbcf(Lbcf(:,2));STbrcf(Lbrcf(:,2));STsfNW(LsfNW(:,2));STsfSE(LsfSE(:,2));STrcf(Lrcf(:,2))];
DTall = [DTtcfs(Ltcfs(:,2));DTwrf(Lwrf(:,2));DTgcf(Lgcf(:,2));DTwrwf(Lwrwf(:,2));DTwf(Lwf(:,2));DTbhf(Lbhf(:,2));DTbcf(Lbcf(:,2));DTbrcf(Lbrcf(:,2));DTsfNW(LsfNW(:,2));DTsfSE(LsfSE(:,2));DTrcf(Lrcf(:,2))];
Dispall = [Disptcfs(Ltcfs(:,2));Dispwrf(Lwrf(:,2));Dispgcf(Lgcf(:,2));Dispwrwf(Lwrwf(:,2));Dispwf(Lwf(:,2));Dispbhf(Lbhf(:,2));Dispbcf(Lbcf(:,2));Dispbrcf(Lbrcf(:,2));DispsfNW(LsfNW(:,2));DispsfSE(LsfSE(:,2));Disprcf(Lrcf(:,2))];
DGall = [DGtcfs(Ltcfs(:,2));DGwrf(Lwrf(:,2));DGgcf(Lgcf(:,2));DGwrwf(Lwrwf(:,2));DGwf(Lwf(:,2));DGbhf(Lbhf(:,2));DGbcf(Lbcf(:,2));DGbrcf(Lbrcf(:,2));DGsfNW(LsfNW(:,2));DGsfSE(LsfSE(:,2));DGrcf(Lrcf(:,2))];

% FAULT_GRID --> X,Y,Z,slip tendency,dilation tendency,displacement gradient
FAULT_GRID(:,1:3) = out.obs.xyz(:,1:3);
for i=1:length(L)
        FAULT_GRID(L(i,1),4) = STall(i);
        FAULT_GRID(L(i,1),5) = DTall(i);
        FAULT_GRID(L(i,1),6) = Dispall(i);
        FAULT_GRID(L(i,1),7) = DGall(i);
end

%% Combine Stress layers

% calculate Sc and S3
for i=1:length(out.obs.pstress)
    Sc(i,1) = (((-out.obs.pstress(i,15))-(-out.obs.pstress(i,7)))/2)*(1+.6^2)^.5 - .6*(((-out.obs.pstress(i,15))+(-out.obs.pstress(i,7)))/2);
    S3(i,1) = (-out.obs.pstress(i,7));
    if find(L(:,1)==i)
        Sc(i,1) = 0;
        S3(i,1) = 0;
    end
end

% extract stress values to compute means and standard deviations
k=1;
for i=1:length(Sc)
    if isnan(Sc(i))
    else
        ScReal(k,1) = Sc(i);
        S3Real(k,1) = S3(i);
        k=k+1;
    end
end

% Mean and Standard Deviation
% Sc
Scmean = mean(ScReal);
SigSc = std(ScReal);
% S3
S3mean = mean(S3Real);
SigS3 = std(S3Real);

% STRESS_GRID --> X,Y,Z,maximum Coulomb shear stress,Shmin
STRESS_GRID(:,1:3) = out.obs.xyz(:,1:3);
STRESS_GRID(:,4) = Sc;
STRESS_GRID(:,5) = S3;

%% Permeability Model Layer Normalization

% Fault Layers
% no normalization needed for slip/dilation tendency (0-1)
Fault.sliptendency(:,1:3) = FAULT_GRID(:,1:3);
Fault.sliptendency(:,4) = FAULT_GRID(:,4);
Fault.dilationtendency(:,1:3) = FAULT_GRID(:,1:3);
Fault.dilationtendency(:,4) = FAULT_GRID(:,5);
% displacement
Fault.displacement(:,1:3) = FAULT_GRID(:,1:3);
Fault.displacement(:,4) = FAULT_GRID(:,6)/max(FAULT_GRID(:,6));
% displacement gradient
Fault.displacementgradient(:,1:3) = FAULT_GRID(:,1:3);
Fault.displacementgradient(:,4) = FAULT_GRID(:,7)/max(FAULT_GRID(:,7));

% Stress Layers
% normalization between +/- X standard deviations
nsd = 3;% # of standard deviations
Stress.MaximumCoulombShearStress(:,1:3) = STRESS_GRID(:,1:3);
Stress.MaximumCoulombShearStress(:,4) = (STRESS_GRID(:,4)-(Scmean-nsd*SigSc))/(2*nsd*SigSc);
I = find(Stress.MaximumCoulombShearStress(:,4)<0);
Stress.MaximumCoulombShearStress(I,4) = 0;
I = find(Stress.MaximumCoulombShearStress(:,4)>1);
Stress.MaximumCoulombShearStress(I,4) = 1;
for i=1:length(L)
    Stress.MaximumCoulombShearStress(L(i,1),4) = 0;
end

% Inverse S3 values by adding 2*mean to negative values
nsd = 3;% # of standard deviations
Stress.Sigma3(:,1:3) = STRESS_GRID(:,1:3);
Stress.Sigma3(:,4) = -STRESS_GRID(:,5);
Stress.Sigma3(:,4) = (Stress.Sigma3(:,4)-(-S3mean-nsd*SigS3))/(2*nsd*SigS3);
I = find(Stress.Sigma3(:,4)<0);
Stress.Sigma3(I,4) = 0;
I = find(Stress.Sigma3(:,4)>1);
Stress.Sigma3(I,4) = 1;
for i=1:length(L)
    Stress.Sigma3(L(i,1),4) = 0;
end

%% FIGURES

figure
plot([1:numel(Sc)],Sc,'k-');ylabel('Sc')
hold on
plot([0 9292],[Scmean+nsd*SigSc Scmean+nsd*SigSc])
plot([0 9292],[Scmean-nsd*SigSc Scmean-nsd*SigSc])
figure
plot([1:numel(S3)],S3,'k-');ylabel('Shmin')
hold on
plot([0 9292],[S3mean+nsd*SigS3 S3mean+nsd*SigS3])
plot([0 9292],[S3mean-nsd*SigS3 S3mean-nsd*SigS3])

figure
plot([1:numel(Stress.MaximumCoulombShearStress(:,4))],Stress.MaximumCoulombShearStress(:,4),'k.');ylabel('Sc favorability')
figure
plot([1:numel(Stress.Sigma3(:,4))],Stress.Sigma3(:,4),'k.');ylabel('Shmin favorability')

% grid data for contour plots
for j=0:91
for i=0:100
    X(1+i,1+j) = out.obs.xyz((1+i)+101*j,1);
    Y(1+i,1+j) = out.obs.xyz((1+i)+101*j,2);
    ScXY(1+i,1+j) = ((((-out.obs.pstress((1+i)+101*j,15))-(-out.obs.pstress((1+i)+101*j,7)))/2)*(1+.6^2)^.5 - .6*(((-out.obs.pstress((1+i)+101*j,15))+(-out.obs.pstress((1+i)+101*j,7)))/2))/1000000;
    S3XY(1+i,1+j) = (-out.obs.pstress((1+i)+101*j,7))/1000000;
    meanstressXY(1+i,1+j) = ((-out.obs.pstress((1+i)+101*j,7))+(-out.obs.pstress((1+i)+101*j,15)))/2/1000000;
    STXY(1+i,1+j) = FAULT_GRID((1+i)+101*j,4);
    DTXY(1+i,1+j) = FAULT_GRID((1+i)+101*j,5);
    DXY(1+i,1+j) = FAULT_GRID((1+i)+101*j,6);
    DGXY(1+i,1+j) = FAULT_GRID((1+i)+101*j,7);
    if find(L(:,1)==((1+i)+101*j))
        ScXY(1+i,1+j) = NaN;
        S3XY(1+i,1+j) = NaN;
    end
end
end

% Sc contour intervals
Vm = [(Scmean-nsd*SigSc)/1000000:.1:(Scmean+nsd*SigSc)/1000000];
figure
contourf(X,Y,ScXY,Vm)
hold on
contour(X,Y,ScXY,Vm)
c=colorbar;
set(get(c,'ylabel'),'String','Sc(MPa)','Fontsize',14);
caxis([(Scmean-nsd*SigSc)/1000000 (Scmean+nsd*SigSc)/1000000]);
colormap(redblue);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)

% S3 contour intervals
Vm = [(S3mean-nsd*SigS3)/1000000:.1:(S3mean+nsd*SigS3)/1000000];
figure
contourf(X,Y,S3XY,Vm)
hold on
contour(X,Y,S3XY,Vm)
c=colorbar;
set(get(c,'ylabel'),'String','Sigma3(MPa)','Fontsize',14);
caxis([(S3mean-nsd*SigS3)/1000000 (S3mean+nsd*SigS3)/1000000]);
colormap(redblue);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)

% slip tendency
figure
contourf(X,Y,STXY)
hold on
contour(X,Y,STXY)
c=colorbar;
set(get(c,'ylabel'),'String','Slip Tendency','Fontsize',14);
colormap(redblue);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)

% dilation tendency
figure
contourf(X,Y,DTXY)
hold on
contour(X,Y,DTXY)
c=colorbar;
set(get(c,'ylabel'),'String','Dilation Tendency','Fontsize',14);
colormap(redblue);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)

% displacement
figure
contourf(X,Y,DXY)
hold on
contour(X,Y,DXY)
c=colorbar;
set(get(c,'ylabel'),'String','Displacement(m)','Fontsize',14);
colormap(redblue);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)

% displacement gradient
figure
Vm = [0:.00005:.005];
contourf(X,Y,DGXY,Vm)
hold on
contour(X,Y,DGXY,Vm)
set(get(c,'ylabel'),'String','Displacement Gradient(m/m)','Fontsize',14);
colormap(redblue);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)