% WRV_Sensitivity_200m.m
%
% AUTHOR:           Michael Swyer
% DATE CREATED:     9/2/2015
% DATE MODIFIED:    
% VERSION:          v.1
%
% PURPOSE:
%   Read Poly3D .out file and process data for permeability potential
%   sensitivity
%         
% PURPOSE OF MODIFICATION:
%
% INPUT: Poly3D output files
%           -MtStHelens200m_ul.out
%           -MtStHelens200m_ll.out
% 
% OUTPUT:
%   fault/stress model sensitivity outputs:
%           -FAULT_GRID: x, y, z, slip tendency, dilation tendency, displacement(m), displacement gradient(m/m)
%           -STRESS_GRID: x, y, z, maximum Coulomb shear stress(Pa), sigma3(Pa)
%   Permeability potential sensitivity layers:
%           -Fault.sliptendency: x, y, z, slip tendency
%           -Fault.dilationtendency: x, y, z, dilation tendency
%           -Fault.displacement: x, y, z, normalized displacement
%           -Fault.displacementgradient: x, y, z, normalized displacement gradient
%           -Stress.MaximumCoulombShearStress: x, y, z, normalized maximum Coulomb shear stress
%           -Stress.Sigma3: x, y, z, normalized sigma 3
%
% NOTE: 
%
% KEY functions written specifically for this modeling
%
% Other related functions
% - p3doutputreader_v04

clear all;close all

filename = 'InputOutputFiles\WindRiver200_ul.out';
out1 = p3doutputreader_v04(filename);
filename = 'InputOutputFiles\WindRiver200_ll.out';
out2 = p3doutputreader_v04(filename);
% Generates structured array including
%   FAULT OBJECTS
%   out.fault.xyz   = array of vertex locations
% 
%   out.fault.vert  = array of vertices
%                     [VERTNUM X1 X2 X3]
% 
%   out.fault.disp  = cell array contain displacements for each fault obj
%                     [ELT X1C X2C X3C B1 U1(+) U1(-) B2 U2(+) U2(-) B3 U3(+)]
%                     ELT = element number, for use in tri
%                     X1C, X2C, X3C = element centroid coordinates
%                     B1, B2, B3 are the burgers vectos components as
%                       (strike,dip,normal)
%                     Ui(+), Ui(-) = relative displacment at centroid
%
%   out.fault.tract = cell array contain tractions for each fault obj
%                     [ELT X1C X2C X3C T1 T2 T3]
%                     T1,T2,T3 are the traction components
%                       (strike,dip,normal)
%   out.fault.name  = cell array contain displacements for each fault obj
% 
%
%   OBSERVATION GRID
%   out.obs.xyz     = array containing the obs grid pts [X1,X2,X3]
%
%   out.obs.disp    = array containing displacements at obs pts
%                     [X1 X2 X3 U1 U2 U3]
%                     U1,U2,U3 = components of the displacement vector
%                     
%   out.obs.pstress = array containing principal stress and principal
%                     stress direcitons at obs pts
%                     [X1 X2 X3 N1 N2 N3 SIG1 N1 N2 N3 SIG2 N1 N2 N3 SIG3]
%                     SIG1,2,3 = principal stress components (tensoral
%                     convention) at each observation point
%                     N1,N2,N3 = principal stress direction vectors for the
%                       following principal stress in the array)
%
%   out.obs.stress  = array contain 
%                     [X1 X2 X3 SIG11 SIG22 SIG33 SIG12 SIG23 SIG13]
%                     SIG11,22,33,12,23,13 = stress tensor component at
%                     each observation point

Sigma200 = importdata('StressTensorWRV200.csv',',');
[V,PS200] = eig(Sigma200);% PS200 = eigenvalues as principal stresses

%% Slip/Dilation Tendency/Displacement/Displacement Gradient

%%% 200m %%%
% Trout Creek Fault
nvectcfs_ul = xlsread('Trout_Creek_Fault_shallow_ul.xls','nvectcfs_ul','A2:C2000');
% upper residuals
I = find(out1.fault.disp{1,2}(:,4)<-90&out1.fault.disp{1,2}(:,4)>-210);
% Tractions
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,2}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvectcfs_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvectcfs_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STtcfs_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTtcfs_ul(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Disptcfs_ul(i,1) = (out1.fault.disp{1,2}(I(i),5)^2 + out1.fault.disp{1,2}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STtcfs_ul = STtcfs_ul(I,1);
DTtcfs_ul = DTtcfs_ul(I,1);
Disptcfs_ul = Disptcfs_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Disptcfs_ul(i)/100;
    else
        dg(i,1) = abs(Disptcfs_ul(i)-Disptcfs_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Disptcfs_ul(i)/100;
for i=1:length(I)
    DGtcfs_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
        J(i,1) = find(Dobs==min(Dobs));
        J(i,2) = i;
end
% Find unique observation points and closest element center
Ltcfs_ul(:,1) = unique(J(:,1));
for i=1:length(Ltcfs_ul)
    I = find(J(:,1)==Ltcfs_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Ltcfs_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Ltcfs_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Ltcfs_ul(i,2) = J(I(K),2);
end
% lower residuals
nvectcfs_ll = xlsread('Trout_Creek_Fault_shallow_ll.xls','nvectcfs_ll','A2:C2000');
I = find(out2.fault.disp{1,2}(:,4)<-90&out2.fault.disp{1,2}(:,4)>-210);
% Tractions
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,2}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvectcfs_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvectcfs_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STtcfs_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTtcfs_ll(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Disptcfs_ll(i,1) = (out2.fault.disp{1,2}(I(i),5)^2 + out2.fault.disp{1,2}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STtcfs_ll = STtcfs_ll(I,1);
DTtcfs_ll = DTtcfs_ll(I,1);
Disptcfs_ll = Disptcfs_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Disptcfs_ll(i)/100;
    else
        dg(i,1) = abs(Disptcfs_ll(i)-Disptcfs_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Disptcfs_ll(i)/100;
for i=1:length(I)
    DGtcfs_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
        J(i,1) = find(Dobs==min(Dobs));
        J(i,2) = i;
end
% Find unique observation points and closest element center
Ltcfs_ll(:,1) = unique(J(:,1));
for i=1:length(Ltcfs_ll)
    I = find(J(:,1)==Ltcfs_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Ltcfs_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Ltcfs_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Ltcfs_ll(i,2) = J(I(K),2);
end


% Wind River Fault
nvecwrf_ul = xlsread('Wind_River_Fault_ul.xls','nvecwrf_ul','A2:C6000');
% upper residuals
I = find(out1.fault.disp{1,4}(:,4)<-90&out1.fault.disp{1,4}(:,4)>-375);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,4}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecwrf_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwrf_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwrf_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwrf_ul(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispwrf_ul(i,1) = (out1.fault.disp{1,4}(I(i),5)^2 + out1.fault.disp{1,4}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STwrf_ul = STwrf_ul(I,1);
DTwrf_ul = DTwrf_ul(I,1);
Dispwrf_ul = Dispwrf_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispwrf_ul(i)/100;
    else
        dg(i,1) = abs(Dispwrf_ul(i)-Dispwrf_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispwrf_ul(i)/100;
for i=1:length(I)
    DGwrf_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lwrf_ul(:,1) = unique(J(:,1));
for i=1:length(Lwrf_ul)
    I = find(J(:,1)==Lwrf_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lwrf_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lwrf_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwrf_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecwrf_ll = xlsread('Wind_River_Fault_ll.xls','nvecwrf_ll','A2:C6000');
I = find(out2.fault.disp{1,4}(:,4)<-90&out2.fault.disp{1,4}(:,4)>-375);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,4}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecwrf_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwrf_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwrf_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwrf_ll(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispwrf_ll(i,1) = (out2.fault.disp{1,4}(I(i),5)^2 + out2.fault.disp{1,4}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STwrf_ll = STwrf_ll(I,1);
DTwrf_ll = DTwrf_ll(I,1);
Dispwrf_ll = Dispwrf_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispwrf_ll(i)/100;
    else
        dg(i,1) = abs(Dispwrf_ll(i)-Dispwrf_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispwrf_ll(i)/100;
for i=1:length(I)
    DGwrf_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lwrf_ll(:,1) = unique(J(:,1));
for i=1:length(Lwrf_ll)
    I = find(J(:,1)==Lwrf_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lwrf_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lwrf_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwrf_ll(i,2) = J(I(K),2);
end


% Gate Creek Fault
nvecgcf_ul = xlsread('Gate_Creek_Fault_ul.xls','nvecgcf_ul','A2:C6000');
% upper residuals
I = find(out1.fault.disp{1,5}(:,4)<-90&out1.fault.disp{1,5}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,5}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecgcf_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecgcf_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STgcf_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTgcf_ul(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispgcf_ul(i,1) = (out1.fault.disp{1,5}(I(i),5)^2 + out1.fault.disp{1,5}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STgcf_ul = STgcf_ul(I,1);
DTgcf_ul = DTgcf_ul(I,1);
Dispgcf_ul = Dispgcf_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispgcf_ul(i)/100;
    else
        dg(i,1) = abs(Dispgcf_ul(i)-Dispgcf_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispgcf_ul(i)/100;
for i=1:length(I)
    DGgcf_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
        J(i,1) = find(Dobs==min(Dobs));
        J(i,2) = i;
end
% Find unique observation points and closest element center
Lgcf_ul(:,1) = unique(J(:,1));
for i=1:length(Lgcf_ul)
    I = find(J(:,1)==Lgcf_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lgcf_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lgcf_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lgcf_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecgcf_ll = xlsread('Gate_Creek_Fault_ll.xls','nvecgcf_ll','A2:C6000');
I = find(out2.fault.disp{1,5}(:,4)<-90&out2.fault.disp{1,5}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,5}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecgcf_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecgcf_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STgcf_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTgcf_ll(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispgcf_ll(i,1) = (out2.fault.disp{1,5}(I(i),5)^2 + out2.fault.disp{1,5}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STgcf_ll = STgcf_ll(I,1);
DTgcf_ll = DTgcf_ll(I,1);
Dispgcf_ll = Dispgcf_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispgcf_ll(i)/100;
    else
        dg(i,1) = abs(Dispgcf_ll(i)-Dispgcf_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispgcf_ll(i)/100;
for i=1:length(I)
    DGgcf_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
        J(i,1) = find(Dobs==min(Dobs));
        J(i,2) = i;
end
% Find unique observation points and closest element center
Lgcf_ll(:,1) = unique(J(:,1));
for i=1:length(Lgcf_ll)
    I = find(J(:,1)==Lgcf_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lgcf_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lgcf_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lgcf_ll(i,2) = J(I(K),2);
end


% Wind River West Fault
nvecwrwf_ul = xlsread('WR_West_Fault_ul.xls','nvecwrwf_ul','A2:C6000');
% upper residuals
I = find(out1.fault.disp{1,6}(:,4)<-90&out1.fault.disp{1,6}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,6}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecwrwf_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwrwf_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwrwf_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwrwf_ul(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispwrwf_ul(i,1) = (out1.fault.disp{1,6}(I(i),5)^2 + out1.fault.disp{1,6}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STwrwf_ul = STwrwf_ul(I,1);
DTwrwf_ul = DTwrwf_ul(I,1);
Dispwrwf_ul = Dispwrwf_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispwrwf_ul(i)/100;
    else
        dg(i,1) = abs(Dispwrwf_ul(i)-Dispwrwf_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispwrwf_ul(i)/100;
for i=1:length(I)
    DGwrwf_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lwrwf_ul(:,1) = unique(J(:,1));
for i=1:length(Lwrwf_ul)
    I = find(J(:,1)==Lwrwf_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lwrwf_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lwrwf_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwrwf_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecwrwf_ll = xlsread('WR_West_Fault_ll.xls','nvecwrwf_ll','A2:C6000');
I = find(out2.fault.disp{1,6}(:,4)<-90&out2.fault.disp{1,6}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,6}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecwrwf_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwrwf_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwrwf_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwrwf_ll(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispwrwf_ll(i,1) = (out2.fault.disp{1,6}(I(i),5)^2 + out2.fault.disp{1,6}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STwrwf_ll = STwrwf_ll(I,1);
DTwrwf_ll = DTwrwf_ll(I,1);
Dispwrwf_ll = Dispwrwf_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispwrwf_ll(i)/100;
    else
        dg(i,1) = abs(Dispwrwf_ll(i)-Dispwrwf_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispwrwf_ll(i)/100;
for i=1:length(I)
    DGwrwf_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lwrwf_ll(:,1) = unique(J(:,1));
for i=1:length(Lwrwf_ll)
    I = find(J(:,1)==Lwrwf_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lwrwf_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lwrwf_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwrwf_ll(i,2) = J(I(K),2);
end


% Wise Fault
nvecwf_ul = xlsread('Wise_Fault_ul.xls','nvecwf_ul','A2:C6000');
% upper residuals
I = find(out1.fault.disp{1,7}(:,4)<-90&out1.fault.disp{1,7}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,7}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecwf_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwf_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwf_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwf_ul(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispwf_ul(i,1) = (out1.fault.disp{1,7}(I(i),5)^2 + out1.fault.disp{1,7}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STwf_ul = STwf_ul(I,1);
DTwf_ul = DTwf_ul(I,1);
Dispwf_ul = Dispwf_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispwf_ul(i)/100;
    else
        dg(i,1) = abs(Dispwf_ul(i)-Dispwf_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispwf_ul(i)/100;
for i=1:length(I)
    DGwf_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lwf_ul(:,1) = unique(J(:,1));
for i=1:length(Lwf_ul)
    I = find(J(:,1)==Lwf_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lwf_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lwf_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwf_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecwf_ll = xlsread('Wise_Fault_ll.xls','nvecwf_ll','A2:C6000');
I = find(out2.fault.disp{1,7}(:,4)<-90&out2.fault.disp{1,7}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,7}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecwf_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwf_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwf_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwf_ll(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispwf_ll(i,1) = (out2.fault.disp{1,7}(I(i),5)^2 + out2.fault.disp{1,7}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STwf_ll = STwf_ll(I,1);
DTwf_ll = DTwf_ll(I,1);
Dispwf_ll = Dispwf_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispwf_ll(i)/100;
    else
        dg(i,1) = abs(Dispwf_ll(i)-Dispwf_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispwf_ll(i)/100;
for i=1:length(I)
    DGwf_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lwf_ll(:,1) = unique(J(:,1));
for i=1:length(Lwf_ll)
    I = find(J(:,1)==Lwf_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lwf_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lwf_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwf_ll(i,2) = J(I(K),2);
end


% Bunker Hill Fault
nvecbhf_ul = xlsread('Bunker_Hill_Fault_ul.xls','nvecbhf_ul','A2:C6000');
% upper residuals
I = find(out1.fault.disp{1,8}(:,4)<-90&out1.fault.disp{1,8}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,8}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecbhf_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecbhf_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STbhf_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTbhf_ul(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispbhf_ul(i,1) = (out1.fault.disp{1,8}(I(i),5)^2 + out1.fault.disp{1,8}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STbhf_ul = STbhf_ul(I,1);
DTbhf_ul = DTbhf_ul(I,1);
Dispbhf_ul = Dispbhf_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispbhf_ul(i)/100;
    else
        dg(i,1) = abs(Dispbhf_ul(i)-Dispbhf_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispbhf_ul(i)/100;
for i=1:length(I)
    DGbhf_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lbhf_ul(:,1) = unique(J(:,1));
for i=1:length(Lbhf_ul)
    I = find(J(:,1)==Lbhf_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lbhf_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lbhf_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lbhf_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecbhf_ll = xlsread('Bunker_Hill_Fault_ll.xls','nvecbhf_ll','A2:C6000');
I = find(out2.fault.disp{1,8}(:,4)<-90&out2.fault.disp{1,8}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,8}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecbhf_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecbhf_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STbhf_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTbhf_ll(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispbhf_ll(i,1) = (out2.fault.disp{1,8}(I(i),5)^2 + out2.fault.disp{1,8}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STbhf_ll = STbhf_ll(I,1);
DTbhf_ll = DTbhf_ll(I,1);
Dispbhf_ll = Dispbhf_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispbhf_ll(i)/100;
    else
        dg(i,1) = abs(Dispbhf_ll(i)-Dispbhf_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispbhf_ll(i)/100;
for i=1:length(I)
    DGbhf_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lbhf_ll(:,1) = unique(J(:,1));
for i=1:length(Lbhf_ll)
    I = find(J(:,1)==Lbhf_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lbhf_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lbhf_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lbhf_ll(i,2) = J(I(K),2);
end


% Bear Creek Fault
% upper residuals
nvecbcf_ul = xlsread('Bear_Creek_Fault_ul.xls','nvecbcf_ul','A2:C6000');
I = find(out1.fault.disp{1,9}(:,4)<-90&out1.fault.disp{1,9}(:,4)>-375);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,9}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecbcf_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecbcf_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STbcf_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTbcf_ul(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispbcf_ul(i,1) = (out1.fault.disp{1,9}(I(i),5)^2 + out1.fault.disp{1,9}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STbcf_ul = STbcf_ul(I,1);
DTbcf_ul = DTbcf_ul(I,1);
Dispbcf_ul = Dispbcf_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispbcf_ul(i)/100;
    else
        dg(i,1) = abs(Dispbcf_ul(i)-Dispbcf_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispbcf_ul(i)/100;
for i=1:length(I)
    DGbcf_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lbcf_ul(:,1) = unique(J(:,1));
for i=1:length(Lbcf_ul)
    I = find(J(:,1)==Lbcf_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lbcf_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lbcf_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lbcf_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecbcf_ll = xlsread('Bear_Creek_Fault_ll.xls','nvecbcf_ll','A2:C6000');
I = find(out2.fault.disp{1,9}(:,4)<-90&out2.fault.disp{1,9}(:,4)>-375);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,9}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecbcf_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecbcf_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STbcf_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTbcf_ll(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispbcf_ll(i,1) = (out2.fault.disp{1,9}(I(i),5)^2 + out2.fault.disp{1,9}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STbcf_ll = STbcf_ll(I,1);
DTbcf_ll = DTbcf_ll(I,1);
Dispbcf_ll = Dispbcf_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispbcf_ll(i)/100;
    else
        dg(i,1) = abs(Dispbcf_ll(i)-Dispbcf_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispbcf_ll(i)/100;
for i=1:length(I)
    DGbcf_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lbcf_ll(:,1) = unique(J(:,1));
for i=1:length(Lbcf_ll)
    I = find(J(:,1)==Lbcf_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lbcf_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lbcf_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lbcf_ll(i,2) = J(I(K),2);
end


% Brush Creek Fault
% upper residuals
nvecbrcf_ul = xlsread('Brush_Creek_Fault_ul.xls','nvecbrcf_ul','A2:C6000');
I = find(out1.fault.disp{1,10}(:,4)<-90&out1.fault.disp{1,10}(:,4)>-375);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,10}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecbrcf_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecbrcf_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STbrcf_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTbrcf_ul(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispbrcf_ul(i,1) = (out1.fault.disp{1,10}(I(i),5)^2 + out1.fault.disp{1,10}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STbrcf_ul = STbrcf_ul(I,1);
DTbrcf_ul = DTbrcf_ul(I,1);
Dispbrcf_ul = Dispbrcf_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispbrcf_ul(i)/100;
    else
        dg(i,1) = abs(Dispbrcf_ul(i)-Dispbrcf_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispbrcf_ul(i)/100;
for i=1:length(I)
    DGbrcf_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lbrcf_ul(:,1) = unique(J(:,1));
for i=1:length(Lbrcf_ul)
    I = find(J(:,1)==Lbrcf_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lbrcf_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lbrcf_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lbrcf_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecbrcf_ll = xlsread('Brush_Creek_Fault_ll.xls','nvecbrcf_ll','A2:C6000');
I = find(out1.fault.disp{1,10}(:,4)<-90&out1.fault.disp{1,10}(:,4)>-375);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,10}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecbrcf_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecbrcf_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STbrcf_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTbrcf_ll(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispbrcf_ll(i,1) = (out2.fault.disp{1,10}(I(i),5)^2 + out2.fault.disp{1,10}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STbrcf_ll = STbrcf_ll(I,1);
DTbrcf_ll = DTbrcf_ll(I,1);
Dispbrcf_ll = Dispbrcf_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispbrcf_ll(i)/100;
    else
        dg(i,1) = abs(Dispbrcf_ll(i)-Dispbrcf_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispbrcf_ll(i)/100;
for i=1:length(I)
    DGbrcf_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lbrcf_ll(:,1) = unique(J(:,1));
for i=1:length(Lbrcf_ll)
    I = find(J(:,1)==Lbrcf_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lbrcf_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lbrcf_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lbrcf_ll(i,2) = J(I(K),2);
end

% Shiperds Fault NW
% upper residuals
nvecsfNW_ul = xlsread('Shiperds_Fault_NW_ul.xls','nvecsfNW_ul','A2:C6000');
I = find(out1.fault.disp{1,11}(:,4)<-90&out1.fault.disp{1,11}(:,4)>-375);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,11}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecsfNW_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecsfNW_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STsfNW_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTsfNW_ul(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    DispsfNW_ul(i,1) = (out1.fault.disp{1,11}(I(i),5)^2 + out1.fault.disp{1,11}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STsfNW_ul = STsfNW_ul(I,1);
DTsfNW_ul = DTsfNW_ul(I,1);
DispsfNW_ul = DispsfNW_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = DispsfNW_ul(i)/100;
    else
        dg(i,1) = abs(DispsfNW_ul(i)-DispsfNW_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = DispsfNW_ul(i)/100;
for i=1:length(I)
    DGsfNW_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
LsfNW_ul(:,1) = unique(J(:,1));
for i=1:length(LsfNW_ul)
    I = find(J(:,1)==LsfNW_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(LsfNW_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(LsfNW_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    LsfNW_ul(i,2) = J(I(K),2);
end
% upper residuals
nvecsfNW_ll = xlsread('Shiperds_Fault_NW_ll.xls','nvecsfNW_ll','A2:C6000');
I = find(out2.fault.disp{1,11}(:,4)<-90&out2.fault.disp{1,11}(:,4)>-375);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,11}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecsfNW_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecsfNW_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STsfNW_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTsfNW_ll(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    DispsfNW_ll(i,1) = (out2.fault.disp{1,11}(I(i),5)^2 + out2.fault.disp{1,11}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STsfNW_ll = STsfNW_ll(I,1);
DTsfNW_ll = DTsfNW_ll(I,1);
DispsfNW_ll = DispsfNW_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = DispsfNW_ll(i)/100;
    else
        dg(i,1) = abs(DispsfNW_ll(i)-DispsfNW_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = DispsfNW_ll(i)/100;
for i=1:length(I)
    DGsfNW_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
LsfNW_ll(:,1) = unique(J(:,1));
for i=1:length(LsfNW_ll)
    I = find(J(:,1)==LsfNW_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(LsfNW_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(LsfNW_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    LsfNW_ll(i,2) = J(I(K),2);
end


% Shiperds Fault SE
% upper residuals
nvecsfSE_ul = xlsread('Shiperds_Fault_SE_ul.xls','nvecsfSE_ul','A2:C6000');
I = find(out1.fault.disp{1,12}(:,4)<-90&out1.fault.disp{1,12}(:,4)>-375);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,12}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecsfSE_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecsfSE_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STsfSE_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTsfSE_ul(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    DispsfSE_ul(i,1) = (out1.fault.disp{1,12}(I(i),5)^2 + out1.fault.disp{1,12}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STsfSE_ul = STsfSE_ul(I,1);
DTsfSE_ul = DTsfSE_ul(I,1);
DispsfSE_ul = DispsfSE_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = DispsfSE_ul(i)/100;
    else
        dg(i,1) = abs(DispsfSE_ul(i)-DispsfSE_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = DispsfSE_ul(i)/100;
for i=1:length(I)
    DGsfSE_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
LsfSE_ul(:,1) = unique(J(:,1));
for i=1:length(LsfSE_ul)
    I = find(J(:,1)==LsfSE_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(LsfSE_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(LsfSE_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    LsfSE_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecsfSE_ll = xlsread('Shiperds_Fault_SE_ll.xls','nvecsfSE_ll','A2:C6000');
I = find(out2.fault.disp{1,12}(:,4)<-90&out2.fault.disp{1,12}(:,4)>-375);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,12}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecsfSE_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecsfSE_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STsfSE_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTsfSE_ll(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    DispsfSE_ll(i,1) = (out2.fault.disp{1,12}(I(i),5)^2 + out2.fault.disp{1,12}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STsfSE_ll = STsfSE_ll(I,1);
DTsfSE_ll = DTsfSE_ll(I,1);
DispsfSE_ll = DispsfSE_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = DispsfSE_ll(i)/100;
    else
        dg(i,1) = abs(DispsfSE_ll(i)-DispsfSE_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = DispsfSE_ll(i)/100;
for i=1:length(I)
    DGsfSE_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
LsfSE_ll(:,1) = unique(J(:,1));
for i=1:length(LsfSE_ll)
    I = find(J(:,1)==LsfSE_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(LsfSE_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(LsfSE_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    LsfSE_ll(i,2) = J(I(K),2);
end


% Rock Creek Fault
datarcf = importdata('Rock_Creek_Fault_surfacepoints.csv',',');
% Normal Vectors --> Slip/Dilation Tendencies
for i=2:length(datarcf.data)
    x1 = datarcf.data(i-1,1);x2 = datarcf.data(i,1);
    y1 = datarcf.data(i-1,2);y2 = datarcf.data(i,2);
    l = ((x2-x1)^2+(y2-y1)^2)^.5;
    nvec(1,1) = (y2-y1)/l;
    nvec(2,1) = -(x2-x1)/l;
    nvec(3,1) = 0;
    T = Sigma200*nvec;% Tractions
    Tn = -T'*nvec;% Normal Tractions
    Tmag = (T(1)^2 + T(2)^2 + T(3)^2)^(1/2);% Traction Magnitudes
    DC = Tn/Tmag;% Direction Cosines
    theta = acos(DC);% Traction angle from normal vector
    Ts = Tmag*sin(theta);% Shear Tractions
    STrcf_ul(i-1,1) = Ts/Tn;% Slip Tendencies
    DTrcf_ul(i-1,1) = ((-PS200(1,1))-(Tn))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    XYrcf(i-1,1) = x1;XYrcf(i-1,2) = y1;% XY points
    nvec(1,1) = ((y2-y1)/l)*cos(20*(pi/180));
    nvec(2,1) = (-(x2-x1)/l)*cos(20*(pi/180));
    nvec(3,1) = ((((y2-y1)/l)^2+(-(x2-x1)/l)^2)^.5)*sin(20*(pi/180));
    T = Sigma200*nvec;% Tractions
    Tn = -T'*nvec;% Normal Tractions
    Tmag = (T(1)^2 + T(2)^2 + T(3)^2)^(1/2);% Traction Magnitudes
    DC = Tn/Tmag;% Direction Cosines
    theta = acos(DC);% Traction angle from normal vector
    Ts = Tmag*sin(theta);% Shear Tractions
    STrcf_ll(i-1,1) = Ts/Tn;% Slip Tendencies
    DTrcf_ll(i-1,1) = ((-PS200(1,1))-(Tn))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
end
Disprcf = zeros(length(XYrcf),1);
DGrcf = zeros(length(XYrcf),1);
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(XYrcf)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYrcf(i,1)-out1.obs.xyz(j,1))^2 + (XYrcf(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lrcf(:,1) = unique(J(:,1));
for i=1:length(Lrcf)
    I = find(J(:,1)==Lrcf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYrcf(J(I(j),2),1)-out1.obs.xyz(Lrcf(i),1))^2 + (XYrcf(J(I(j),2),2)-out1.obs.xyz(Lrcf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lrcf(i,2) = J(I(K),2);
end

%% combine fault layers

% upper residual
L_ul = [Ltcfs_ul;Lwrf_ul;Lgcf_ul;Lwrwf_ul;Lwf_ul;Lbhf_ul;Lbcf_ul;Lbrcf_ul;LsfNW_ul;LsfSE_ul;Lrcf];
STall_ul = [STtcfs_ul(Ltcfs_ul(:,2));STwrf_ul(Lwrf_ul(:,2));STgcf_ul(Lgcf_ul(:,2));STwrwf_ul(Lwrwf_ul(:,2));STwf_ul(Lwf_ul(:,2));STbhf_ul(Lbhf_ul(:,2));STbcf_ul(Lbcf_ul(:,2));STbrcf_ul(Lbrcf_ul(:,2));STsfNW_ul(LsfNW_ul(:,2));STsfSE_ul(LsfSE_ul(:,2));STrcf_ul(Lrcf(:,2))];
DTall_ul = [DTtcfs_ul(Ltcfs_ul(:,2));DTwrf_ul(Lwrf_ul(:,2));DTgcf_ul(Lgcf_ul(:,2));DTwrwf_ul(Lwrwf_ul(:,2));DTwf_ul(Lwf_ul(:,2));DTbhf_ul(Lbhf_ul(:,2));DTbcf_ul(Lbcf_ul(:,2));DTbrcf_ll(Lbrcf_ll(:,2));DTsfNW_ll(LsfNW_ll(:,2));DTsfSE_ll(LsfSE_ll(:,2));DTrcf_ul(Lrcf(:,2))];
Dispall_ul = [Disptcfs_ul(Ltcfs_ul(:,2));Dispwrf_ul(Lwrf_ul(:,2));Dispgcf_ul(Lgcf_ul(:,2));Dispwrwf_ul(Lwrwf_ul(:,2));Dispwf_ul(Lwf_ul(:,2));Dispbhf_ul(Lbhf_ul(:,2));Dispbcf_ul(Lbcf_ul(:,2));Dispbrcf_ul(Lbrcf_ul(:,2));DispsfNW_ul(LsfNW_ul(:,2));DispsfSE_ul(LsfSE_ul(:,2));Disprcf(Lrcf(:,2))];
DGall_ul = [DGtcfs_ul(Ltcfs_ul(:,2));DGwrf_ul(Lwrf_ul(:,2));DGgcf_ul(Lgcf_ul(:,2));DGwrwf_ul(Lwrwf_ul(:,2));DGwf_ul(Lwf_ul(:,2));DGbhf_ul(Lbhf_ul(:,2));DGbcf_ul(Lbcf_ul(:,2));DGbrcf_ul(Lbrcf_ul(:,2));DGsfNW_ul(LsfNW_ul(:,2));DGsfSE_ul(LsfSE_ul(:,2));DGrcf(Lrcf(:,2))];

% lower residual
L_ll = [Ltcfs_ll;Lwrf_ll;Lgcf_ll;Lwrwf_ll;Lwf_ll;Lbhf_ll;Lbcf_ll;Lbrcf_ll;LsfNW_ll;LsfSE_ll;Lrcf];
STall_ll = [STtcfs_ll(Ltcfs_ll(:,2));STwrf_ll(Lwrf_ll(:,2));STgcf_ll(Lgcf_ll(:,2));STwrwf_ll(Lwrwf_ll(:,2));STwf_ll(Lwf_ll(:,2));STbhf_ll(Lbhf_ll(:,2));STbcf_ll(Lbcf_ll(:,2));STbrcf_ll(Lbrcf_ll(:,2));STsfNW_ll(LsfNW_ll(:,2));STsfSE_ll(LsfSE_ll(:,2));STrcf_ul(Lrcf(:,2))];
DTall_ll = [DTtcfs_ll(Ltcfs_ll(:,2));DTwrf_ll(Lwrf_ll(:,2));DTgcf_ll(Lgcf_ll(:,2));DTwrwf_ll(Lwrwf_ll(:,2));DTwf_ll(Lwf_ll(:,2));DTbhf_ll(Lbhf_ll(:,2));DTbcf_ll(Lbcf_ll(:,2));DTbrcf_ll(Lbrcf_ll(:,2));DTsfNW_ll(LsfNW_ll(:,2));DTsfSE_ll(LsfSE_ll(:,2));DTrcf_ul(Lrcf(:,2))];
Dispall_ll = [Disptcfs_ll(Ltcfs_ll(:,2));Dispwrf_ll(Lwrf_ll(:,2));Dispgcf_ll(Lgcf_ll(:,2));Dispwrwf_ll(Lwrwf_ll(:,2));Dispwf_ll(Lwf_ll(:,2));Dispbhf_ll(Lbhf_ll(:,2));Dispbcf_ll(Lbcf_ll(:,2));Dispbrcf_ll(Lbrcf_ll(:,2));DispsfNW_ll(LsfNW_ll(:,2));DispsfSE_ll(LsfSE_ll(:,2));Disprcf(Lrcf(:,2))];
DGall_ll = [DGtcfs_ll(Ltcfs_ll(:,2));DGwrf_ll(Lwrf_ll(:,2));DGgcf_ll(Lgcf_ll(:,2));DGwrwf_ll(Lwrwf_ll(:,2));DGwf_ll(Lwf_ll(:,2));DGbhf_ll(Lbhf_ll(:,2));DGbcf_ll(Lbcf_ll(:,2));DGbrcf_ll(Lbrcf_ll(:,2));DGsfNW_ll(LsfNW_ll(:,2));DGsfSE_ll(LsfSE_ll(:,2));DGrcf(Lrcf(:,2))];


k=1;
for i=1:length(out1.obs.pstress)
    if find(L_ul(:,1)==i)
        if STall_ul(k)>1
            ST_ul(i,1) = 1;
        elseif STall_ul(k)<0
            ST_ul(i,1) = 0;
        else
            ST_ul(i,1) = STall_ul(k);
        end
        DT_ul(i,1) = DTall_ul(k);
        Disp_ul(i,1) = Dispall_ul(k);
        DG_ul(i,1) = DGall_ul(k);
        k=k+1;
    else
        ST_ul(i,1) = 0;
        DT_ul(i,1) = 0;
        Disp_ul(i,1) = 0;
        DG_ul(i,1) = 0;
    end
end
k=1;
for i=1:length(out2.obs.pstress)
    if find(L_ll(:,1)==i)
        if STall_ll(k)>1
            ST_ll(i,1) = 1;
        elseif STall_ll(k)<0
            ST_ll(i,1) = 0;
        else
            ST_ll(i,1) = STall_ll(k);
        end
        DT_ll(i,1) = DTall_ll(k);
        Disp_ll(i,1) = Dispall_ll(k);
        DG_ll(i,1) = DGall_ll(k);
        k=k+1;
    else
        ST_ll(i,1) = 0;
        DT_ll(i,1) = 0;
        Disp_ll(i,1) = 0;
        DG_ll(i,1) = 0;
    end
end

% FAULT_GRID --> X,Y,Z,slip tendency,dilation tendency,displacement gradient
for i=1:length(out1.obs.pstress)
    FAULT_GRID(i,1:3) = out1.obs.pstress(i,1:3);
end
FAULT_GRID(:,4) = abs(ST_ul-ST_ll);
FAULT_GRID(:,5) = abs(DT_ul-DT_ll);
FAULT_GRID(:,6) = abs(Disp_ul-Disp_ll);
FAULT_GRID(:,7) = abs(DG_ul-DG_ll);

%% Combine Stress layers

% calculate absolute difference of  Sc and S3 ul and ll
for i=1:length(out1.obs.pstress)
    Sc_ul(i,1) = (((-out1.obs.pstress(i,15))-(-out1.obs.pstress(i,7)))/2)*(1+.6^2)^.5 - .6*(((-out1.obs.pstress(i,15))+(-out1.obs.pstress(i,7)))/2);
    S3_ul(i,1) = (-out1.obs.pstress(i,7));
    if find(L_ul(:,1)==i)
        Sc_ul(i,1) = NaN;
        S3_ul(i,1) = NaN;
    end
end
for i=1:length(out2.obs.pstress)
    Sc_ll(i,1) = (((-out2.obs.pstress(i,15))-(-out2.obs.pstress(i,7)))/2)*(1+.6^2)^.5 - .6*(((-out2.obs.pstress(i,15))+(-out1.obs.pstress(i,7)))/2);
    S3_ll(i,1) = (-out2.obs.pstress(i,7));
    if find(L_ll(:,1)==i)
        Sc_ll(i,1) = NaN;
        S3_ll(i,1) = NaN;
    end
end

% extract stress values to compute means and standard deviations
k=1;
for i=1:length(Sc_ul)
    if isnan(Sc_ul(i)-Sc_ll(i))
        Sc(i,1) = 0;
        S3(i,1) = 0;
    else
        Sc(i,1) = abs(Sc_ul(i)-Sc_ll(i));
        S3(i,1) = abs(S3_ul(i)-S3_ll(i));
        ScReal(k,1) = abs(Sc_ul(i)-Sc_ll(i));
        S3Real(k,1) = abs(S3_ul(i)-S3_ll(i));
        k=k+1;
    end
end

% Mean and Standard Deviation
% Sc
Scmean = mean(ScReal);%/1000000;
SigSc = std(ScReal);
% Shmin
Shminmean = mean(S3Real);%/1000000;
SigShmin = std(S3Real);

% STRESS_GRID --> X,Y,Z,maximum Coulomb shear stress,Shmin
STRESS_GRID(:,1:3) = out1.obs.xyz(:,1:3);
STRESS_GRID(:,4) = Sc;
STRESS_GRID(:,5) = S3;

%% Permeability Model Layer Normalization

% Fault Layers
Fault.sliptendency(:,1:3) = FAULT_GRID(:,1:3);
Fault.sliptendency(:,4) = FAULT_GRID(:,4)/max(FAULT_GRID(:,4));
Fault.dilationtendency(:,1:3) = FAULT_GRID(:,1:3);
Fault.dilationtendency(:,4) = FAULT_GRID(:,5)/max(FAULT_GRID(:,5));
% displacement
Fault.displacement(:,1:3) = FAULT_GRID(:,1:3);
Fault.displacement(:,4) = FAULT_GRID(:,6)/max(FAULT_GRID(:,6));
% displacement gradient
Fault.displacementgradient(:,1:3) = FAULT_GRID(:,1:3);
Fault.displacementgradient(:,4) = FAULT_GRID(:,7)/max(FAULT_GRID(:,7));

% Stress Layers
% normalization between +/- X standard deviations
nsd = 5;% # of standard deviations
Stress.MaximumCoulombShearStress(:,1:3) = STRESS_GRID(:,1:3);
% Stress.MaximumCoulombShearStress(:,4) = (STRESS_GRID(:,4)-(Scmean-sdc*SigSc))/(2*sdc*SigSc);
Stress.MaximumCoulombShearStress(:,4) = STRESS_GRID(:,4)/(2*nsd*SigSc);
I = find(Stress.MaximumCoulombShearStress(:,4)<0);
Stress.MaximumCoulombShearStress(I,4) = 0;
I = find(Stress.MaximumCoulombShearStress(:,4)>1);
Stress.MaximumCoulombShearStress(I,4) = 1;
for i=1:length(L_ul)
    Stress.MaximumCoulombShearStress(L_ul(i,1),4) = 0;
end
for i=1:length(L_ll)
    Stress.MaximumCoulombShearStress(L_ll(i,1),4) = 0;
end

% Inverse Shmin values by adding 2*mean to negative values
Stress.Sigma3(:,1:3) = STRESS_GRID(:,1:3);
Stress.Sigma3(:,4) = STRESS_GRID(:,5);
Stress.Sigma3(:,4) = Stress.Sigma3(:,4)/(2*nsd*SigShmin);
I = find(Stress.Sigma3(:,4)<0);
Stress.Sigma3(I,4) = 0;
I = find(Stress.Sigma3(:,4)>1);
Stress.Sigma3(I,4) = 1;
for i=1:length(L_ul)
    Stress.Sigma3(L_ul(i,1),4) = 0;
end
for i=1:length(L_ll)
    Stress.Sigma3(L_ll(i,1),4) = 0;
end
%% FIGURES

figure
plot([1:numel(Sc)],Sc,'k-');ylabel('Sc')
hold on
plot([0 9292],[Scmean+2*nsd*SigSc Scmean+2*nsd*SigSc])
plot([0 9292],[0 0])
figure
plot([1:numel(S3)],S3,'k-');ylabel('Shmin')
hold on
plot([0 9292],[Shminmean+2*nsd*SigShmin Shminmean+2*nsd*SigShmin])
plot([0 9292],[0 0])

figure
plot([1:numel(Stress.MaximumCoulombShearStress(:,4))],Stress.MaximumCoulombShearStress(:,4),'k.');ylabel('Sc favorability')
figure
plot([1:numel(Stress.Sigma3(:,4))],Stress.Sigma3(:,4),'k.');ylabel('Shmin favorability')

% grid data for contour plots
for j=0:91
for i=0:100
    X(1+i,1+j) = out1.obs.pstress((1+i)+101*j,1);
    Y(1+i,1+j) = out1.obs.pstress((1+i)+101*j,2);
    STXY(1+i,1+j) = Fault.sliptendency((1+i)+101*j,4);
    DTXY(1+i,1+j) = Fault.dilationtendency((1+i)+101*j,4);
    DispXY(1+i,1+j) = Fault.displacement((1+i)+101*j,4);
    DGXY(1+i,1+j) = Fault.displacementgradient((1+i)+101*j,4);
    ScXY(1+i,1+j) = Stress.MaximumCoulombShearStress((1+i)+101*j,4);
    SsXY(1+i,1+j) = Stress.Sigma3((1+i)+101*j,4);
    if find(L_ul(:,1)==((1+i)+101*j))
        ScXY(1+i,1+j) = NaN;
        SsXY(1+i,1+j) = NaN;
    elseif find(L_ll(:,1)==((1+i)+101*j))
        ScXY(1+i,1+j) = NaN;
        SsXY(1+i,1+j) = NaN;
    end
end
end

% colormap white-black
for i=1:50
    unccm(i,:) = [(1-i/50) (1-i/50) (1-i/50)];
end

% Sc sensitivity map
figure
contourf(X,Y,ScXY)
hold on
contour(X,Y,ScXY)
c=colorbar;
set(get(c,'ylabel'),'String','Sc uncertainty','Fontsize',14);
caxis([0 1]);
colormap(unccm);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)

% S3 sensitivity map
figure
contourf(X,Y,SsXY)
hold on
contour(X,Y,SsXY)
c=colorbar;
set(get(c,'ylabel'),'String','Sigma3 uncertainty','Fontsize',14);
caxis([0 1]);
colormap(unccm);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)

% ST sensitivity map
figure
contourf(X,Y,STXY)
hold on
contour(X,Y,STXY)
c=colorbar;
set(get(c,'ylabel'),'String','Slip Tendency uncertainty','Fontsize',14);
caxis([0 1]);
colormap(unccm);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)

% DT sensitivity map
figure
contourf(X,Y,DTXY)
hold on
contour(X,Y,DTXY)
c=colorbar;
set(get(c,'ylabel'),'String','Dilation Tendency uncertainty','Fontsize',14);
caxis([0 1]);
colormap(unccm);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)

% Disp sensitivity map
figure
contourf(X,Y,DispXY)
hold on
contour(X,Y,DispXY)
c=colorbar;
set(get(c,'ylabel'),'String','Displacement uncertainty','Fontsize',14);
caxis([0 1]);
colormap(unccm);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)

% DG sensitivity map
figure
contourf(X,Y,DGXY)
hold on
contour(X,Y,DGXY)
c=colorbar;
set(get(c,'ylabel'),'String','Displacement Gradient uncertainty','Fontsize',14);
caxis([0 1]);
colormap(unccm);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)